package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type ArticleDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewArticleDAOImplement(session *xorm.Session, plantNr int, userid string) *ArticleDAOImplement {
	return &ArticleDAOImplement{session, plantNr, userid}
}

//插入Article
func (self *ArticleDAOImplement) InsertOne(entity *model.Article) error {
	_, err := self.session.Table(meta.Article.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的Article
func (self *ArticleDAOImplement) DeleteOne(artId string) error {
	_, err := self.session.Table(meta.Article.TableName).ID(core.PK{self.plantNr, artId}).Delete(meta.Article.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的Article
func (self *ArticleDAOImplement) SelectOne(artId string) (*model.Article, error) {
	var data model.Article
	ok, err := self.session.Table(meta.Article.TableName).ID(core.PK{self.plantNr, artId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改Article
func (self *ArticleDAOImplement) UpdateOne(entity *model.Article) error {
	_, err := self.session.Table(meta.Article.TableName).Cols(meta.Article_Descr1.ColumnName, meta.Article_Descr2.ColumnName, meta.Article_ArtTypeId.ColumnName, meta.Article_ProjectId.ColumnName, meta.Article_CustMaterialId.ColumnName, meta.Article_AlternativeMaterialId.ColumnName, meta.Article_UomId.ColumnName, meta.Article_QuantityPerHour.ColumnName, meta.Article_DeliveryBuffer.ColumnName, meta.Article_Icon.ColumnName, meta.Article_DisplayColor.ColumnName, meta.Article_Document.ColumnName, meta.Article_DefaultRoute.ColumnName, meta.Article_LotSize.ColumnName, meta.Article_ABCClass.ColumnName, meta.Article_ArtSize1.ColumnName, meta.Article_ArtSize2.ColumnName, meta.Article_ArtSize3.ColumnName, meta.Article_ArtSize4.ColumnName, meta.Article_ArtSize5.ColumnName, meta.Article_ArtSpec1.ColumnName, meta.Article_ArtSpec2.ColumnName, meta.Article_ArtSpec3.ColumnName, meta.Article_ArtSpec4.ColumnName, meta.Article_ArtSpec5.ColumnName, meta.Article_DefaultInspectPlanId.ColumnName, meta.Article_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查Article
func (self *ArticleDAOImplement) checkArticleRecords(records *[]model.Article) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询Article
func (self *ArticleDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.Article, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.Article, 0, 10)
	session := self.session.Table(meta.Article.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询Article并分页
func (self *ArticleDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.Article.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.Article.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.Article, 0, 10)
	err = self.session.Table(meta.Article.TableName).SQL("select * from Article where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
