package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type AttributeDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewAttributeDAOImplement(session *xorm.Session, plantNr int, userid string) *AttributeDAOImplement {
	return &AttributeDAOImplement{session, plantNr, userid}
}

//插入Attribute
func (self *AttributeDAOImplement) InsertOne(entity *model.Attribute) error {
	_, err := self.session.Table(meta.Attribute.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的Attribute
func (self *AttributeDAOImplement) DeleteOne(attrCode int) error {
	_, err := self.session.Table(meta.Attribute.TableName).ID(core.PK{self.plantNr, attrCode}).Delete(meta.Attribute.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的Attribute
func (self *AttributeDAOImplement) SelectOne(attrCode int) (*model.Attribute, error) {
	var data model.Attribute
	ok, err := self.session.Table(meta.Attribute.TableName).ID(core.PK{self.plantNr, attrCode}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改Attribute
func (self *AttributeDAOImplement) UpdateOne(entity *model.Attribute) error {
	_, err := self.session.Table(meta.Attribute.TableName).Cols(meta.Attribute_AttrName.ColumnName, meta.Attribute_Descr.ColumnName, meta.Attribute_AttrGroup.ColumnName, meta.Attribute_ShortCode.ColumnName, meta.Attribute_AttrType.ColumnName, meta.Attribute_AttrDataType.ColumnName, meta.Attribute_AttrValType.ColumnName, meta.Attribute_ValFormat.ColumnName, meta.Attribute_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查Attribute
func (self *AttributeDAOImplement) checkAttributeRecords(records *[]model.Attribute) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询Attribute
func (self *AttributeDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.Attribute, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.Attribute, 0, 10)
	session := self.session.Table(meta.Attribute.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询Attribute并分页
func (self *AttributeDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.Attribute.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.Attribute.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.Attribute, 0, 10)
	err = self.session.Table(meta.Attribute.TableName).SQL("select * from Attribute where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
