package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type AttributeGroupDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewAttributeGroupDAOImplement(session *xorm.Session, plantNr int, userid string) *AttributeGroupDAOImplement {
	return &AttributeGroupDAOImplement{session, plantNr, userid}
}

//插入AttributeGroup
func (self *AttributeGroupDAOImplement) InsertOne(entity *model.AttributeGroup) error {
	_, err := self.session.Table(meta.AttributeGroup.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的AttributeGroup
func (self *AttributeGroupDAOImplement) DeleteOne(attrGrpCode int) error {
	_, err := self.session.Table(meta.AttributeGroup.TableName).ID(core.PK{self.plantNr, attrGrpCode}).Delete(meta.AttributeGroup.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的AttributeGroup
func (self *AttributeGroupDAOImplement) SelectOne(attrGrpCode int) (*model.AttributeGroup, error) {
	var data model.AttributeGroup
	ok, err := self.session.Table(meta.AttributeGroup.TableName).ID(core.PK{self.plantNr, attrGrpCode}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改AttributeGroup
func (self *AttributeGroupDAOImplement) UpdateOne(entity *model.AttributeGroup) error {
	_, err := self.session.Table(meta.AttributeGroup.TableName).Cols(meta.AttributeGroup_Descr.ColumnName, meta.AttributeGroup_Color.ColumnName, meta.AttributeGroup_AgiPara1.ColumnName, meta.AttributeGroup_AgiPara2.ColumnName, meta.AttributeGroup_AgcPara1.ColumnName, meta.AttributeGroup_AgcPara2.ColumnName, meta.AttributeGroup_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查AttributeGroup
func (self *AttributeGroupDAOImplement) checkAttributeGroupRecords(records *[]model.AttributeGroup) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询AttributeGroup
func (self *AttributeGroupDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.AttributeGroup, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.AttributeGroup, 0, 10)
	session := self.session.Table(meta.AttributeGroup.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询AttributeGroup并分页
func (self *AttributeGroupDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.AttributeGroup.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.AttributeGroup.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.AttributeGroup, 0, 10)
	err = self.session.Table(meta.AttributeGroup.TableName).SQL("select * from AttributeGroup where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
