package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type AttributeValstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewAttributeValstDAOImplement(session *xorm.Session, plantNr int, userid string) *AttributeValstDAOImplement {
	return &AttributeValstDAOImplement{session, plantNr, userid}
}

//插入AttributeValst
func (self *AttributeValstDAOImplement) InsertOne(entity *model.AttributeValst) error {
	_, err := self.session.Table(meta.AttributeValst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的AttributeValst
func (self *AttributeValstDAOImplement) DeleteOne(attrCode int, pos int) error {
	_, err := self.session.Table(meta.AttributeValst.TableName).ID(core.PK{self.plantNr, attrCode, pos}).Delete(meta.AttributeValst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的AttributeValst
func (self *AttributeValstDAOImplement) SelectOne(attrCode int, pos int) (*model.AttributeValst, error) {
	var data model.AttributeValst
	ok, err := self.session.Table(meta.AttributeValst.TableName).ID(core.PK{self.plantNr, attrCode, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改AttributeValst
func (self *AttributeValstDAOImplement) UpdateOne(entity *model.AttributeValst) error {
	_, err := self.session.Table(meta.AttributeValst.TableName).Cols(meta.AttributeValst_AttrValue.ColumnName, meta.AttributeValst_Descr.ColumnName, meta.AttributeValst_ShortCode.ColumnName, meta.AttributeValst_Valformat.ColumnName, meta.AttributeValst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查AttributeValst
func (self *AttributeValstDAOImplement) checkAttributeValstRecords(records *[]model.AttributeValst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询AttributeValst
func (self *AttributeValstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.AttributeValst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.AttributeValst, 0, 10)
	session := self.session.Table(meta.AttributeValst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询AttributeValst并分页
func (self *AttributeValstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.AttributeValst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.AttributeValst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.AttributeValst, 0, 10)
	err = self.session.Table(meta.AttributeValst.TableName).SQL("select * from AttributeValst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
