package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type CodeParserDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewCodeParserDAOImplement(session *xorm.Session, plantNr int, userid string) *CodeParserDAOImplement {
	return &CodeParserDAOImplement{session, plantNr, userid}
}

//插入CodeParser
func (self *CodeParserDAOImplement) InsertOne(entity *model.CodeParser) error {
	_, err := self.session.Table(meta.CodeParser.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的CodeParser
func (self *CodeParserDAOImplement) DeleteOne(parserId string) error {
	_, err := self.session.Table(meta.CodeParser.TableName).ID(core.PK{self.plantNr, parserId}).Delete(meta.CodeParser.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的CodeParser
func (self *CodeParserDAOImplement) SelectOne(parserId string) (*model.CodeParser, error) {
	var data model.CodeParser
	ok, err := self.session.Table(meta.CodeParser.TableName).ID(core.PK{self.plantNr, parserId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改CodeParser
func (self *CodeParserDAOImplement) UpdateOne(entity *model.CodeParser) error {
	_, err := self.session.Table(meta.CodeParser.TableName).Cols(meta.CodeParser_StartPos.ColumnName, meta.CodeParser_Length.ColumnName, meta.CodeParser_ParserType.ColumnName, meta.CodeParser_Descr.ColumnName, meta.CodeParser_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查CodeParser
func (self *CodeParserDAOImplement) checkCodeParserRecords(records *[]model.CodeParser) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询CodeParser
func (self *CodeParserDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.CodeParser, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.CodeParser, 0, 10)
	session := self.session.Table(meta.CodeParser.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询CodeParser并分页
func (self *CodeParserDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.CodeParser.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.CodeParser.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.CodeParser, 0, 10)
	err = self.session.Table(meta.CodeParser.TableName).SQL("select * from CodeParser where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
