package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type CostCenterDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewCostCenterDAOImplement(session *xorm.Session, plantNr int, userid string) *CostCenterDAOImplement {
	return &CostCenterDAOImplement{session, plantNr, userid}
}

//插入CostCenter
func (self *CostCenterDAOImplement) InsertOne(entity *model.CostCenter) error {
	_, err := self.session.Table(meta.CostCenter.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的CostCenter
func (self *CostCenterDAOImplement) DeleteOne(costCenterId string) error {
	_, err := self.session.Table(meta.CostCenter.TableName).ID(core.PK{self.plantNr, costCenterId}).Delete(meta.CostCenter.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的CostCenter
func (self *CostCenterDAOImplement) SelectOne(costCenterId string) (*model.CostCenter, error) {
	var data model.CostCenter
	ok, err := self.session.Table(meta.CostCenter.TableName).ID(core.PK{self.plantNr, costCenterId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改CostCenter
func (self *CostCenterDAOImplement) UpdateOne(entity *model.CostCenter) error {
	_, err := self.session.Table(meta.CostCenter.TableName).Cols(meta.CostCenter_Descr.ColumnName, meta.CostCenter_HourRate.ColumnName, meta.CostCenter_CCCVal1.ColumnName, meta.CostCenter_CCCVal2.ColumnName, meta.CostCenter_CCIVal1.ColumnName, meta.CostCenter_CCIVal2.ColumnName, meta.CostCenter_CCFVal1.ColumnName, meta.CostCenter_CCFVal2.ColumnName, meta.CostCenter_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查CostCenter
func (self *CostCenterDAOImplement) checkCostCenterRecords(records *[]model.CostCenter) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询CostCenter
func (self *CostCenterDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.CostCenter, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.CostCenter, 0, 10)
	session := self.session.Table(meta.CostCenter.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询CostCenter并分页
func (self *CostCenterDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.CostCenter.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.CostCenter.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.CostCenter, 0, 10)
	err = self.session.Table(meta.CostCenter.TableName).SQL("select * from CostCenter where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
