package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type PlantDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewPlantDAOImplement(session *xorm.Session, plantNr int, userid string) *PlantDAOImplement {
	return &PlantDAOImplement{session, plantNr, userid}
}

//插入Plant
func (self *PlantDAOImplement) InsertOne(entity *model.Plant) error {
	_, err := self.session.Table(meta.Plant.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的Plant
func (self *PlantDAOImplement) DeleteOne() error {

	return nil
}

//查找指定键的Plant
func (self *PlantDAOImplement) SelectOne() (*model.Plant, error) {
	var data model.Plant
	ok, err := self.session.Table(meta.Plant.TableName).ID(core.PK{self.plantNr}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改Plant
func (self *PlantDAOImplement) UpdateOne(entity *model.Plant) error {
	_, err := self.session.Table(meta.Plant.TableName).Cols(meta.Plant_Status.ColumnName, meta.Plant_Name1.ColumnName, meta.Plant_Name2.ColumnName, meta.Plant_Logo.ColumnName, meta.Plant_Abrevname.ColumnName, meta.Plant_Country.ColumnName, meta.Plant_Street.ColumnName, meta.Plant_Address.ColumnName, meta.Plant_PostCode.ColumnName, meta.Plant_Phone.ColumnName, meta.Plant_Fax.ColumnName, meta.Plant_StartYear.ColumnName, meta.Plant_EndYear.ColumnName, meta.Plant_CompanyTitle.ColumnName, meta.Plant_CompanyAddress.ColumnName, meta.Plant_TaxId.ColumnName, meta.Plant_AccountBank.ColumnName, meta.Plant_AccountNr.ColumnName, meta.Plant_Currency.ColumnName, meta.Plant_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查Plant
func (self *PlantDAOImplement) checkPlantRecords(records *[]model.Plant) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询Plant
func (self *PlantDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.Plant, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.Plant, 0, 10)
	session := self.session.Table(meta.Plant.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询Plant并分页
func (self *PlantDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.Plant.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.Plant.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.Plant, 0, 10)
	err = self.session.Table(meta.Plant.TableName).SQL("select * from Plant where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
