package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type StatusColorDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewStatusColorDAOImplement(session *xorm.Session, plantNr int, userid string) *StatusColorDAOImplement {
	return &StatusColorDAOImplement{session, plantNr, userid}
}

//插入StatusColor
func (self *StatusColorDAOImplement) InsertOne(entity *model.StatusColor) error {
	_, err := self.session.Table(meta.StatusColor.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的StatusColor
func (self *StatusColorDAOImplement) DeleteOne(statusObj string, statusVal string) error {
	_, err := self.session.Table(meta.StatusColor.TableName).ID(core.PK{self.plantNr, statusObj, statusVal}).Delete(meta.StatusColor.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的StatusColor
func (self *StatusColorDAOImplement) SelectOne(statusObj string, statusVal string) (*model.StatusColor, error) {
	var data model.StatusColor
	ok, err := self.session.Table(meta.StatusColor.TableName).ID(core.PK{self.plantNr, statusObj, statusVal}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改StatusColor
func (self *StatusColorDAOImplement) UpdateOne(entity *model.StatusColor) error {
	_, err := self.session.Table(meta.StatusColor.TableName).Cols(meta.StatusColor_Descr.ColumnName, meta.StatusColor_StatusRgb.ColumnName, meta.StatusColor_StatusHexColor.ColumnName, meta.StatusColor_StatusBitmap.ColumnName, meta.StatusColor_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查StatusColor
func (self *StatusColorDAOImplement) checkStatusColorRecords(records *[]model.StatusColor) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询StatusColor
func (self *StatusColorDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.StatusColor, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.StatusColor, 0, 10)
	session := self.session.Table(meta.StatusColor.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询StatusColor并分页
func (self *StatusColorDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.StatusColor.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.StatusColor.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.StatusColor, 0, 10)
	err = self.session.Table(meta.StatusColor.TableName).SQL("select * from StatusColor where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
