package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type UomDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewUomDAOImplement(session *xorm.Session, plantNr int, userid string) *UomDAOImplement {
	return &UomDAOImplement{session, plantNr, userid}
}

//插入Uom
func (self *UomDAOImplement) InsertOne(entity *model.Uom) error {
	_, err := self.session.Table(meta.Uom.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的Uom
func (self *UomDAOImplement) DeleteOne(uomId string) error {
	_, err := self.session.Table(meta.Uom.TableName).ID(core.PK{self.plantNr, uomId}).Delete(meta.Uom.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的Uom
func (self *UomDAOImplement) SelectOne(uomId string) (*model.Uom, error) {
	var data model.Uom
	ok, err := self.session.Table(meta.Uom.TableName).ID(core.PK{self.plantNr, uomId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改Uom
func (self *UomDAOImplement) UpdateOne(entity *model.Uom) error {
	_, err := self.session.Table(meta.Uom.TableName).Cols(meta.Uom_UomName.ColumnName, meta.Uom_UomType.ColumnName, meta.Uom_BasicUomToggle.ColumnName, meta.Uom_BasicUom.ColumnName, meta.Uom_ConvertRatio.ColumnName, meta.Uom_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查Uom
func (self *UomDAOImplement) checkUomRecords(records *[]model.Uom) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询Uom
func (self *UomDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.Uom, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.Uom, 0, 10)
	session := self.session.Table(meta.Uom.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询Uom并分页
func (self *UomDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.Uom.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.Uom.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.Uom, 0, 10)
	err = self.session.Table(meta.Uom.TableName).SQL("select * from Uom where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
