package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type WeekModelLstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewWeekModelLstDAOImplement(session *xorm.Session, plantNr int, userid string) *WeekModelLstDAOImplement {
	return &WeekModelLstDAOImplement{session, plantNr, userid}
}

//插入WeekModelLst
func (self *WeekModelLstDAOImplement) InsertOne(entity *model.WeekModelLst) error {
	_, err := self.session.Table(meta.WeekModelLst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的WeekModelLst
func (self *WeekModelLstDAOImplement) DeleteOne(weekModelNr int, workDate int) error {
	_, err := self.session.Table(meta.WeekModelLst.TableName).ID(core.PK{self.plantNr, weekModelNr, workDate}).Delete(meta.WeekModelLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的WeekModelLst
func (self *WeekModelLstDAOImplement) SelectOne(weekModelNr int, workDate int) (*model.WeekModelLst, error) {
	var data model.WeekModelLst
	ok, err := self.session.Table(meta.WeekModelLst.TableName).ID(core.PK{self.plantNr, weekModelNr, workDate}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改WeekModelLst
func (self *WeekModelLstDAOImplement) UpdateOne(entity *model.WeekModelLst) error {
	_, err := self.session.Table(meta.WeekModelLst.TableName).Cols(meta.WeekModelLst_DayModelNr.ColumnName, meta.WeekModelLst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查WeekModelLst
func (self *WeekModelLstDAOImplement) checkWeekModelLstRecords(records *[]model.WeekModelLst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询WeekModelLst
func (self *WeekModelLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WeekModelLst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.WeekModelLst, 0, 10)
	session := self.session.Table(meta.WeekModelLst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询WeekModelLst并分页
func (self *WeekModelLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.WeekModelLst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.WeekModelLst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WeekModelLst, 0, 10)
	err = self.session.Table(meta.WeekModelLst.TableName).SQL("select * from WeekModelLst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
