package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type WorkCalendarDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewWorkCalendarDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkCalendarDAOImplement {
	return &WorkCalendarDAOImplement{session, plantNr, userid}
}

//插入WorkCalendar
func (self *WorkCalendarDAOImplement) InsertOne(entity *model.WorkCalendar) error {
	_, err := self.session.Table(meta.WorkCalendar.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的WorkCalendar
func (self *WorkCalendarDAOImplement) DeleteOne(workCalendarNr int) error {
	_, err := self.session.Table(meta.WorkCalendar.TableName).ID(core.PK{self.plantNr, workCalendarNr}).Delete(meta.WorkCalendar.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的WorkCalendar
func (self *WorkCalendarDAOImplement) SelectOne(workCalendarNr int) (*model.WorkCalendar, error) {
	var data model.WorkCalendar
	ok, err := self.session.Table(meta.WorkCalendar.TableName).ID(core.PK{self.plantNr, workCalendarNr}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改WorkCalendar
func (self *WorkCalendarDAOImplement) UpdateOne(entity *model.WorkCalendar) error {
	_, err := self.session.Table(meta.WorkCalendar.TableName).Cols(meta.WorkCalendar_Descr.ColumnName, meta.WorkCalendar_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查WorkCalendar
func (self *WorkCalendarDAOImplement) checkWorkCalendarRecords(records *[]model.WorkCalendar) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询WorkCalendar
func (self *WorkCalendarDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkCalendar, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.WorkCalendar, 0, 10)
	session := self.session.Table(meta.WorkCalendar.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询WorkCalendar并分页
func (self *WorkCalendarDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.WorkCalendar.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.WorkCalendar.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkCalendar, 0, 10)
	err = self.session.Table(meta.WorkCalendar.TableName).SQL("select * from WorkCalendar where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
