package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type WorkCalendarLstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewWorkCalendarLstDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkCalendarLstDAOImplement {
	return &WorkCalendarLstDAOImplement{session, plantNr, userid}
}

//插入WorkCalendarLst
func (self *WorkCalendarLstDAOImplement) InsertOne(entity *model.WorkCalendarLst) error {
	_, err := self.session.Table(meta.WorkCalendarLst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的WorkCalendarLst
func (self *WorkCalendarLstDAOImplement) DeleteOne(workCalendarNr int, workDate int) error {
	_, err := self.session.Table(meta.WorkCalendarLst.TableName).ID(core.PK{self.plantNr, workCalendarNr, workDate}).Delete(meta.WorkCalendarLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的WorkCalendarLst
func (self *WorkCalendarLstDAOImplement) SelectOne(workCalendarNr int, workDate int) (*model.WorkCalendarLst, error) {
	var data model.WorkCalendarLst
	ok, err := self.session.Table(meta.WorkCalendarLst.TableName).ID(core.PK{self.plantNr, workCalendarNr, workDate}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改WorkCalendarLst
func (self *WorkCalendarLstDAOImplement) UpdateOne(entity *model.WorkCalendarLst) error {
	_, err := self.session.Table(meta.WorkCalendarLst.TableName).Cols(meta.WorkCalendarLst_DayModelNr.ColumnName, meta.WorkCalendarLst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查WorkCalendarLst
func (self *WorkCalendarLstDAOImplement) checkWorkCalendarLstRecords(records *[]model.WorkCalendarLst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询WorkCalendarLst
func (self *WorkCalendarLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkCalendarLst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.WorkCalendarLst, 0, 10)
	session := self.session.Table(meta.WorkCalendarLst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询WorkCalendarLst并分页
func (self *WorkCalendarLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.WorkCalendarLst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.WorkCalendarLst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkCalendarLst, 0, 10)
	err = self.session.Table(meta.WorkCalendarLst.TableName).SQL("select * from WorkCalendarLst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
