package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type WorkLineDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewWorkLineDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkLineDAOImplement {
	return &WorkLineDAOImplement{session, plantNr, userid}
}

//插入WorkLine
func (self *WorkLineDAOImplement) InsertOne(entity *model.WorkLine) error {
	_, err := self.session.Table(meta.WorkLine.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的WorkLine
func (self *WorkLineDAOImplement) DeleteOne(workLineid string) error {
	_, err := self.session.Table(meta.WorkLine.TableName).ID(core.PK{self.plantNr, workLineid}).Delete(meta.WorkLine.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的WorkLine
func (self *WorkLineDAOImplement) SelectOne(workLineid string) (*model.WorkLine, error) {
	var data model.WorkLine
	ok, err := self.session.Table(meta.WorkLine.TableName).ID(core.PK{self.plantNr, workLineid}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改WorkLine
func (self *WorkLineDAOImplement) UpdateOne(entity *model.WorkLine) error {
	_, err := self.session.Table(meta.WorkLine.TableName).Cols(meta.WorkLine_Descr.ColumnName, meta.WorkLine_LineType.ColumnName, meta.WorkLine_LinePlanMode.ColumnName, meta.WorkLine_WeekModelNr.ColumnName, meta.WorkLine_WorkCalendarNr.ColumnName, meta.WorkLine_Location.ColumnName, meta.WorkLine_CostCenterId.ColumnName, meta.WorkLine_CostRate.ColumnName, meta.WorkLine_ProdEff.ColumnName, meta.WorkLine_ReqWorkers.ColumnName, meta.WorkLine_Pos.ColumnName, meta.WorkLine_TaskQueueSortWay.ColumnName, meta.WorkLine_MultiQueueMixSortToggle.ColumnName, meta.WorkLine_TaskQueueMixSortWay.ColumnName, meta.WorkLine_MixSortLogic.ColumnName, meta.WorkLine_TaskReleaseWay.ColumnName, meta.WorkLine_ReleaseQtyParameter.ColumnName, meta.WorkLine_ReleaseTimeParameter.ColumnName, meta.WorkLine_ReleaseCtrlParameter.ColumnName, meta.WorkLine_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查WorkLine
func (self *WorkLineDAOImplement) checkWorkLineRecords(records *[]model.WorkLine) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询WorkLine
func (self *WorkLineDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkLine, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.WorkLine, 0, 10)
	session := self.session.Table(meta.WorkLine.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询WorkLine并分页
func (self *WorkLineDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.WorkLine.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.WorkLine.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkLine, 0, 10)
	err = self.session.Table(meta.WorkLine.TableName).SQL("select * from WorkLine where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
