package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type WorkLineSpecialDayDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewWorkLineSpecialDayDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkLineSpecialDayDAOImplement {
	return &WorkLineSpecialDayDAOImplement{session, plantNr, userid}
}

//插入WorkLineSpecialDay
func (self *WorkLineSpecialDayDAOImplement) InsertOne(entity *model.WorkLineSpecialDay) error {
	_, err := self.session.Table(meta.WorkLineSpecialDay.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的WorkLineSpecialDay
func (self *WorkLineSpecialDayDAOImplement) DeleteOne(workLineid string, specialDay string) error {
	_, err := self.session.Table(meta.WorkLineSpecialDay.TableName).ID(core.PK{self.plantNr, workLineid, specialDay}).Delete(meta.WorkLineSpecialDay.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的WorkLineSpecialDay
func (self *WorkLineSpecialDayDAOImplement) SelectOne(workLineid string, specialDay string) (*model.WorkLineSpecialDay, error) {
	var data model.WorkLineSpecialDay
	ok, err := self.session.Table(meta.WorkLineSpecialDay.TableName).ID(core.PK{self.plantNr, workLineid, specialDay}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改WorkLineSpecialDay
func (self *WorkLineSpecialDayDAOImplement) UpdateOne(entity *model.WorkLineSpecialDay) error {
	_, err := self.session.Table(meta.WorkLineSpecialDay.TableName).Cols(meta.WorkLineSpecialDay_DayModelNr.ColumnName, meta.WorkLineSpecialDay_Descr.ColumnName, meta.WorkLineSpecialDay_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查WorkLineSpecialDay
func (self *WorkLineSpecialDayDAOImplement) checkWorkLineSpecialDayRecords(records *[]model.WorkLineSpecialDay) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询WorkLineSpecialDay
func (self *WorkLineSpecialDayDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkLineSpecialDay, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.WorkLineSpecialDay, 0, 10)
	session := self.session.Table(meta.WorkLineSpecialDay.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询WorkLineSpecialDay并分页
func (self *WorkLineSpecialDayDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.WorkLineSpecialDay.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.WorkLineSpecialDay.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkLineSpecialDay, 0, 10)
	err = self.session.Table(meta.WorkLineSpecialDay.TableName).SQL("select * from WorkLineSpecialDay where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
