package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type WorkLineWorkShiftLstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewWorkLineWorkShiftLstDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkLineWorkShiftLstDAOImplement {
	return &WorkLineWorkShiftLstDAOImplement{session, plantNr, userid}
}

//插入WorkLineWorkShiftLst
func (self *WorkLineWorkShiftLstDAOImplement) InsertOne(entity *model.WorkLineWorkShiftLst) error {
	_, err := self.session.Table(meta.WorkLineWorkShiftLst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的WorkLineWorkShiftLst
func (self *WorkLineWorkShiftLstDAOImplement) DeleteOne(workLineId string, workDay string, pos int) error {
	_, err := self.session.Table(meta.WorkLineWorkShiftLst.TableName).ID(core.PK{self.plantNr, workLineId, workDay, pos}).Delete(meta.WorkLineWorkShiftLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的WorkLineWorkShiftLst
func (self *WorkLineWorkShiftLstDAOImplement) SelectOne(workLineId string, workDay string, pos int) (*model.WorkLineWorkShiftLst, error) {
	var data model.WorkLineWorkShiftLst
	ok, err := self.session.Table(meta.WorkLineWorkShiftLst.TableName).ID(core.PK{self.plantNr, workLineId, workDay, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改WorkLineWorkShiftLst
func (self *WorkLineWorkShiftLstDAOImplement) UpdateOne(entity *model.WorkLineWorkShiftLst) error {
	_, err := self.session.Table(meta.WorkLineWorkShiftLst.TableName).Cols(meta.WorkLineWorkShiftLst_WorkShiftNr.ColumnName, meta.WorkLineWorkShiftLst_LevelId.ColumnName, meta.WorkLineWorkShiftLst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查WorkLineWorkShiftLst
func (self *WorkLineWorkShiftLstDAOImplement) checkWorkLineWorkShiftLstRecords(records *[]model.WorkLineWorkShiftLst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询WorkLineWorkShiftLst
func (self *WorkLineWorkShiftLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkLineWorkShiftLst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.WorkLineWorkShiftLst, 0, 10)
	session := self.session.Table(meta.WorkLineWorkShiftLst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询WorkLineWorkShiftLst并分页
func (self *WorkLineWorkShiftLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.WorkLineWorkShiftLst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.WorkLineWorkShiftLst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkLineWorkShiftLst, 0, 10)
	err = self.session.Table(meta.WorkLineWorkShiftLst.TableName).SQL("select * from WorkLineWorkShiftLst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
