package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type WorkShiftDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewWorkShiftDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkShiftDAOImplement {
	return &WorkShiftDAOImplement{session, plantNr, userid}
}

//插入WorkShift
func (self *WorkShiftDAOImplement) InsertOne(entity *model.WorkShift) error {
	_, err := self.session.Table(meta.WorkShift.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的WorkShift
func (self *WorkShiftDAOImplement) DeleteOne(workShiftNr int) error {
	_, err := self.session.Table(meta.WorkShift.TableName).ID(core.PK{self.plantNr, workShiftNr}).Delete(meta.WorkShift.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的WorkShift
func (self *WorkShiftDAOImplement) SelectOne(workShiftNr int) (*model.WorkShift, error) {
	var data model.WorkShift
	ok, err := self.session.Table(meta.WorkShift.TableName).ID(core.PK{self.plantNr, workShiftNr}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改WorkShift
func (self *WorkShiftDAOImplement) UpdateOne(entity *model.WorkShift) error {
	_, err := self.session.Table(meta.WorkShift.TableName).Cols(meta.WorkShift_Descr.ColumnName, meta.WorkShift_Abrev.ColumnName, meta.WorkShift_HexColor.ColumnName, meta.WorkShift_PlanPersonQty.ColumnName, meta.WorkShift_PlanEfficiency.ColumnName, meta.WorkShift_SBeg.ColumnName, meta.WorkShift_SEnd.ColumnName, meta.WorkShift_SLen.ColumnName, meta.WorkShift_SB1Beg.ColumnName, meta.WorkShift_SB1End.ColumnName, meta.WorkShift_SB2Beg.ColumnName, meta.WorkShift_SB2End.ColumnName, meta.WorkShift_SB3Beg.ColumnName, meta.WorkShift_SB3End.ColumnName, meta.WorkShift_SB4Beg.ColumnName, meta.WorkShift_SB4End.ColumnName, meta.WorkShift_SB5Beg.ColumnName, meta.WorkShift_SB5End.ColumnName, meta.WorkShift_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查WorkShift
func (self *WorkShiftDAOImplement) checkWorkShiftRecords(records *[]model.WorkShift) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询WorkShift
func (self *WorkShiftDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkShift, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.WorkShift, 0, 10)
	session := self.session.Table(meta.WorkShift.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询WorkShift并分页
func (self *WorkShiftDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.WorkShift.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.WorkShift.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkShift, 0, 10)
	err = self.session.Table(meta.WorkShift.TableName).SQL("select * from WorkShift where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
