package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"xorm.io/core"
)

type WorkShiftEffLstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewWorkShiftEffLstDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkShiftEffLstDAOImplement {
	return &WorkShiftEffLstDAOImplement{session, plantNr, userid}
}

//插入WorkShiftEffLst
func (self *WorkShiftEffLstDAOImplement) InsertOne(entity *model.WorkShiftEffLst) error {
	_, err := self.session.Table(meta.WorkShiftEffLst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的WorkShiftEffLst
func (self *WorkShiftEffLstDAOImplement) DeleteOne(workShiftNr int, levelId string) error {
	_, err := self.session.Table(meta.WorkShiftEffLst.TableName).ID(core.PK{self.plantNr, workShiftNr, levelId}).Delete(meta.WorkShiftEffLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的WorkShiftEffLst
func (self *WorkShiftEffLstDAOImplement) SelectOne(workShiftNr int, levelId string) (*model.WorkShiftEffLst, error) {
	var data model.WorkShiftEffLst
	ok, err := self.session.Table(meta.WorkShiftEffLst.TableName).ID(core.PK{self.plantNr, workShiftNr, levelId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改WorkShiftEffLst
func (self *WorkShiftEffLstDAOImplement) UpdateOne(entity *model.WorkShiftEffLst) error {
	_, err := self.session.Table(meta.WorkShiftEffLst.TableName).Cols(meta.WorkShiftEffLst_Descr.ColumnName, meta.WorkShiftEffLst_PlanPersonUclQty.ColumnName, meta.WorkShiftEffLst_PlanPersonLclQty.ColumnName, meta.WorkShiftEffLst_PlanEfficiency.ColumnName, meta.WorkShiftEffLst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查WorkShiftEffLst
func (self *WorkShiftEffLstDAOImplement) checkWorkShiftEffLstRecords(records *[]model.WorkShiftEffLst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询WorkShiftEffLst
func (self *WorkShiftEffLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkShiftEffLst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.WorkShiftEffLst, 0, 10)
	session := self.session.Table(meta.WorkShiftEffLst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询WorkShiftEffLst并分页
func (self *WorkShiftEffLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.WorkShiftEffLst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.WorkShiftEffLst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkShiftEffLst, 0, 10)
	err = self.session.Table(meta.WorkShiftEffLst.TableName).SQL("select * from WorkShiftEffLst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
