package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"xorm.io/core"
)

type ArtDemandHeadDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewArtDemandHeadDAOImplement(session *xorm.Session, plantNr int, userid string) *ArtDemandHeadDAOImplement {
	return &ArtDemandHeadDAOImplement{session, plantNr, userid}
}

//插入ArtDemandHead
func (self *ArtDemandHeadDAOImplement) InsertOne(entity *model.ArtDemandHead) error {
	_, err := self.session.Table(meta.ArtDemandHead.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的ArtDemandHead
func (self *ArtDemandHeadDAOImplement) DeleteOne(artId string, demandId string) error {
	_, err := self.session.Table(meta.ArtDemandHead.TableName).ID(core.PK{self.plantNr, artId, demandId}).Delete(meta.ArtDemandHead.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的ArtDemandHead
func (self *ArtDemandHeadDAOImplement) SelectOne(artId string, demandId string) (*model.ArtDemandHead, error) {
	var data model.ArtDemandHead
	ok, err := self.session.Table(meta.ArtDemandHead.TableName).ID(core.PK{self.plantNr, artId, demandId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改ArtDemandHead
func (self *ArtDemandHeadDAOImplement) UpdateOne(entity *model.ArtDemandHead) error {
	_, err := self.session.Table(meta.ArtDemandHead.TableName).Cols(meta.ArtDemandHead_DemandType.ColumnName, meta.ArtDemandHead_DemandYear.ColumnName, meta.ArtDemandHead_DemandMonth.ColumnName, meta.ArtDemandHead_DemandWeek.ColumnName, meta.ArtDemandHead_DemandDate.ColumnName, meta.ArtDemandHead_DemandHour.ColumnName, meta.ArtDemandHead_DemandTime.ColumnName, meta.ArtDemandHead_DemandQty.ColumnName, meta.ArtDemandHead_QtyUomId.ColumnName, meta.ArtDemandHead_Status.ColumnName, meta.ArtDemandHead_DemandSendTime.ColumnName, meta.ArtDemandHead_DemandRecieveTime.ColumnName, meta.ArtDemandHead_DemandConfirmTime.ColumnName, meta.ArtDemandHead_DemandCloseTime.ColumnName, meta.ArtDemandHead_DemandDeliveredQty.ColumnName, meta.ArtDemandHead_DemandCtrlPara1.ColumnName, meta.ArtDemandHead_DemandCtrlPara2.ColumnName, meta.ArtDemandHead_DemandCtrlPara3.ColumnName, meta.ArtDemandHead_DemandCtrlPara4.ColumnName, meta.ArtDemandHead_DemandCtrlTime1.ColumnName, meta.ArtDemandHead_DemandCtrlTime2.ColumnName, meta.ArtDemandHead_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查ArtDemandHead
func (self *ArtDemandHeadDAOImplement) checkArtDemandHeadRecords(records *[]model.ArtDemandHead) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询ArtDemandHead
func (self *ArtDemandHeadDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtDemandHead, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.ArtDemandHead, 0, 10)
	session := self.session.Table(meta.ArtDemandHead.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询ArtDemandHead并分页
func (self *ArtDemandHeadDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.ArtDemandHead.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.ArtDemandHead.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ArtDemandHead, 0, 10)
	err = self.session.Table(meta.ArtDemandHead.TableName).SQL("select * from LOG_ArtDemandHead where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
