package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"xorm.io/core"
)

type PackOrderDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewPackOrderDAOImplement(session *xorm.Session, plantNr int, userid string) *PackOrderDAOImplement {
	return &PackOrderDAOImplement{session, plantNr, userid}
}

//插入PackOrder
func (self *PackOrderDAOImplement) InsertOne(entity *model.PackOrder) error {
	_, err := self.session.Table(meta.PackOrder.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的PackOrder
func (self *PackOrderDAOImplement) DeleteOne(packOrderId string) error {
	_, err := self.session.Table(meta.PackOrder.TableName).ID(core.PK{self.plantNr, packOrderId}).Delete(meta.PackOrder.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的PackOrder
func (self *PackOrderDAOImplement) SelectOne(packOrderId string) (*model.PackOrder, error) {
	var data model.PackOrder
	ok, err := self.session.Table(meta.PackOrder.TableName).ID(core.PK{self.plantNr, packOrderId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改PackOrder
func (self *PackOrderDAOImplement) UpdateOne(entity *model.PackOrder) error {
	_, err := self.session.Table(meta.PackOrder.TableName).Cols(meta.PackOrder_OrderInfo.ColumnName, meta.PackOrder_PackTemplateId.ColumnName, meta.PackOrder_PackTypeId.ColumnName, meta.PackOrder_TerminalId.ColumnName, meta.PackOrder_WorkplaceId.ColumnName, meta.PackOrder_PersonNr.ColumnName, meta.PackOrder_ShiftId.ColumnName, meta.PackOrder_MaterialId.ColumnName, meta.PackOrder_Status.ColumnName, meta.PackOrder_ShortPack.ColumnName, meta.PackOrder_ShortBy.ColumnName, meta.PackOrder_ShortTime.ColumnName, meta.PackOrder_ShipStatus.ColumnName, meta.PackOrder_PlanQty.ColumnName, meta.PackOrder_ActQty.ColumnName, meta.PackOrder_OpenTime.ColumnName, meta.PackOrder_CloseTime.ColumnName, meta.PackOrder_BackFlushStatus.ColumnName, meta.PackOrder_BackFlushTime.ColumnName, meta.PackOrder_BoxSid.ColumnName, meta.PackOrder_SyncSid.ColumnName, meta.PackOrder_PKOCustC1.ColumnName, meta.PackOrder_PKOCustC2.ColumnName, meta.PackOrder_PKOCustI1.ColumnName, meta.PackOrder_PKOCustI2.ColumnName, meta.PackOrder_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查PackOrder
func (self *PackOrderDAOImplement) checkPackOrderRecords(records *[]model.PackOrder) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询PackOrder
func (self *PackOrderDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.PackOrder, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.PackOrder, 0, 10)
	session := self.session.Table(meta.PackOrder.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询PackOrder并分页
func (self *PackOrderDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.PackOrder.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.PackOrder.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.PackOrder, 0, 10)
	err = self.session.Table(meta.PackOrder.TableName).SQL("select * from LOG_PackOrder where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
