package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"xorm.io/core"
)

type PackOrderItemlstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewPackOrderItemlstDAOImplement(session *xorm.Session, plantNr int, userid string) *PackOrderItemlstDAOImplement {
	return &PackOrderItemlstDAOImplement{session, plantNr, userid}
}

//插入PackOrderItemlst
func (self *PackOrderItemlstDAOImplement) InsertOne(entity *model.PackOrderItemlst) error {
	_, err := self.session.Table(meta.PackOrderItemlst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的PackOrderItemlst
func (self *PackOrderItemlstDAOImplement) DeleteOne(packOrderId string, pos int) error {
	_, err := self.session.Table(meta.PackOrderItemlst.TableName).ID(core.PK{self.plantNr, packOrderId, pos}).Delete(meta.PackOrderItemlst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的PackOrderItemlst
func (self *PackOrderItemlstDAOImplement) SelectOne(packOrderId string, pos int) (*model.PackOrderItemlst, error) {
	var data model.PackOrderItemlst
	ok, err := self.session.Table(meta.PackOrderItemlst.TableName).ID(core.PK{self.plantNr, packOrderId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改PackOrderItemlst
func (self *PackOrderItemlstDAOImplement) UpdateOne(entity *model.PackOrderItemlst) error {
	_, err := self.session.Table(meta.PackOrderItemlst.TableName).Cols(meta.PackOrderItemlst_PosCode.ColumnName, meta.PackOrderItemlst_MaterialId.ColumnName, meta.PackOrderItemlst_SerialOrderId.ColumnName, meta.PackOrderItemlst_PlanQty.ColumnName, meta.PackOrderItemlst_ActQty.ColumnName, meta.PackOrderItemlst_Status.ColumnName, meta.PackOrderItemlst_Seq.ColumnName, meta.PackOrderItemlst_PKOICustC1.ColumnName, meta.PackOrderItemlst_PKOICustC2.ColumnName, meta.PackOrderItemlst_PKOICustI1.ColumnName, meta.PackOrderItemlst_PKOICustI2.ColumnName, meta.PackOrderItemlst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查PackOrderItemlst
func (self *PackOrderItemlstDAOImplement) checkPackOrderItemlstRecords(records *[]model.PackOrderItemlst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询PackOrderItemlst
func (self *PackOrderItemlstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.PackOrderItemlst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.PackOrderItemlst, 0, 10)
	session := self.session.Table(meta.PackOrderItemlst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询PackOrderItemlst并分页
func (self *PackOrderItemlstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.PackOrderItemlst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.PackOrderItemlst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.PackOrderItemlst, 0, 10)
	err = self.session.Table(meta.PackOrderItemlst.TableName).SQL("select * from LOG_PackOrderItemlst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
