package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"xorm.io/core"
)

type PackTemplateDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewPackTemplateDAOImplement(session *xorm.Session, plantNr int, userid string) *PackTemplateDAOImplement {
	return &PackTemplateDAOImplement{session, plantNr, userid}
}

//插入PackTemplate
func (self *PackTemplateDAOImplement) InsertOne(entity *model.PackTemplate) error {
	_, err := self.session.Table(meta.PackTemplate.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的PackTemplate
func (self *PackTemplateDAOImplement) DeleteOne(packTemplateId string) error {
	_, err := self.session.Table(meta.PackTemplate.TableName).ID(core.PK{self.plantNr, packTemplateId}).Delete(meta.PackTemplate.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的PackTemplate
func (self *PackTemplateDAOImplement) SelectOne(packTemplateId string) (*model.PackTemplate, error) {
	var data model.PackTemplate
	ok, err := self.session.Table(meta.PackTemplate.TableName).ID(core.PK{self.plantNr, packTemplateId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改PackTemplate
func (self *PackTemplateDAOImplement) UpdateOne(entity *model.PackTemplate) error {
	_, err := self.session.Table(meta.PackTemplate.TableName).Cols(meta.PackTemplate_Descr.ColumnName, meta.PackTemplate_ActiveToggle.ColumnName, meta.PackTemplate_PackTypeId.ColumnName, meta.PackTemplate_PrinterId.ColumnName, meta.PackTemplate_TemplateFile.ColumnName, meta.PackTemplate_PrintQty.ColumnName, meta.PackTemplate_PackOrderSn.ColumnName, meta.PackTemplate_BoxSn.ColumnName, meta.PackTemplate_SyncToggle.ColumnName, meta.PackTemplate_SyncSn.ColumnName, meta.PackTemplate_TwoDSheet.ColumnName, meta.PackTemplate_FullFillToggle.ColumnName, meta.PackTemplate_MaterialId.ColumnName, meta.PackTemplate_PlanQty.ColumnName, meta.PackTemplate_PKTMPCustC1.ColumnName, meta.PackTemplate_PKTMPCustC2.ColumnName, meta.PackTemplate_PKTMPCustI1.ColumnName, meta.PackTemplate_PKTMPCustI2.ColumnName, meta.PackTemplate_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查PackTemplate
func (self *PackTemplateDAOImplement) checkPackTemplateRecords(records *[]model.PackTemplate) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询PackTemplate
func (self *PackTemplateDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.PackTemplate, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.PackTemplate, 0, 10)
	session := self.session.Table(meta.PackTemplate.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询PackTemplate并分页
func (self *PackTemplateDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.PackTemplate.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.PackTemplate.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.PackTemplate, 0, 10)
	err = self.session.Table(meta.PackTemplate.TableName).SQL("select * from LOG_PackTemplate where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
