package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"xorm.io/core"
)

type PackTypeDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewPackTypeDAOImplement(session *xorm.Session, plantNr int, userid string) *PackTypeDAOImplement {
	return &PackTypeDAOImplement{session, plantNr, userid}
}

//插入PackType
func (self *PackTypeDAOImplement) InsertOne(entity *model.PackType) error {
	_, err := self.session.Table(meta.PackType.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的PackType
func (self *PackTypeDAOImplement) DeleteOne(packTypeId string) error {
	_, err := self.session.Table(meta.PackType.TableName).ID(core.PK{self.plantNr, packTypeId}).Delete(meta.PackType.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的PackType
func (self *PackTypeDAOImplement) SelectOne(packTypeId string) (*model.PackType, error) {
	var data model.PackType
	ok, err := self.session.Table(meta.PackType.TableName).ID(core.PK{self.plantNr, packTypeId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改PackType
func (self *PackTypeDAOImplement) UpdateOne(entity *model.PackType) error {
	_, err := self.session.Table(meta.PackType.TableName).Cols(meta.PackType_Descr.ColumnName, meta.PackType_SortWay.ColumnName, meta.PackType_VerifySlotToggle.ColumnName, meta.PackType_VerifyRule.ColumnName, meta.PackType_Length.ColumnName, meta.PackType_Width.ColumnName, meta.PackType_Height.ColumnName, meta.PackType_SizeUom.ColumnName, meta.PackType_Weight.ColumnName, meta.PackType_WeightUom.ColumnName, meta.PackType_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查PackType
func (self *PackTypeDAOImplement) checkPackTypeRecords(records *[]model.PackType) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询PackType
func (self *PackTypeDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.PackType, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.PackType, 0, 10)
	session := self.session.Table(meta.PackType.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询PackType并分页
func (self *PackTypeDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.PackType.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.PackType.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.PackType, 0, 10)
	err = self.session.Table(meta.PackType.TableName).SQL("select * from LOG_PackType where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
