package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"xorm.io/core"
)

type VendorDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewVendorDAOImplement(session *xorm.Session, plantNr int, userid string) *VendorDAOImplement {
	return &VendorDAOImplement{session, plantNr, userid}
}

//插入Vendor
func (self *VendorDAOImplement) InsertOne(entity *model.Vendor) error {
	_, err := self.session.Table(meta.Vendor.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的Vendor
func (self *VendorDAOImplement) DeleteOne(vendorId string) error {
	_, err := self.session.Table(meta.Vendor.TableName).ID(core.PK{self.plantNr, vendorId}).Delete(meta.Vendor.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的Vendor
func (self *VendorDAOImplement) SelectOne(vendorId string) (*model.Vendor, error) {
	var data model.Vendor
	ok, err := self.session.Table(meta.Vendor.TableName).ID(core.PK{self.plantNr, vendorId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改Vendor
func (self *VendorDAOImplement) UpdateOne(entity *model.Vendor) error {
	_, err := self.session.Table(meta.Vendor.TableName).Cols(meta.Vendor_Descr.ColumnName, meta.Vendor_Address.ColumnName, meta.Vendor_VendorNr.ColumnName, meta.Vendor_Name.ColumnName, meta.Vendor_Name1.ColumnName, meta.Vendor_Name2.ColumnName, meta.Vendor_ValidStartDate.ColumnName, meta.Vendor_Country.ColumnName, meta.Vendor_City.ColumnName, meta.Vendor_District.ColumnName, meta.Vendor_Street.ColumnName, meta.Vendor_Location.ColumnName, meta.Vendor_PostCode.ColumnName, meta.Vendor_Phone.ColumnName, meta.Vendor_Mobile.ColumnName, meta.Vendor_Fax.ColumnName, meta.Vendor_Email1.ColumnName, meta.Vendor_Email2.ColumnName, meta.Vendor_ContactPerson.ColumnName, meta.Vendor_PersonTitle.ColumnName, meta.Vendor_ContactAddress.ColumnName, meta.Vendor_Account.ColumnName, meta.Vendor_TaxRate.ColumnName, meta.Vendor_Status.ColumnName, meta.Vendor_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查Vendor
func (self *VendorDAOImplement) checkVendorRecords(records *[]model.Vendor) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询Vendor
func (self *VendorDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.Vendor, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.Vendor, 0, 10)
	session := self.session.Table(meta.Vendor.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询Vendor并分页
func (self *VendorDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.Vendor.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.Vendor.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.Vendor, 0, 10)
	err = self.session.Table(meta.Vendor.TableName).SQL("select * from LOG_Vendor where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
