package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"xorm.io/core"
)

type VendorArtLstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewVendorArtLstDAOImplement(session *xorm.Session, plantNr int, userid string) *VendorArtLstDAOImplement {
	return &VendorArtLstDAOImplement{session, plantNr, userid}
}

//插入VendorArtLst
func (self *VendorArtLstDAOImplement) InsertOne(entity *model.VendorArtLst) error {
	_, err := self.session.Table(meta.VendorArtLst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的VendorArtLst
func (self *VendorArtLstDAOImplement) DeleteOne(artId string) error {
	_, err := self.session.Table(meta.VendorArtLst.TableName).ID(core.PK{self.plantNr, artId}).Delete(meta.VendorArtLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的VendorArtLst
func (self *VendorArtLstDAOImplement) SelectOne(artId string) (*model.VendorArtLst, error) {
	var data model.VendorArtLst
	ok, err := self.session.Table(meta.VendorArtLst.TableName).ID(core.PK{self.plantNr, artId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改VendorArtLst
func (self *VendorArtLstDAOImplement) UpdateOne(entity *model.VendorArtLst) error {
	_, err := self.session.Table(meta.VendorArtLst.TableName).Cols(meta.VendorArtLst_VendorId.ColumnName, meta.VendorArtLst_Pos.ColumnName, meta.VendorArtLst_CtrlLevel.ColumnName, meta.VendorArtLst_CtrlPara1.ColumnName, meta.VendorArtLst_CtrlPara2.ColumnName, meta.VendorArtLst_CtrlPara3.ColumnName, meta.VendorArtLst_CtrlPara4.ColumnName, meta.VendorArtLst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查VendorArtLst
func (self *VendorArtLstDAOImplement) checkVendorArtLstRecords(records *[]model.VendorArtLst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询VendorArtLst
func (self *VendorArtLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.VendorArtLst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.VendorArtLst, 0, 10)
	session := self.session.Table(meta.VendorArtLst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询VendorArtLst并分页
func (self *VendorArtLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.VendorArtLst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.VendorArtLst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.VendorArtLst, 0, 10)
	err = self.session.Table(meta.VendorArtLst.TableName).SQL("select * from LOG_VendorArtLst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
