package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"xorm.io/core"
)

type VendorUserLstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewVendorUserLstDAOImplement(session *xorm.Session, plantNr int, userid string) *VendorUserLstDAOImplement {
	return &VendorUserLstDAOImplement{session, plantNr, userid}
}

//插入VendorUserLst
func (self *VendorUserLstDAOImplement) InsertOne(entity *model.VendorUserLst) error {
	_, err := self.session.Table(meta.VendorUserLst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的VendorUserLst
func (self *VendorUserLstDAOImplement) DeleteOne(vendorId string) error {
	_, err := self.session.Table(meta.VendorUserLst.TableName).ID(core.PK{self.plantNr, vendorId}).Delete(meta.VendorUserLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的VendorUserLst
func (self *VendorUserLstDAOImplement) SelectOne(vendorId string) (*model.VendorUserLst, error) {
	var data model.VendorUserLst
	ok, err := self.session.Table(meta.VendorUserLst.TableName).ID(core.PK{self.plantNr, vendorId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改VendorUserLst
func (self *VendorUserLstDAOImplement) UpdateOne(entity *model.VendorUserLst) error {
	_, err := self.session.Table(meta.VendorUserLst.TableName).Cols(meta.VendorUserLst_UserId.ColumnName, meta.VendorUserLst_Pos.ColumnName, meta.VendorUserLst_CtrlLevel.ColumnName, meta.VendorUserLst_CtrlPara1.ColumnName, meta.VendorUserLst_CtrlPara2.ColumnName, meta.VendorUserLst_CtrlPara3.ColumnName, meta.VendorUserLst_CtrlPara4.ColumnName, meta.VendorUserLst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查VendorUserLst
func (self *VendorUserLstDAOImplement) checkVendorUserLstRecords(records *[]model.VendorUserLst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询VendorUserLst
func (self *VendorUserLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.VendorUserLst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.VendorUserLst, 0, 10)
	session := self.session.Table(meta.VendorUserLst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询VendorUserLst并分页
func (self *VendorUserLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.VendorUserLst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.VendorUserLst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.VendorUserLst, 0, 10)
	err = self.session.Table(meta.VendorUserLst.TableName).SQL("select * from LOG_VendorUserLst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
