package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/ods"
	model "leit.com/LAPP_GAAS_GFrame/models/ods"
	"xorm.io/core"
)

type ArtRouteOdsLstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewArtRouteOdsLstDAOImplement(session *xorm.Session, plantNr int, userid string) *ArtRouteOdsLstDAOImplement {
	return &ArtRouteOdsLstDAOImplement{session, plantNr, userid}
}

//插入ArtRouteOdsLst
func (self *ArtRouteOdsLstDAOImplement) InsertOne(entity *model.ArtRouteOdsLst) error {
	_, err := self.session.Table(meta.ArtRouteOdsLst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的ArtRouteOdsLst
func (self *ArtRouteOdsLstDAOImplement) DeleteOne(artId string, operationNr int, pos int) error {
	_, err := self.session.Table(meta.ArtRouteOdsLst.TableName).ID(core.PK{self.plantNr, artId, operationNr, pos}).Delete(meta.ArtRouteOdsLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的ArtRouteOdsLst
func (self *ArtRouteOdsLstDAOImplement) SelectOne(artId string, operationNr int, pos int) (*model.ArtRouteOdsLst, error) {
	var data model.ArtRouteOdsLst
	ok, err := self.session.Table(meta.ArtRouteOdsLst.TableName).ID(core.PK{self.plantNr, artId, operationNr, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改ArtRouteOdsLst
func (self *ArtRouteOdsLstDAOImplement) UpdateOne(entity *model.ArtRouteOdsLst) error {
	_, err := self.session.Table(meta.ArtRouteOdsLst.TableName).Cols(meta.ArtRouteOdsLst_WorkPlaceId.ColumnName, meta.ArtRouteOdsLst_Descr.ColumnName, meta.ArtRouteOdsLst_OdsId.ColumnName, meta.ArtRouteOdsLst_OdsTypeId.ColumnName, meta.ArtRouteOdsLst_OdsContentIdx.ColumnName, meta.ArtRouteOdsLst_CtrlPara1.ColumnName, meta.ArtRouteOdsLst_CtrlPara2.ColumnName, meta.ArtRouteOdsLst_CtrlPara3.ColumnName, meta.ArtRouteOdsLst_CtrlPara4.ColumnName, meta.ArtRouteOdsLst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查ArtRouteOdsLst
func (self *ArtRouteOdsLstDAOImplement) checkArtRouteOdsLstRecords(records *[]model.ArtRouteOdsLst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询ArtRouteOdsLst
func (self *ArtRouteOdsLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtRouteOdsLst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.ArtRouteOdsLst, 0, 10)
	session := self.session.Table(meta.ArtRouteOdsLst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询ArtRouteOdsLst并分页
func (self *ArtRouteOdsLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.ArtRouteOdsLst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.ArtRouteOdsLst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ArtRouteOdsLst, 0, 10)
	err = self.session.Table(meta.ArtRouteOdsLst.TableName).SQL("select * from ODS_ArtRouteOdsLst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
