package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/ods"
	model "leit.com/LAPP_GAAS_GFrame/models/ods"
	"xorm.io/core"
)

type OdsHeadDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewOdsHeadDAOImplement(session *xorm.Session, plantNr int, userid string) *OdsHeadDAOImplement {
	return &OdsHeadDAOImplement{session, plantNr, userid}
}

//插入OdsHead
func (self *OdsHeadDAOImplement) InsertOne(entity *model.OdsHead) error {
	_, err := self.session.Table(meta.OdsHead.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的OdsHead
func (self *OdsHeadDAOImplement) DeleteOne(odsId string) error {
	_, err := self.session.Table(meta.OdsHead.TableName).ID(core.PK{self.plantNr, odsId}).Delete(meta.OdsHead.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的OdsHead
func (self *OdsHeadDAOImplement) SelectOne(odsId string) (*model.OdsHead, error) {
	var data model.OdsHead
	ok, err := self.session.Table(meta.OdsHead.TableName).ID(core.PK{self.plantNr, odsId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改OdsHead
func (self *OdsHeadDAOImplement) UpdateOne(entity *model.OdsHead) error {
	_, err := self.session.Table(meta.OdsHead.TableName).Cols(meta.OdsHead_Descr.ColumnName, meta.OdsHead_OdsTypeId.ColumnName, meta.OdsHead_OdsContentIdx.ColumnName, meta.OdsHead_CtrlPara1.ColumnName, meta.OdsHead_CtrlPara2.ColumnName, meta.OdsHead_CtrlPara3.ColumnName, meta.OdsHead_CtrlPara4.ColumnName, meta.OdsHead_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查OdsHead
func (self *OdsHeadDAOImplement) checkOdsHeadRecords(records *[]model.OdsHead) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询OdsHead
func (self *OdsHeadDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.OdsHead, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.OdsHead, 0, 10)
	session := self.session.Table(meta.OdsHead.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询OdsHead并分页
func (self *OdsHeadDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.OdsHead.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.OdsHead.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.OdsHead, 0, 10)
	err = self.session.Table(meta.OdsHead.TableName).SQL("select * from ODS_OdsHead where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
