package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/ods"
	model "leit.com/LAPP_GAAS_GFrame/models/ods"
	"xorm.io/core"
)

type OdsStepLstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewOdsStepLstDAOImplement(session *xorm.Session, plantNr int, userid string) *OdsStepLstDAOImplement {
	return &OdsStepLstDAOImplement{session, plantNr, userid}
}

//插入OdsStepLst
func (self *OdsStepLstDAOImplement) InsertOne(entity *model.OdsStepLst) error {
	_, err := self.session.Table(meta.OdsStepLst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的OdsStepLst
func (self *OdsStepLstDAOImplement) DeleteOne(odsId string, pos int) error {
	_, err := self.session.Table(meta.OdsStepLst.TableName).ID(core.PK{self.plantNr, odsId, pos}).Delete(meta.OdsStepLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的OdsStepLst
func (self *OdsStepLstDAOImplement) SelectOne(odsId string, pos int) (*model.OdsStepLst, error) {
	var data model.OdsStepLst
	ok, err := self.session.Table(meta.OdsStepLst.TableName).ID(core.PK{self.plantNr, odsId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改OdsStepLst
func (self *OdsStepLstDAOImplement) UpdateOne(entity *model.OdsStepLst) error {
	_, err := self.session.Table(meta.OdsStepLst.TableName).Cols(meta.OdsStepLst_Descr.ColumnName, meta.OdsStepLst_OdsTypeId.ColumnName, meta.OdsStepLst_OdsContentIdx.ColumnName, meta.OdsStepLst_CtrlPara1.ColumnName, meta.OdsStepLst_CtrlPara2.ColumnName, meta.OdsStepLst_CtrlPara3.ColumnName, meta.OdsStepLst_CtrlPara4.ColumnName, meta.OdsStepLst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查OdsStepLst
func (self *OdsStepLstDAOImplement) checkOdsStepLstRecords(records *[]model.OdsStepLst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询OdsStepLst
func (self *OdsStepLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.OdsStepLst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.OdsStepLst, 0, 10)
	session := self.session.Table(meta.OdsStepLst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询OdsStepLst并分页
func (self *OdsStepLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.OdsStepLst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.OdsStepLst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.OdsStepLst, 0, 10)
	err = self.session.Table(meta.OdsStepLst.TableName).SQL("select * from ODS_OdsStepLst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
