package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/ods"
	model "leit.com/LAPP_GAAS_GFrame/models/ods"
	"xorm.io/core"
)

type OdsTypeDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewOdsTypeDAOImplement(session *xorm.Session, plantNr int, userid string) *OdsTypeDAOImplement {
	return &OdsTypeDAOImplement{session, plantNr, userid}
}

//插入OdsType
func (self *OdsTypeDAOImplement) InsertOne(entity *model.OdsType) error {
	_, err := self.session.Table(meta.OdsType.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的OdsType
func (self *OdsTypeDAOImplement) DeleteOne(odsTypeId string) error {
	_, err := self.session.Table(meta.OdsType.TableName).ID(core.PK{self.plantNr, odsTypeId}).Delete(meta.OdsType.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的OdsType
func (self *OdsTypeDAOImplement) SelectOne(odsTypeId string) (*model.OdsType, error) {
	var data model.OdsType
	ok, err := self.session.Table(meta.OdsType.TableName).ID(core.PK{self.plantNr, odsTypeId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改OdsType
func (self *OdsTypeDAOImplement) UpdateOne(entity *model.OdsType) error {
	_, err := self.session.Table(meta.OdsType.TableName).Cols(meta.OdsType_Descr.ColumnName, meta.OdsType_Width.ColumnName, meta.OdsType_Height.ColumnName, meta.OdsType_Player.ColumnName, meta.OdsType_CtrlPara1.ColumnName, meta.OdsType_CtrlPara2.ColumnName, meta.OdsType_CtrlPara3.ColumnName, meta.OdsType_CtrlPara4.ColumnName, meta.OdsType_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查OdsType
func (self *OdsTypeDAOImplement) checkOdsTypeRecords(records *[]model.OdsType) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询OdsType
func (self *OdsTypeDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.OdsType, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.OdsType, 0, 10)
	session := self.session.Table(meta.OdsType.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询OdsType并分页
func (self *OdsTypeDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.OdsType.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.OdsType.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.OdsType, 0, 10)
	err = self.session.Table(meta.OdsType.TableName).SQL("select * from ODS_OdsType where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
