package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/om"
	model "leit.com/LAPP_GAAS_GFrame/models/om"
	"xorm.io/core"
)

type ProdOrderDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewProdOrderDAOImplement(session *xorm.Session, plantNr int, userid string) *ProdOrderDAOImplement {
	return &ProdOrderDAOImplement{session, plantNr, userid}
}

//插入ProdOrder
func (self *ProdOrderDAOImplement) InsertOne(entity *model.ProdOrder) error {
	_, err := self.session.Table(meta.ProdOrder.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的ProdOrder
func (self *ProdOrderDAOImplement) DeleteOne(prodOrderId string) error {
	_, err := self.session.Table(meta.ProdOrder.TableName).ID(core.PK{self.plantNr, prodOrderId}).Delete(meta.ProdOrder.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的ProdOrder
func (self *ProdOrderDAOImplement) SelectOne(prodOrderId string) (*model.ProdOrder, error) {
	var data model.ProdOrder
	ok, err := self.session.Table(meta.ProdOrder.TableName).ID(core.PK{self.plantNr, prodOrderId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改ProdOrder
func (self *ProdOrderDAOImplement) UpdateOne(entity *model.ProdOrder) error {
	_, err := self.session.Table(meta.ProdOrder.TableName).Cols(meta.ProdOrder_ArtId.ColumnName, meta.ProdOrder_CustArtId.ColumnName, meta.ProdOrder_RouteTemplateId.ColumnName, meta.ProdOrder_OrderType.ColumnName, meta.ProdOrder_OrderInfo.ColumnName, meta.ProdOrder_CustOrderId.ColumnName, meta.ProdOrder_ErpOrderId.ColumnName, meta.ProdOrder_ParentOrderId.ColumnName, meta.ProdOrder_Priority.ColumnName, meta.ProdOrder_Status.ColumnName, meta.ProdOrder_PlanResourceGroupId.ColumnName, meta.ProdOrder_PlanResourceId.ColumnName, meta.ProdOrder_UsedResourceId.ColumnName, meta.ProdOrder_PlanQty.ColumnName, meta.ProdOrder_QtyUomId.ColumnName, meta.ProdOrder_RatePerHourToggle.ColumnName, meta.ProdOrder_TimePerItemToggle.ColumnName, meta.ProdOrder_TimePerBatchToggle.ColumnName, meta.ProdOrder_BatchTimeFieldToggle.ColumnName, meta.ProdOrder_OpTimePerItem.ColumnName, meta.ProdOrder_BatchTime.ColumnName, meta.ProdOrder_QuantityPerHour.ColumnName, meta.ProdOrder_MidBatchQuantity.ColumnName, meta.ProdOrder_MidBatchTime.ColumnName, meta.ProdOrder_BatchingMethod.ColumnName, meta.ProdOrder_PlanStartDate.ColumnName, meta.ProdOrder_PlanEndDate.ColumnName, meta.ProdOrder_PlanStartTime.ColumnName, meta.ProdOrder_PlanEndTime.ColumnName, meta.ProdOrder_ActStartTime.ColumnName, meta.ProdOrder_ActEndTime.ColumnName, meta.ProdOrder_ProjectId.ColumnName, meta.ProdOrder_CustomerId.ColumnName, meta.ProdOrder_CustomerName.ColumnName, meta.ProdOrder_BackflushStatus.ColumnName, meta.ProdOrder_BackflushTime.ColumnName, meta.ProdOrder_PackStatus.ColumnName, meta.ProdOrder_PackTime.ColumnName, meta.ProdOrder_ShipStatus.ColumnName, meta.ProdOrder_ShipTime.ColumnName, meta.ProdOrder_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查ProdOrder
func (self *ProdOrderDAOImplement) checkProdOrderRecords(records *[]model.ProdOrder) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询ProdOrder
func (self *ProdOrderDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ProdOrder, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.ProdOrder, 0, 10)
	session := self.session.Table(meta.ProdOrder.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询ProdOrder并分页
func (self *ProdOrderDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.ProdOrder.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.ProdOrder.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ProdOrder, 0, 10)
	err = self.session.Table(meta.ProdOrder.TableName).SQL("select * from OM_ProdOrder where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
