package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/om"
	model "leit.com/LAPP_GAAS_GFrame/models/om"
	"xorm.io/core"
)

type ProdOrderQtyDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewProdOrderQtyDAOImplement(session *xorm.Session, plantNr int, userid string) *ProdOrderQtyDAOImplement {
	return &ProdOrderQtyDAOImplement{session, plantNr, userid}
}

//插入ProdOrderQty
func (self *ProdOrderQtyDAOImplement) InsertOne(entity *model.ProdOrderQty) error {
	_, err := self.session.Table(meta.ProdOrderQty.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的ProdOrderQty
func (self *ProdOrderQtyDAOImplement) DeleteOne(prodOrderId string) error {
	_, err := self.session.Table(meta.ProdOrderQty.TableName).ID(core.PK{self.plantNr, prodOrderId}).Delete(meta.ProdOrderQty.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的ProdOrderQty
func (self *ProdOrderQtyDAOImplement) SelectOne(prodOrderId string) (*model.ProdOrderQty, error) {
	var data model.ProdOrderQty
	ok, err := self.session.Table(meta.ProdOrderQty.TableName).ID(core.PK{self.plantNr, prodOrderId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改ProdOrderQty
func (self *ProdOrderQtyDAOImplement) UpdateOne(entity *model.ProdOrderQty) error {
	_, err := self.session.Table(meta.ProdOrderQty.TableName).Cols(meta.ProdOrderQty_ActQty.ColumnName, meta.ProdOrderQty_ActGoodQty.ColumnName, meta.ProdOrderQty_ActScrapQty.ColumnName, meta.ProdOrderQty_ActReworkQty.ColumnName, meta.ProdOrderQty_ActQty1.ColumnName, meta.ProdOrderQty_ActQty2.ColumnName, meta.ProdOrderQty_ActQty3.ColumnName, meta.ProdOrderQty_ActQty4.ColumnName, meta.ProdOrderQty_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查ProdOrderQty
func (self *ProdOrderQtyDAOImplement) checkProdOrderQtyRecords(records *[]model.ProdOrderQty) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询ProdOrderQty
func (self *ProdOrderQtyDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ProdOrderQty, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.ProdOrderQty, 0, 10)
	session := self.session.Table(meta.ProdOrderQty.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询ProdOrderQty并分页
func (self *ProdOrderQtyDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.ProdOrderQty.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.ProdOrderQty.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ProdOrderQty, 0, 10)
	err = self.session.Table(meta.ProdOrderQty.TableName).SQL("select * from OM_ProdOrderQty where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
