package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/om"
	model "leit.com/LAPP_GAAS_GFrame/models/om"
	"xorm.io/core"
)

type ProdOrderQtyRecLstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewProdOrderQtyRecLstDAOImplement(session *xorm.Session, plantNr int, userid string) *ProdOrderQtyRecLstDAOImplement {
	return &ProdOrderQtyRecLstDAOImplement{session, plantNr, userid}
}

//插入ProdOrderQtyRecLst
func (self *ProdOrderQtyRecLstDAOImplement) InsertOne(entity *model.ProdOrderQtyRecLst) error {
	_, err := self.session.Table(meta.ProdOrderQtyRecLst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的ProdOrderQtyRecLst
func (self *ProdOrderQtyRecLstDAOImplement) DeleteOne(prodOrderId string, pos int) error {
	_, err := self.session.Table(meta.ProdOrderQtyRecLst.TableName).ID(core.PK{self.plantNr, prodOrderId, pos}).Delete(meta.ProdOrderQtyRecLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的ProdOrderQtyRecLst
func (self *ProdOrderQtyRecLstDAOImplement) SelectOne(prodOrderId string, pos int) (*model.ProdOrderQtyRecLst, error) {
	var data model.ProdOrderQtyRecLst
	ok, err := self.session.Table(meta.ProdOrderQtyRecLst.TableName).ID(core.PK{self.plantNr, prodOrderId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改ProdOrderQtyRecLst
func (self *ProdOrderQtyRecLstDAOImplement) UpdateOne(entity *model.ProdOrderQtyRecLst) error {
	_, err := self.session.Table(meta.ProdOrderQtyRecLst.TableName).Cols(meta.ProdOrderQtyRecLst_ActQty.ColumnName, meta.ProdOrderQtyRecLst_OrderQtyType.ColumnName, meta.ProdOrderQtyRecLst_RecordTime.ColumnName, meta.ProdOrderQtyRecLst_TriggerEvent.ColumnName, meta.ProdOrderQtyRecLst_TriggerObjectId.ColumnName, meta.ProdOrderQtyRecLst_TriggerSubObjectId.ColumnName, meta.ProdOrderQtyRecLst_OutputEvent.ColumnName, meta.ProdOrderQtyRecLst_OutputEventMessageId.ColumnName, meta.ProdOrderQtyRecLst_OutputObjectId.ColumnName, meta.ProdOrderQtyRecLst_OutputSubObjectId.ColumnName, meta.ProdOrderQtyRecLst_Remark1.ColumnName, meta.ProdOrderQtyRecLst_Remark2.ColumnName, meta.ProdOrderQtyRecLst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查ProdOrderQtyRecLst
func (self *ProdOrderQtyRecLstDAOImplement) checkProdOrderQtyRecLstRecords(records *[]model.ProdOrderQtyRecLst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询ProdOrderQtyRecLst
func (self *ProdOrderQtyRecLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ProdOrderQtyRecLst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.ProdOrderQtyRecLst, 0, 10)
	session := self.session.Table(meta.ProdOrderQtyRecLst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询ProdOrderQtyRecLst并分页
func (self *ProdOrderQtyRecLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.ProdOrderQtyRecLst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.ProdOrderQtyRecLst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ProdOrderQtyRecLst, 0, 10)
	err = self.session.Table(meta.ProdOrderQtyRecLst.TableName).SQL("select * from OM_ProdOrderQtyRecLst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
