package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/om"
	model "leit.com/LAPP_GAAS_GFrame/models/om"
	"xorm.io/core"
)

type ProdOrderStatusDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewProdOrderStatusDAOImplement(session *xorm.Session, plantNr int, userid string) *ProdOrderStatusDAOImplement {
	return &ProdOrderStatusDAOImplement{session, plantNr, userid}
}

//插入ProdOrderStatus
func (self *ProdOrderStatusDAOImplement) InsertOne(entity *model.ProdOrderStatus) error {
	_, err := self.session.Table(meta.ProdOrderStatus.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的ProdOrderStatus
func (self *ProdOrderStatusDAOImplement) DeleteOne(prodOrderId string) error {
	_, err := self.session.Table(meta.ProdOrderStatus.TableName).ID(core.PK{self.plantNr, prodOrderId}).Delete(meta.ProdOrderStatus.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的ProdOrderStatus
func (self *ProdOrderStatusDAOImplement) SelectOne(prodOrderId string) (*model.ProdOrderStatus, error) {
	var data model.ProdOrderStatus
	ok, err := self.session.Table(meta.ProdOrderStatus.TableName).ID(core.PK{self.plantNr, prodOrderId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改ProdOrderStatus
func (self *ProdOrderStatusDAOImplement) UpdateOne(entity *model.ProdOrderStatus) error {
	_, err := self.session.Table(meta.ProdOrderStatus.TableName).Cols(meta.ProdOrderStatus_Status.ColumnName, meta.ProdOrderStatus_TriggerEvent.ColumnName, meta.ProdOrderStatus_TriggerObjectId.ColumnName, meta.ProdOrderStatus_TriggerSubObjectId.ColumnName, meta.ProdOrderStatus_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查ProdOrderStatus
func (self *ProdOrderStatusDAOImplement) checkProdOrderStatusRecords(records *[]model.ProdOrderStatus) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询ProdOrderStatus
func (self *ProdOrderStatusDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ProdOrderStatus, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.ProdOrderStatus, 0, 10)
	session := self.session.Table(meta.ProdOrderStatus.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询ProdOrderStatus并分页
func (self *ProdOrderStatusDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.ProdOrderStatus.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.ProdOrderStatus.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ProdOrderStatus, 0, 10)
	err = self.session.Table(meta.ProdOrderStatus.TableName).SQL("select * from OM_ProdOrderStatus where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
