package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"xorm.io/core"
)

type DefectGrpReasonLstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewDefectGrpReasonLstDAOImplement(session *xorm.Session, plantNr int, userid string) *DefectGrpReasonLstDAOImplement {
	return &DefectGrpReasonLstDAOImplement{session, plantNr, userid}
}

//插入DefectGrpReasonLst
func (self *DefectGrpReasonLstDAOImplement) InsertOne(entity *model.DefectGrpReasonLst) error {
	_, err := self.session.Table(meta.DefectGrpReasonLst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的DefectGrpReasonLst
func (self *DefectGrpReasonLstDAOImplement) DeleteOne(defectGrpId string, defectReasonId string) error {
	_, err := self.session.Table(meta.DefectGrpReasonLst.TableName).ID(core.PK{self.plantNr, defectGrpId, defectReasonId}).Delete(meta.DefectGrpReasonLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的DefectGrpReasonLst
func (self *DefectGrpReasonLstDAOImplement) SelectOne(defectGrpId string, defectReasonId string) (*model.DefectGrpReasonLst, error) {
	var data model.DefectGrpReasonLst
	ok, err := self.session.Table(meta.DefectGrpReasonLst.TableName).ID(core.PK{self.plantNr, defectGrpId, defectReasonId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改DefectGrpReasonLst
func (self *DefectGrpReasonLstDAOImplement) UpdateOne(entity *model.DefectGrpReasonLst) error {
	_, err := self.session.Table(meta.DefectGrpReasonLst.TableName).Cols(meta.DefectGrpReasonLst_Pos.ColumnName, meta.DefectGrpReasonLst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查DefectGrpReasonLst
func (self *DefectGrpReasonLstDAOImplement) checkDefectGrpReasonLstRecords(records *[]model.DefectGrpReasonLst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询DefectGrpReasonLst
func (self *DefectGrpReasonLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.DefectGrpReasonLst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.DefectGrpReasonLst, 0, 10)
	session := self.session.Table(meta.DefectGrpReasonLst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询DefectGrpReasonLst并分页
func (self *DefectGrpReasonLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.DefectGrpReasonLst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.DefectGrpReasonLst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.DefectGrpReasonLst, 0, 10)
	err = self.session.Table(meta.DefectGrpReasonLst.TableName).SQL("select * from QM_DefectGrpReasonLst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
