package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"xorm.io/core"
)

type DefectReasonDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewDefectReasonDAOImplement(session *xorm.Session, plantNr int, userid string) *DefectReasonDAOImplement {
	return &DefectReasonDAOImplement{session, plantNr, userid}
}

//插入DefectReason
func (self *DefectReasonDAOImplement) InsertOne(entity *model.DefectReason) error {
	_, err := self.session.Table(meta.DefectReason.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的DefectReason
func (self *DefectReasonDAOImplement) DeleteOne(defectReasonId string) error {
	_, err := self.session.Table(meta.DefectReason.TableName).ID(core.PK{self.plantNr, defectReasonId}).Delete(meta.DefectReason.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的DefectReason
func (self *DefectReasonDAOImplement) SelectOne(defectReasonId string) (*model.DefectReason, error) {
	var data model.DefectReason
	ok, err := self.session.Table(meta.DefectReason.TableName).ID(core.PK{self.plantNr, defectReasonId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改DefectReason
func (self *DefectReasonDAOImplement) UpdateOne(entity *model.DefectReason) error {
	_, err := self.session.Table(meta.DefectReason.TableName).Cols(meta.DefectReason_Descr.ColumnName, meta.DefectReason_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查DefectReason
func (self *DefectReasonDAOImplement) checkDefectReasonRecords(records *[]model.DefectReason) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询DefectReason
func (self *DefectReasonDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.DefectReason, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.DefectReason, 0, 10)
	session := self.session.Table(meta.DefectReason.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询DefectReason并分页
func (self *DefectReasonDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.DefectReason.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.DefectReason.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.DefectReason, 0, 10)
	err = self.session.Table(meta.DefectReason.TableName).SQL("select * from QM_DefectReason where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
