package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"xorm.io/core"
)

type DefectRecordDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewDefectRecordDAOImplement(session *xorm.Session, plantNr int, userid string) *DefectRecordDAOImplement {
	return &DefectRecordDAOImplement{session, plantNr, userid}
}

//插入DefectRecord
func (self *DefectRecordDAOImplement) InsertOne(entity *model.DefectRecord) error {
	_, err := self.session.Table(meta.DefectRecord.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的DefectRecord
func (self *DefectRecordDAOImplement) DeleteOne(recNr int) error {
	_, err := self.session.Table(meta.DefectRecord.TableName).ID(core.PK{self.plantNr, recNr}).Delete(meta.DefectRecord.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的DefectRecord
func (self *DefectRecordDAOImplement) SelectOne(recNr int) (*model.DefectRecord, error) {
	var data model.DefectRecord
	ok, err := self.session.Table(meta.DefectRecord.TableName).ID(core.PK{self.plantNr, recNr}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改DefectRecord
func (self *DefectRecordDAOImplement) UpdateOne(entity *model.DefectRecord) error {
	_, err := self.session.Table(meta.DefectRecord.TableName).Cols(meta.DefectRecord_SerialOrderId.ColumnName, meta.DefectRecord_OperationNr.ColumnName, meta.DefectRecord_Qty.ColumnName, meta.DefectRecord_ViewId.ColumnName, meta.DefectRecord_ViewDescr.ColumnName, meta.DefectRecord_ViewPicture.ColumnName, meta.DefectRecord_ViewCode.ColumnName, meta.DefectRecord_Width.ColumnName, meta.DefectRecord_Height.ColumnName, meta.DefectRecord_EndProduct.ColumnName, meta.DefectRecord_AreaId.ColumnName, meta.DefectRecord_XStart.ColumnName, meta.DefectRecord_XEnd.ColumnName, meta.DefectRecord_YStart.ColumnName, meta.DefectRecord_YEnd.ColumnName, meta.DefectRecord_XPos.ColumnName, meta.DefectRecord_YPos.ColumnName, meta.DefectRecord_WorkplaceId.ColumnName, meta.DefectRecord_ReworkplaceId.ColumnName, meta.DefectRecord_Status.ColumnName, meta.DefectRecord_DefectGrpId.ColumnName, meta.DefectRecord_DefectGrpDescr.ColumnName, meta.DefectRecord_DefectReasonId.ColumnName, meta.DefectRecord_DefectDescr.ColumnName, meta.DefectRecord_InspectTime.ColumnName, meta.DefectRecord_InspectShiftId.ColumnName, meta.DefectRecord_Inspector.ColumnName, meta.DefectRecord_ReworkTime.ColumnName, meta.DefectRecord_ReworkShiftId.ColumnName, meta.DefectRecord_Reworker.ColumnName, meta.DefectRecord_BuildCode.ColumnName, meta.DefectRecord_DDCCustC1.ColumnName, meta.DefectRecord_DDCCustC2.ColumnName, meta.DefectRecord_DDCCustC3.ColumnName, meta.DefectRecord_DDCCustC4.ColumnName, meta.DefectRecord_DDCCustI1.ColumnName, meta.DefectRecord_DDCCustI2.ColumnName, meta.DefectRecord_DDCCustI3.ColumnName, meta.DefectRecord_DDCCustI4.ColumnName, meta.DefectRecord_DDCCustT1.ColumnName, meta.DefectRecord_DDCCustT2.ColumnName, meta.DefectRecord_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查DefectRecord
func (self *DefectRecordDAOImplement) checkDefectRecordRecords(records *[]model.DefectRecord) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询DefectRecord
func (self *DefectRecordDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.DefectRecord, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.DefectRecord, 0, 10)
	session := self.session.Table(meta.DefectRecord.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询DefectRecord并分页
func (self *DefectRecordDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.DefectRecord.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.DefectRecord.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.DefectRecord, 0, 10)
	err = self.session.Table(meta.DefectRecord.TableName).SQL("select * from QM_DefectRecord where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
