package implments

import (
	"github.com/go-xorm/xorm"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"xorm.io/core"
)

type ViewValstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

func NewViewValstDAOImplement(session *xorm.Session, plantNr int, userid string) *ViewValstDAOImplement {
	return &ViewValstDAOImplement{session, plantNr, userid}
}

//插入ViewValst
func (self *ViewValstDAOImplement) InsertOne(entity *model.ViewValst) error {
	_, err := self.session.Table(meta.ViewValst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//删除指定键的ViewValst
func (self *ViewValstDAOImplement) DeleteOne(viewId string, pos int) error {
	_, err := self.session.Table(meta.ViewValst.TableName).ID(core.PK{self.plantNr, viewId, pos}).Delete(meta.ViewValst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

//查找指定键的ViewValst
func (self *ViewValstDAOImplement) SelectOne(viewId string, pos int) (*model.ViewValst, error) {
	var data model.ViewValst
	ok, err := self.session.Table(meta.ViewValst.TableName).ID(core.PK{self.plantNr, viewId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

//修改ViewValst
func (self *ViewValstDAOImplement) UpdateOne(entity *model.ViewValst) error {
	_, err := self.session.Table(meta.ViewValst.TableName).Cols(meta.ViewValst_ValName.ColumnName, meta.ViewValst_XStart.ColumnName, meta.ViewValst_YStart.ColumnName, meta.ViewValst_Width.ColumnName, meta.ViewValst_Height.ColumnName, meta.ViewValst_Descr.ColumnName, meta.ViewValst_LastUser.ColumnName).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

//批量检查ViewValst
func (self *ViewValstDAOImplement) checkViewValstRecords(records *[]model.ViewValst) error {
	for _, record := range *records {
		if self.plantNr != record.PlantNr {
			return grmi.NewBusinessError("记录不在范围内!")
		}
	}
	return nil
}

//按条件查询ViewValst
func (self *ViewValstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ViewValst, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	data := make([]model.ViewValst, 0, 10)
	session := self.session.Table(meta.ViewValst.TableName).Where("PlantNr = ?"+where, parameters...).OrderBy("PlantNr")
	for _, field := range orderByFields {
		session = session.OrderBy(field.ColumnName)
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

//按条件查询ViewValst并分页
func (self *ViewValstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	parameters := make([]interface{}, 0, 10)
	parameters = append(parameters, self.plantNr)

	where := ""
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Value)
		}
	}
	orderBy := " order by PlantNr"
	for _, field := range orderByFields {
		orderBy += ", " + field.ColumnName
	}
	count, err := self.session.Table(meta.ViewValst.TableName).Where("PlantNr = ? "+where, parameters...).Count(meta.ViewValst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ViewValst, 0, 10)
	err = self.session.Table(meta.ViewValst.TableName).SQL("select * from QM_ViewValst where PlantNr = ?"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}
