package container

import (
	"errors"
	"fmt"
	"leit.com/LAPP_GAAS_GFrame/web/models"
	"reflect"
	"strings"
)

var contextType = reflect.TypeOf((*models.Usertab)(nil))
var errorType = reflect.TypeOf((*error)(nil)).Elem()
var stringType = reflect.TypeOf("")

type DefaultComponentContainer struct {
	errors       []string
	serviceInfos []InvokerInfo
	none         *NoneInvoker
}

func (container *DefaultComponentContainer) appendError(errorText string) {
	container.errors = append(container.errors, errorText)
}

func void(interface{}, string) (interface{}, error) {
	return nil, nil
}

func (container *DefaultComponentContainer) parseJsonBoolean(jsonValue interface{}, parameterName string) (interface{}, error) {
	if jsonValue == nil {
		return nil, errors.New(fmt.Sprintf("%s 不能为空!", parameterName))
	} else if value, ok := jsonValue.(bool); !ok {
		return nil, errors.New(fmt.Sprintf("%s 无法解析!源类型:%v,目标类型:Bool.", parameterName, reflect.TypeOf(jsonValue)))
	} else {
		return value, nil
	}
}

func (container *DefaultComponentContainer) parseJsonString(jsonValue interface{}, parameterName string) (interface{}, error) {
	if jsonValue == nil {
		return "", nil
	} else if value, ok := jsonValue.(string); !ok {
		return nil, errors.New(fmt.Sprintf("%s 无法解析!源类型:%v,目标类型:String.", parameterName, reflect.TypeOf(jsonValue)))
	} else {
		return value, nil
	}
}

func (container *DefaultComponentContainer) parseJsonNumber(jsonValue interface{}, parameterName string) (float64, error) {
	if jsonValue == nil {
		return 0, errors.New(fmt.Sprintf("%s 不能为空!", parameterName))
	} else if value, ok := jsonValue.(float64); !ok {
		return 0, errors.New(fmt.Sprintf("%s 无法解析!源类型:%v,目标类型:Number.", parameterName, reflect.TypeOf(jsonValue)))
	} else {
		return value, nil
	}
}

func (container *DefaultComponentContainer) parseJsonArray(jsonValue interface{}, parameterName string) ([]interface{}, error) {
	if jsonValue == nil {
		return nil, errors.New(fmt.Sprintf("%s 不能为空!", parameterName))
	} else if items, ok := jsonValue.([]interface{}); !ok {
		return nil, errors.New(fmt.Sprintf("%s 无法解析!源类型:%v,目标类型:Array.", parameterName, reflect.TypeOf(jsonValue)))
	} else {
		return items, nil
	}
}

func (container *DefaultComponentContainer) parseJsonObject(jsonValue interface{}, parameterName string) (map[string]interface{}, error) {
	if jsonValue == nil {
		return nil, errors.New(fmt.Sprintf("%s 不能为空!", parameterName))
	} else if jsonObject, ok := jsonValue.(map[string]interface{}); !ok {
		return nil, errors.New(fmt.Sprintf("%s 无法解析!源类型:%v,目标类型:Object.", parameterName, reflect.TypeOf(jsonValue)))
	} else {
		return jsonObject, nil
	}
}

func (container *DefaultComponentContainer) parseUnsignedInteger(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return uint(value), nil
	}
}

func (container *DefaultComponentContainer) parseUnsignedInteger8(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return uint8(value), nil
	}
}

func (container *DefaultComponentContainer) parseUnsignedInteger16(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return uint16(value), nil
	}
}

func (container *DefaultComponentContainer) parseUnsignedInteger32(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return uint32(value), nil
	}
}

func (container *DefaultComponentContainer) parseUnsignedInteger64(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return uint64(value), nil
	}
}

func (container *DefaultComponentContainer) parseInteger(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return int(value), nil
	}
}

func (container *DefaultComponentContainer) parseInteger8(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return int8(value), nil
	}
}

func (container *DefaultComponentContainer) parseInteger16(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return int16(value), nil
	}
}

func (container *DefaultComponentContainer) parseInteger32(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return int32(value), nil
	}
}

func (container *DefaultComponentContainer) parseInteger64(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return int64(value), nil
	}
}

func (container *DefaultComponentContainer) parseFloat32(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return float32(value), nil
	}
}

func (container *DefaultComponentContainer) parseFloat64(jsonValue interface{}, parameterName string) (interface{}, error) {
	if value, err := container.parseJsonNumber(jsonValue, parameterName); err != nil {
		return nil, err
	} else {
		return value, nil
	}
}

func (container *DefaultComponentContainer) buildMapParser(valueParser parameterParser, valueType reflect.Type) parameterParser {

	return func(jsonValue interface{}, parameterName string) (interface{}, error) {

		if jsonObject, err := container.parseJsonObject(jsonValue, parameterName); err != nil {
			return reflect.Zero(reflect.MapOf(stringType, valueType)).Interface(), nil
		} else {
			result := reflect.MakeMapWithSize(reflect.MapOf(stringType, valueType), len(jsonObject))
			for key, value := range jsonObject {
				if value, err := valueParser(value, fmt.Sprintf("%s[%s]", parameterName, key)); err != nil {
					return nil, err
				} else {
					result.SetMapIndex(reflect.ValueOf(key), reflect.ValueOf(value))
				}
			}
			return result.Interface(), nil
		}
	}
}

func (container *DefaultComponentContainer) buildSliceParser(itemParser parameterParser, elementType reflect.Type) parameterParser {

	return func(jsonValue interface{}, parameterName string) (interface{}, error) {

		if jsonArray, err := container.parseJsonArray(jsonValue, parameterName); err != nil {
			return reflect.Zero(reflect.SliceOf(elementType)).Interface(), nil
		} else {
			slice := reflect.MakeSlice(reflect.SliceOf(elementType), len(jsonArray), len(jsonArray))
			for index, item := range jsonArray {
				if value, err := itemParser(item, fmt.Sprintf("%s[%d]", parameterName, index)); err != nil {
					return nil, err
				} else {
					slice.Index(index).Set(reflect.ValueOf(value))
				}
			}
			return slice.Interface(), nil
		}
	}
}

func (container *DefaultComponentContainer) buildArrayParser(itemParser parameterParser, length int, elementType reflect.Type) parameterParser {

	return func(jsonValue interface{}, parameterName string) (interface{}, error) {

		if jsonArray, err := container.parseJsonArray(jsonValue, parameterName); err != nil {
			return nil, err
		} else if len(jsonArray) != length {
			return nil, errors.New(fmt.Sprintf("%s 数组长度匹配!期望长度:%d,实际长度:%d.", parameterName, length, len(jsonArray)))
		} else {
			array := reflect.New(reflect.ArrayOf(length, elementType)).Elem()
			for index := 0; index < length; index++ {
				if value, err := itemParser(jsonArray[index], fmt.Sprintf("%s[%d]", parameterName, index)); err != nil {
					return nil, err
				} else {
					array.Index(index).Set(reflect.ValueOf(value))
				}
			}
			return array.Interface(), nil
		}
	}
}

func (container *DefaultComponentContainer) buildPointerParser(itemParser parameterParser, elementType reflect.Type) parameterParser {

	return func(jsonValue interface{}, parameterName string) (interface{}, error) {

		if jsonValue == nil {
			return reflect.Zero(reflect.PtrTo(elementType)).Interface(), nil
		} else if value, err := itemParser(jsonValue, parameterName); err != nil {
			return nil, err
		} else {
			pointer := reflect.New(elementType)
			pointer.Elem().Set(reflect.ValueOf(value))
			return pointer.Interface(), nil
		}
	}
}

func (container *DefaultComponentContainer) buildStructParser(structType reflect.Type, serviceName string, methodName string, parameterName string, typeName string) parameterParser {

	fieldCount := structType.NumField()
	parsers := make(map[string]parameterParser, fieldCount)
	hasError := false
	for i := 0; i < fieldCount; i++ {
		field := structType.Field(i)
		if parameterParser, typeText := container.getParameterParser(serviceName, methodName, field.Type); parameterParser != nil {
			parsers[field.Name] = parameterParser
		} else {
			container.appendError(fmt.Sprintf("不支持的字段类型! 方法: %s.%s 参数: %s 字段: %s.%s 类型: %s", serviceName, methodName, parameterName, typeName, field.Name, typeText))
			hasError = true
		}
	}

	if hasError {
		return nil
	}

	return func(jsonValue interface{}, parameterName string) (interface{}, error) {

		structValue := reflect.New(structType).Elem()
		for fieldName, parser := range parsers {
			field := structValue.FieldByName(fieldName)
			if !field.IsValid() {
				return nil, errors.New(fmt.Sprintf("%s 没有找到字段:%v.%s", parameterName, structType, fieldName))
			}
			if jsonObject, err := container.parseJsonObject(jsonValue, parameterName); err != nil {
				return nil, err
			} else if value, err := parser(jsonObject[fieldName], fmt.Sprintf("%s.%s", parameterName, fieldName)); err != nil {
				return nil, err
			} else {
				field.Set(reflect.ValueOf(value))
			}
		}
		return structValue.Interface(), nil
	}
}

func getFullName(t reflect.Type) string {
	if "" == t.PkgPath() {
		return t.Name()
	} else {
		return fmt.Sprintf("%s.%s", t.PkgPath(), t.Name())
	}
}

func (container *DefaultComponentContainer) checkOutType(parameterType reflect.Type) (bool, string) {
	switch parameterType.Kind() {
	case reflect.Invalid:
		return false, parameterType.Name()
	case reflect.Bool:
		return true, parameterType.Name()
	case reflect.Int:
		return true, parameterType.Name()
	case reflect.Int8:
		return true, parameterType.Name()
	case reflect.Int16:
		return true, parameterType.Name()
	case reflect.Int32:
		return true, parameterType.Name()
	case reflect.Int64:
		return true, parameterType.Name()
	case reflect.Uint:
		return true, parameterType.Name()
	case reflect.Uint8:
		return true, parameterType.Name()
	case reflect.Uint16:
		return true, parameterType.Name()
	case reflect.Uint32:
		return true, parameterType.Name()
	case reflect.Uint64:
		return true, parameterType.Name()
	case reflect.Uintptr:
		return false, parameterType.Name()
	case reflect.Float32:
		return true, parameterType.Name()
	case reflect.Float64:
		return true, parameterType.Name()
	case reflect.Complex64:
		return false, parameterType.Name()
	case reflect.Complex128:
		return false, parameterType.Name()
	case reflect.Array:
		if ok, typeText := container.checkOutType(parameterType.Elem()); ok {
			return true, fmt.Sprintf("[%d]%s", parameterType.Len(), typeText)
		} else {
			return false, fmt.Sprintf("[%d]%s", parameterType.Len(), typeText)
		}
	case reflect.Chan:
		return false, parameterType.Name()
	case reflect.Func:
		return false, parameterType.Name()
	case reflect.Interface:
		return true, getFullName(parameterType)
	case reflect.Map:
		keyOk, keyTypeText := container.checkOutType(parameterType.Key())
		valueOk, valueTypeText := container.checkOutType(parameterType.Elem())
		if keyOk && valueOk {
			return true, fmt.Sprintf("*map[%s]%s", keyTypeText, valueTypeText)
		} else {
			return false, fmt.Sprintf("*map[%s]%s", keyTypeText, valueTypeText)
		}
	case reflect.Ptr:
		if ok, typeText := container.checkOutType(parameterType.Elem()); ok {
			return true, fmt.Sprintf("*%s", typeText)
		} else {
			return false, fmt.Sprintf("*%s", typeText)
		}
	case reflect.Slice:
		if ok, typeText := container.checkOutType(parameterType.Elem()); ok {
			return true, fmt.Sprintf("[]%s", typeText)
		} else {
			return false, fmt.Sprintf("[]%s", typeText)
		}
	case reflect.String:
		return true, parameterType.Name()
	case reflect.Struct:
		return true, getFullName(parameterType)
	case reflect.UnsafePointer:
		return false, parameterType.Name()
	default:
		return false, "Unknown"
	}
}

func (container *DefaultComponentContainer) getParameterParser(serviceName string, methodName string, parameterType reflect.Type) (parameterParser, string) {
	switch parameterType.Kind() {
	case reflect.Invalid:
		return nil, parameterType.Name()
	case reflect.Bool:
		return container.parseJsonBoolean, parameterType.Name()
	case reflect.Int:
		return container.parseInteger, parameterType.Name()
	case reflect.Int8:
		return container.parseInteger8, parameterType.Name()
	case reflect.Int16:
		return container.parseInteger16, parameterType.Name()
	case reflect.Int32:
		return container.parseInteger32, parameterType.Name()
	case reflect.Int64:
		return container.parseInteger64, parameterType.Name()
	case reflect.Uint:
		return container.parseUnsignedInteger, parameterType.Name()
	case reflect.Uint8:
		return container.parseUnsignedInteger8, parameterType.Name()
	case reflect.Uint16:
		return container.parseUnsignedInteger16, parameterType.Name()
	case reflect.Uint32:
		return container.parseUnsignedInteger32, parameterType.Name()
	case reflect.Uint64:
		return container.parseUnsignedInteger64, parameterType.Name()
	case reflect.Uintptr:
		return nil, parameterType.Name()
	case reflect.Float32:
		return container.parseFloat32, parameterType.Name()
	case reflect.Float64:
		return container.parseFloat64, parameterType.Name()
	case reflect.Complex64:
		return nil, parameterType.Name()
	case reflect.Complex128:
		return nil, parameterType.Name()
	case reflect.Array:
		if parameterParser, typeText := container.getParameterParser(serviceName, methodName, parameterType.Elem()); parameterParser != nil {
			return container.buildArrayParser(parameterParser, parameterType.Len(), parameterType.Elem()), fmt.Sprintf("[%d]%s", parameterType.Len(), typeText)
		} else {
			return nil, fmt.Sprintf("[%d]%s", parameterType.Len(), typeText)
		}
	case reflect.Chan:
		return nil, parameterType.Name()
	case reflect.Func:
		return nil, parameterType.Name()
	case reflect.Interface:
		return nil, parameterType.Name()
	case reflect.Map:
		_, keyTypeText := container.getParameterParser(serviceName, methodName, parameterType.Key())
		valuerParser, valueTypeText := container.getParameterParser(serviceName, methodName, parameterType.Elem())
		if parameterType.Key().Kind() != reflect.String {
			return nil, fmt.Sprintf("*map[%s]%s", keyTypeText, valueTypeText)
		}
		if valuerParser != nil {
			return container.buildMapParser(valuerParser, parameterType.Elem()), fmt.Sprintf("*map[%s]%s", keyTypeText, valueTypeText)
		} else {
			return nil, fmt.Sprintf("*map[%s]%s", keyTypeText, valueTypeText)
		}
	case reflect.Ptr:
		if parameterParser, typeText := container.getParameterParser(serviceName, methodName, parameterType.Elem()); parameterParser != nil {
			return container.buildPointerParser(parameterParser, parameterType.Elem()), fmt.Sprintf("*%s", typeText)
		} else {
			return nil, fmt.Sprintf("*%s", typeText)
		}
	case reflect.Slice:
		if parameterParser, typeText := container.getParameterParser(serviceName, methodName, parameterType.Elem()); parameterParser != nil {
			return container.buildSliceParser(parameterParser, parameterType.Elem()), fmt.Sprintf("[]%s", typeText)
		} else {
			return nil, fmt.Sprintf("[]%s", typeText)
		}
	case reflect.String:
		return container.parseJsonString, parameterType.Name()
	case reflect.Struct:
		typeName := getFullName(parameterType)
		return container.buildStructParser(parameterType, serviceName, methodName, typeName, parameterType.Name()), typeName
	case reflect.UnsafePointer:
		return nil, parameterType.Name()
	default:
		return nil, "Unknown"
	}
}

func (container *DefaultComponentContainer) parseParameter(parameterType reflect.Type, serviceName string, methodName string, parameterName string) parameterParser {
	if parameterParser, typeText := container.getParameterParser(serviceName, methodName, parameterType); parameterParser != nil {
		return parameterParser
	} else {
		container.appendError(fmt.Sprintf("不支持的参数类型! 方法: %s.%s 参数: %s 类型: %s", serviceName, methodName, parameterName, typeText))
		return void
	}
}

func (container *DefaultComponentContainer) parseService(path string, service reflect.StructField, serviceType reflect.Type, serviceValue reflect.Value) {

	serviceName := service.Name
	if serviceType.Kind() != reflect.Interface {
		container.appendError(fmt.Sprintf("服务类型必须是接口! 服务: %s", serviceName))
	} else {
		for i := 0; i < serviceType.NumMethod(); i++ {
			method := serviceType.Method(i)
			hasError, invoker := container.parseServiceMethod(serviceName, method.Name, method.Type, serviceValue)
			if !hasError {
				container.serviceInfos = append(container.serviceInfos, InvokerInfo{fmt.Sprintf("/%s/%s", path, strings.ToLower(method.Name)), invoker})
			}
		}
	}
}

func (container *DefaultComponentContainer) parseServiceMethod(serviceName string, methodName string, methodType reflect.Type, serviceValue reflect.Value) (bool, *MethodInvoker) {

	hasError := false
	if methodType.NumIn() < 1 {
		container.appendError(fmt.Sprintf("参数数量错误! 方法: %s.%s 参数数量: %d", serviceName, methodName, methodType.NumIn()))
		hasError = true
	}
	if methodType.In(0) != contextType {
		container.appendError(fmt.Sprintf("第一个参数类型错误! 方法: %s.%s 类型:%s", serviceName, methodName, methodType.In(0)))
		hasError = true
	}
	parameterParsers := make([]parameterParser, 0, 10)
	for i := 1; i < methodType.NumIn(); i++ {
		parameterParsers = append(parameterParsers, container.parseParameter(methodType.In(i), serviceName, methodName, fmt.Sprintf("%s.%s-in#%d", serviceName, methodName, i)))
	}
	if methodType.NumOut() < 1 || 2 < methodType.NumOut() {
		container.appendError(fmt.Sprintf("返回值数量错误! 方法: %s.%s 返回值数量: %d", serviceName, methodName, methodType.NumOut()))
		hasError = true
	}
	if methodType.Out(methodType.NumOut()-1) != errorType {
		container.appendError(fmt.Sprintf("最后一个返回值类型错误! 方法: %s.%s 类型:%s", serviceName, methodName, methodType.Out(methodType.NumOut()-1)))
		hasError = true
	}
	for i := 0; i < methodType.NumOut(); i++ {
		if ok, typeText := container.checkOutType(methodType.Out(i)); !ok {
			container.appendError(fmt.Sprintf("不支持的返回值类型! 方法:%s.%s 参数: #%d 类型: %s", serviceName, methodName, i+1, typeText))
			hasError = true
		}
	}
	if hasError {
		return hasError, nil
	} else {
		return hasError, NewMethodInvoker(serviceValue.MethodByName(methodName), parameterParsers)
	}
}

func (container *DefaultComponentContainer) Parse(perserInstance interface{}) error {

	perserType := reflect.TypeOf(perserInstance)
	perserValue := reflect.ValueOf(perserInstance)

	if perserType.Kind() == reflect.Ptr {
		perserType = perserType.Elem()
		perserValue = perserValue.Elem()
	}

	if perserType.Kind() != reflect.Struct {
		container.appendError(fmt.Sprintf("服务映射必须是结构体!"))
	} else {
		pathMapping := make(map[string][]string)
		for i := 0; i < perserType.NumField(); i++ {
			field := perserType.Field(i)
			serviceName := field.Name
			path := strings.ToLower(serviceName)
			group, ok := pathMapping[path]
			if !ok {
				group = make([]string, 0, 10)
			}
			pathMapping[path] = append(group, serviceName)
			container.parseService(path, field, perserType.Field(i).Type, perserValue.FieldByName(perserType.Field(i).Name).Elem())
		}

		for path, group := range pathMapping {
			if len(group) > 1 {
				container.appendError(fmt.Sprintf("服务路径冲突! 路径: \"%s\" 服务: %s", path, group))
			}
		}
	}

	if len(container.errors) > 0 {
		return errors.New(strings.Join(container.errors, "\r\n"))
	}
	return nil
}

func (container *DefaultComponentContainer) Errors() []string {
	return container.errors
}

func (container *DefaultComponentContainer) ServiceInfos() []InvokerInfo {
	return container.serviceInfos
}

func (container *DefaultComponentContainer) None() Invoker {
	return container.none
}
