package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//Article的默认查询条件
var DefaultConditionOfArticle = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Article_ArtId.UrlParameterName:                 grmi.NewConditionItem(meta.Article_ArtId, grmi.Equal, true),
		meta.Article_Descr1.UrlParameterName:                grmi.NewConditionItem(meta.Article_Descr1, grmi.Equal, false),
		meta.Article_Descr2.UrlParameterName:                grmi.NewConditionItem(meta.Article_Descr2, grmi.Equal, false),
		meta.Article_ArtTypeId.UrlParameterName:             grmi.NewConditionItem(meta.Article_ArtTypeId, grmi.Equal, false),
		meta.Article_ProjectId.UrlParameterName:             grmi.NewConditionItem(meta.Article_ProjectId, grmi.Equal, false),
		meta.Article_CustMaterialId.UrlParameterName:        grmi.NewConditionItem(meta.Article_CustMaterialId, grmi.Equal, false),
		meta.Article_AlternativeMaterialId.UrlParameterName: grmi.NewConditionItem(meta.Article_AlternativeMaterialId, grmi.Equal, false),
		meta.Article_UomId.UrlParameterName:                 grmi.NewConditionItem(meta.Article_UomId, grmi.Equal, false),
		meta.Article_QuantityPerHour.UrlParameterName:       grmi.NewConditionItem(meta.Article_QuantityPerHour, grmi.Equal, false),
		meta.Article_DeliveryBuffer.UrlParameterName:        grmi.NewConditionItem(meta.Article_DeliveryBuffer, grmi.Equal, false),
		meta.Article_Icon.UrlParameterName:                  grmi.NewConditionItem(meta.Article_Icon, grmi.Equal, false),
		meta.Article_DisplayColor.UrlParameterName:          grmi.NewConditionItem(meta.Article_DisplayColor, grmi.Equal, false),
		meta.Article_Document.UrlParameterName:              grmi.NewConditionItem(meta.Article_Document, grmi.Equal, false),
		meta.Article_DefaultRoute.UrlParameterName:          grmi.NewConditionItem(meta.Article_DefaultRoute, grmi.Equal, false),
		meta.Article_LotSize.UrlParameterName:               grmi.NewConditionItem(meta.Article_LotSize, grmi.Equal, false),
		meta.Article_ABCClass.UrlParameterName:              grmi.NewConditionItem(meta.Article_ABCClass, grmi.Equal, false),
		meta.Article_ArtSize1.UrlParameterName:              grmi.NewConditionItem(meta.Article_ArtSize1, grmi.Equal, false),
		meta.Article_ArtSize2.UrlParameterName:              grmi.NewConditionItem(meta.Article_ArtSize2, grmi.Equal, false),
		meta.Article_ArtSize3.UrlParameterName:              grmi.NewConditionItem(meta.Article_ArtSize3, grmi.Equal, false),
		meta.Article_ArtSize4.UrlParameterName:              grmi.NewConditionItem(meta.Article_ArtSize4, grmi.Equal, false),
		meta.Article_ArtSize5.UrlParameterName:              grmi.NewConditionItem(meta.Article_ArtSize5, grmi.Equal, false),
		meta.Article_ArtSpec1.UrlParameterName:              grmi.NewConditionItem(meta.Article_ArtSpec1, grmi.Equal, false),
		meta.Article_ArtSpec2.UrlParameterName:              grmi.NewConditionItem(meta.Article_ArtSpec2, grmi.Equal, false),
		meta.Article_ArtSpec3.UrlParameterName:              grmi.NewConditionItem(meta.Article_ArtSpec3, grmi.Equal, false),
		meta.Article_ArtSpec4.UrlParameterName:              grmi.NewConditionItem(meta.Article_ArtSpec4, grmi.Equal, false),
		meta.Article_ArtSpec5.UrlParameterName:              grmi.NewConditionItem(meta.Article_ArtSpec5, grmi.Equal, false),
		meta.Article_DefaultInspectPlanId.UrlParameterName:  grmi.NewConditionItem(meta.Article_DefaultInspectPlanId, grmi.Equal, false),
		meta.Article_LastModify.UrlParameterName:            grmi.NewConditionItem(meta.Article_LastModify, grmi.Approximate, false),
		meta.Article_LastUser.UrlParameterName:              grmi.NewConditionItem(meta.Article_LastUser, grmi.Equal, false),
		meta.Article_CreateTime.UrlParameterName:            grmi.NewConditionItem(meta.Article_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//Article的默认分页查询条件
var DefaultConditionOfArticleAndPaging = grmi.NewCondition(
	DefaultConditionOfArticle.Items,
	grmi.NewPaging(),
)

type ArticleServiceImplement struct {
}

func (self *ArticleServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Article.service.impl.go", "SelectArticle", "查询Article")

	condition := DefaultConditionOfArticleAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewArticleDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *ArticleServiceImplement) InsertOne(user *models.Usertab, entity *model.Article) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Article.service.impl.go", "InsertOneArticle", "插入一个Article")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArticleDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ArtId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *ArticleServiceImplement) DeleteOne(user *models.Usertab, artId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Article.service.impl.go", "DeleteOneArticle", "删除一个Article")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArticleDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(artId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(artId)
	if err != nil {
		return err
	}
	return nil
}

func (self *ArticleServiceImplement) SelectOne(user *models.Usertab, artId string) (*model.Article, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Article.service.impl.go", "SelectOneArticle", "查询一个Article")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArticleDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(artId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *ArticleServiceImplement) UpdateOne(user *models.Usertab, entity *model.Article) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Article.service.impl.go", "UpdateOneArticle", "修改一个Article")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArticleDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ArtId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewArticleServiceImplement() *ArticleServiceImplement {
	return &ArticleServiceImplement{}
}
