package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//Attribute的默认查询条件
var DefaultConditionOfAttribute = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Attribute_AttrCode.UrlParameterName:     grmi.NewConditionItem(meta.Attribute_AttrCode, grmi.Equal, true),
		meta.Attribute_AttrName.UrlParameterName:     grmi.NewConditionItem(meta.Attribute_AttrName, grmi.Equal, false),
		meta.Attribute_Descr.UrlParameterName:        grmi.NewConditionItem(meta.Attribute_Descr, grmi.Equal, false),
		meta.Attribute_AttrGroup.UrlParameterName:    grmi.NewConditionItem(meta.Attribute_AttrGroup, grmi.Equal, false),
		meta.Attribute_ShortCode.UrlParameterName:    grmi.NewConditionItem(meta.Attribute_ShortCode, grmi.Equal, false),
		meta.Attribute_AttrType.UrlParameterName:     grmi.NewConditionItem(meta.Attribute_AttrType, grmi.Equal, false),
		meta.Attribute_AttrDataType.UrlParameterName: grmi.NewConditionItem(meta.Attribute_AttrDataType, grmi.Equal, false),
		meta.Attribute_AttrValType.UrlParameterName:  grmi.NewConditionItem(meta.Attribute_AttrValType, grmi.Equal, false),
		meta.Attribute_ValFormat.UrlParameterName:    grmi.NewConditionItem(meta.Attribute_ValFormat, grmi.Equal, false),
		meta.Attribute_LastModify.UrlParameterName:   grmi.NewConditionItem(meta.Attribute_LastModify, grmi.Approximate, false),
		meta.Attribute_LastUser.UrlParameterName:     grmi.NewConditionItem(meta.Attribute_LastUser, grmi.Equal, false),
		meta.Attribute_CreateTime.UrlParameterName:   grmi.NewConditionItem(meta.Attribute_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//Attribute的默认分页查询条件
var DefaultConditionOfAttributeAndPaging = grmi.NewCondition(
	DefaultConditionOfAttribute.Items,
	grmi.NewPaging(),
)

type AttributeServiceImplement struct {
}

func (self *AttributeServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Attribute.service.impl.go", "SelectAttribute", "查询Attribute")

	condition := DefaultConditionOfAttributeAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewAttributeDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *AttributeServiceImplement) InsertOne(user *models.Usertab, entity *model.Attribute) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Attribute.service.impl.go", "InsertOneAttribute", "插入一个Attribute")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.AttrCode)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *AttributeServiceImplement) DeleteOne(user *models.Usertab, attrCode int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Attribute.service.impl.go", "DeleteOneAttribute", "删除一个Attribute")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(attrCode)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(attrCode)
	if err != nil {
		return err
	}
	return nil
}

func (self *AttributeServiceImplement) SelectOne(user *models.Usertab, attrCode int) (*model.Attribute, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Attribute.service.impl.go", "SelectOneAttribute", "查询一个Attribute")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(attrCode)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *AttributeServiceImplement) UpdateOne(user *models.Usertab, entity *model.Attribute) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Attribute.service.impl.go", "UpdateOneAttribute", "修改一个Attribute")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.AttrCode)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewAttributeServiceImplement() *AttributeServiceImplement {
	return &AttributeServiceImplement{}
}
