package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//AttributeGroup的默认查询条件
var DefaultConditionOfAttributeGroup = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.AttributeGroup_AttrGrpCode.UrlParameterName: grmi.NewConditionItem(meta.AttributeGroup_AttrGrpCode, grmi.Equal, true),
		meta.AttributeGroup_Descr.UrlParameterName:       grmi.NewConditionItem(meta.AttributeGroup_Descr, grmi.Equal, false),
		meta.AttributeGroup_Color.UrlParameterName:       grmi.NewConditionItem(meta.AttributeGroup_Color, grmi.Equal, false),
		meta.AttributeGroup_AgiPara1.UrlParameterName:    grmi.NewConditionItem(meta.AttributeGroup_AgiPara1, grmi.Equal, false),
		meta.AttributeGroup_AgiPara2.UrlParameterName:    grmi.NewConditionItem(meta.AttributeGroup_AgiPara2, grmi.Equal, false),
		meta.AttributeGroup_AgcPara1.UrlParameterName:    grmi.NewConditionItem(meta.AttributeGroup_AgcPara1, grmi.Equal, false),
		meta.AttributeGroup_AgcPara2.UrlParameterName:    grmi.NewConditionItem(meta.AttributeGroup_AgcPara2, grmi.Equal, false),
		meta.AttributeGroup_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.AttributeGroup_LastModify, grmi.Approximate, false),
		meta.AttributeGroup_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.AttributeGroup_LastUser, grmi.Equal, false),
		meta.AttributeGroup_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.AttributeGroup_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//AttributeGroup的默认分页查询条件
var DefaultConditionOfAttributeGroupAndPaging = grmi.NewCondition(
	DefaultConditionOfAttributeGroup.Items,
	grmi.NewPaging(),
)

type AttributeGroupServiceImplement struct {
}

func (self *AttributeGroupServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeGroup.service.impl.go", "SelectAttributeGroup", "查询AttributeGroup")

	condition := DefaultConditionOfAttributeGroupAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewAttributeGroupDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *AttributeGroupServiceImplement) InsertOne(user *models.Usertab, entity *model.AttributeGroup) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeGroup.service.impl.go", "InsertOneAttributeGroup", "插入一个AttributeGroup")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeGroupDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.AttrGrpCode)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *AttributeGroupServiceImplement) DeleteOne(user *models.Usertab, attrGrpCode int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeGroup.service.impl.go", "DeleteOneAttributeGroup", "删除一个AttributeGroup")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeGroupDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(attrGrpCode)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(attrGrpCode)
	if err != nil {
		return err
	}
	return nil
}

func (self *AttributeGroupServiceImplement) SelectOne(user *models.Usertab, attrGrpCode int) (*model.AttributeGroup, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeGroup.service.impl.go", "SelectOneAttributeGroup", "查询一个AttributeGroup")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeGroupDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(attrGrpCode)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *AttributeGroupServiceImplement) UpdateOne(user *models.Usertab, entity *model.AttributeGroup) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeGroup.service.impl.go", "UpdateOneAttributeGroup", "修改一个AttributeGroup")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeGroupDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.AttrGrpCode)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewAttributeGroupServiceImplement() *AttributeGroupServiceImplement {
	return &AttributeGroupServiceImplement{}
}
