package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//AttributeGroupValst的默认查询条件
var DefaultConditionOfAttributeGroupValst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.AttributeGroupValst_AttrCode.UrlParameterName:    grmi.NewConditionItem(meta.AttributeGroupValst_AttrCode, grmi.Equal, true),
		meta.AttributeGroupValst_AttrGrpCode.UrlParameterName: grmi.NewConditionItem(meta.AttributeGroupValst_AttrGrpCode, grmi.Equal, true),
		meta.AttributeGroupValst_Pos.UrlParameterName:         grmi.NewConditionItem(meta.AttributeGroupValst_Pos, grmi.Equal, false),
		meta.AttributeGroupValst_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.AttributeGroupValst_LastModify, grmi.Approximate, false),
		meta.AttributeGroupValst_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.AttributeGroupValst_LastUser, grmi.Equal, false),
		meta.AttributeGroupValst_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.AttributeGroupValst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//AttributeGroupValst的默认分页查询条件
var DefaultConditionOfAttributeGroupValstAndPaging = grmi.NewCondition(
	DefaultConditionOfAttributeGroupValst.Items,
	grmi.NewPaging(),
)

type AttributeGroupValstServiceImplement struct {
}

func (self *AttributeGroupValstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeGroupValst.service.impl.go", "SelectAttributeGroupValst", "查询AttributeGroupValst")

	condition := DefaultConditionOfAttributeGroupValstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewAttributeGroupValstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *AttributeGroupValstServiceImplement) InsertOne(user *models.Usertab, entity *model.AttributeGroupValst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeGroupValst.service.impl.go", "InsertOneAttributeGroupValst", "插入一个AttributeGroupValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeGroupValstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.AttrCode, entity.AttrGrpCode)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *AttributeGroupValstServiceImplement) DeleteOne(user *models.Usertab, attrCode int, attrGrpCode int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeGroupValst.service.impl.go", "DeleteOneAttributeGroupValst", "删除一个AttributeGroupValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeGroupValstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(attrCode, attrGrpCode)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(attrCode, attrGrpCode)
	if err != nil {
		return err
	}
	return nil
}

func (self *AttributeGroupValstServiceImplement) SelectOne(user *models.Usertab, attrCode int, attrGrpCode int) (*model.AttributeGroupValst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeGroupValst.service.impl.go", "SelectOneAttributeGroupValst", "查询一个AttributeGroupValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeGroupValstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(attrCode, attrGrpCode)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *AttributeGroupValstServiceImplement) UpdateOne(user *models.Usertab, entity *model.AttributeGroupValst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeGroupValst.service.impl.go", "UpdateOneAttributeGroupValst", "修改一个AttributeGroupValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeGroupValstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.AttrCode, entity.AttrGrpCode)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewAttributeGroupValstServiceImplement() *AttributeGroupValstServiceImplement {
	return &AttributeGroupValstServiceImplement{}
}
