package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//AttributeValst的默认查询条件
var DefaultConditionOfAttributeValst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.AttributeValst_AttrCode.UrlParameterName:   grmi.NewConditionItem(meta.AttributeValst_AttrCode, grmi.Equal, true),
		meta.AttributeValst_Pos.UrlParameterName:        grmi.NewConditionItem(meta.AttributeValst_Pos, grmi.Equal, true),
		meta.AttributeValst_AttrValue.UrlParameterName:  grmi.NewConditionItem(meta.AttributeValst_AttrValue, grmi.Equal, false),
		meta.AttributeValst_Descr.UrlParameterName:      grmi.NewConditionItem(meta.AttributeValst_Descr, grmi.Equal, false),
		meta.AttributeValst_ShortCode.UrlParameterName:  grmi.NewConditionItem(meta.AttributeValst_ShortCode, grmi.Equal, false),
		meta.AttributeValst_Valformat.UrlParameterName:  grmi.NewConditionItem(meta.AttributeValst_Valformat, grmi.Equal, false),
		meta.AttributeValst_LastModify.UrlParameterName: grmi.NewConditionItem(meta.AttributeValst_LastModify, grmi.Approximate, false),
		meta.AttributeValst_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.AttributeValst_LastUser, grmi.Equal, false),
		meta.AttributeValst_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.AttributeValst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//AttributeValst的默认分页查询条件
var DefaultConditionOfAttributeValstAndPaging = grmi.NewCondition(
	DefaultConditionOfAttributeValst.Items,
	grmi.NewPaging(),
)

type AttributeValstServiceImplement struct {
}

func (self *AttributeValstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeValst.service.impl.go", "SelectAttributeValst", "查询AttributeValst")

	condition := DefaultConditionOfAttributeValstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewAttributeValstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *AttributeValstServiceImplement) InsertOne(user *models.Usertab, entity *model.AttributeValst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeValst.service.impl.go", "InsertOneAttributeValst", "插入一个AttributeValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeValstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.AttrCode, entity.Pos)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *AttributeValstServiceImplement) DeleteOne(user *models.Usertab, attrCode int, pos int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeValst.service.impl.go", "DeleteOneAttributeValst", "删除一个AttributeValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeValstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(attrCode, pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(attrCode, pos)
	if err != nil {
		return err
	}
	return nil
}

func (self *AttributeValstServiceImplement) SelectOne(user *models.Usertab, attrCode int, pos int) (*model.AttributeValst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeValst.service.impl.go", "SelectOneAttributeValst", "查询一个AttributeValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeValstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(attrCode, pos)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *AttributeValstServiceImplement) UpdateOne(user *models.Usertab, entity *model.AttributeValst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/AttributeValst.service.impl.go", "UpdateOneAttributeValst", "修改一个AttributeValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewAttributeValstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.AttrCode, entity.Pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewAttributeValstServiceImplement() *AttributeValstServiceImplement {
	return &AttributeValstServiceImplement{}
}
