package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//CodeParser的默认查询条件
var DefaultConditionOfCodeParser = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.CodeParser_ParserId.UrlParameterName:   grmi.NewConditionItem(meta.CodeParser_ParserId, grmi.Equal, true),
		meta.CodeParser_StartPos.UrlParameterName:   grmi.NewConditionItem(meta.CodeParser_StartPos, grmi.Equal, false),
		meta.CodeParser_Length.UrlParameterName:     grmi.NewConditionItem(meta.CodeParser_Length, grmi.Equal, false),
		meta.CodeParser_ParserType.UrlParameterName: grmi.NewConditionItem(meta.CodeParser_ParserType, grmi.Equal, false),
		meta.CodeParser_Descr.UrlParameterName:      grmi.NewConditionItem(meta.CodeParser_Descr, grmi.Equal, false),
		meta.CodeParser_LastModify.UrlParameterName: grmi.NewConditionItem(meta.CodeParser_LastModify, grmi.Approximate, false),
		meta.CodeParser_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.CodeParser_LastUser, grmi.Equal, false),
		meta.CodeParser_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.CodeParser_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//CodeParser的默认分页查询条件
var DefaultConditionOfCodeParserAndPaging = grmi.NewCondition(
	DefaultConditionOfCodeParser.Items,
	grmi.NewPaging(),
)

type CodeParserServiceImplement struct {
}

func (self *CodeParserServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/CodeParser.service.impl.go", "SelectCodeParser", "查询CodeParser")

	condition := DefaultConditionOfCodeParserAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewCodeParserDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *CodeParserServiceImplement) InsertOne(user *models.Usertab, entity *model.CodeParser) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/CodeParser.service.impl.go", "InsertOneCodeParser", "插入一个CodeParser")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewCodeParserDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ParserId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *CodeParserServiceImplement) DeleteOne(user *models.Usertab, parserId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/CodeParser.service.impl.go", "DeleteOneCodeParser", "删除一个CodeParser")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewCodeParserDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(parserId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(parserId)
	if err != nil {
		return err
	}
	return nil
}

func (self *CodeParserServiceImplement) SelectOne(user *models.Usertab, parserId string) (*model.CodeParser, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/CodeParser.service.impl.go", "SelectOneCodeParser", "查询一个CodeParser")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewCodeParserDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(parserId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *CodeParserServiceImplement) UpdateOne(user *models.Usertab, entity *model.CodeParser) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/CodeParser.service.impl.go", "UpdateOneCodeParser", "修改一个CodeParser")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewCodeParserDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ParserId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewCodeParserServiceImplement() *CodeParserServiceImplement {
	return &CodeParserServiceImplement{}
}
