package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//CostCenter的默认查询条件
var DefaultConditionOfCostCenter = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.CostCenter_CostCenterId.UrlParameterName: grmi.NewConditionItem(meta.CostCenter_CostCenterId, grmi.Equal, true),
		meta.CostCenter_Descr.UrlParameterName:        grmi.NewConditionItem(meta.CostCenter_Descr, grmi.Equal, false),
		meta.CostCenter_HourRate.UrlParameterName:     grmi.NewConditionItem(meta.CostCenter_HourRate, grmi.Equal, false),
		meta.CostCenter_CCCVal1.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCCVal1, grmi.Equal, false),
		meta.CostCenter_CCCVal2.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCCVal2, grmi.Equal, false),
		meta.CostCenter_CCIVal1.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCIVal1, grmi.Equal, false),
		meta.CostCenter_CCIVal2.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCIVal2, grmi.Equal, false),
		meta.CostCenter_CCFVal1.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCFVal1, grmi.Equal, false),
		meta.CostCenter_CCFVal2.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCFVal2, grmi.Equal, false),
		meta.CostCenter_LastModify.UrlParameterName:   grmi.NewConditionItem(meta.CostCenter_LastModify, grmi.Approximate, false),
		meta.CostCenter_LastUser.UrlParameterName:     grmi.NewConditionItem(meta.CostCenter_LastUser, grmi.Equal, false),
		meta.CostCenter_CreateTime.UrlParameterName:   grmi.NewConditionItem(meta.CostCenter_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//CostCenter的默认分页查询条件
var DefaultConditionOfCostCenterAndPaging = grmi.NewCondition(
	DefaultConditionOfCostCenter.Items,
	grmi.NewPaging(),
)

type CostCenterServiceImplement struct {
}

func (self *CostCenterServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/CostCenter.service.impl.go", "SelectCostCenter", "查询CostCenter")

	condition := DefaultConditionOfCostCenterAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *CostCenterServiceImplement) InsertOne(user *models.Usertab, entity *model.CostCenter) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/CostCenter.service.impl.go", "InsertOneCostCenter", "插入一个CostCenter")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.CostCenterId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *CostCenterServiceImplement) DeleteOne(user *models.Usertab, costCenterId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/CostCenter.service.impl.go", "DeleteOneCostCenter", "删除一个CostCenter")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(costCenterId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(costCenterId)
	if err != nil {
		return err
	}
	return nil
}

func (self *CostCenterServiceImplement) SelectOne(user *models.Usertab, costCenterId string) (*model.CostCenter, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/CostCenter.service.impl.go", "SelectOneCostCenter", "查询一个CostCenter")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(costCenterId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *CostCenterServiceImplement) UpdateOne(user *models.Usertab, entity *model.CostCenter) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/CostCenter.service.impl.go", "UpdateOneCostCenter", "修改一个CostCenter")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.CostCenterId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewCostCenterServiceImplement() *CostCenterServiceImplement {
	return &CostCenterServiceImplement{}
}
