package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//Plant的默认查询条件
var DefaultConditionOfPlant = grmi.NewCondition(
	map[string]grmi.ConditionItem{

		meta.Plant_Status.UrlParameterName:         grmi.NewConditionItem(meta.Plant_Status, grmi.Equal, false),
		meta.Plant_Name1.UrlParameterName:          grmi.NewConditionItem(meta.Plant_Name1, grmi.Equal, false),
		meta.Plant_Name2.UrlParameterName:          grmi.NewConditionItem(meta.Plant_Name2, grmi.Equal, false),
		meta.Plant_Logo.UrlParameterName:           grmi.NewConditionItem(meta.Plant_Logo, grmi.Equal, false),
		meta.Plant_Abrevname.UrlParameterName:      grmi.NewConditionItem(meta.Plant_Abrevname, grmi.Equal, false),
		meta.Plant_Country.UrlParameterName:        grmi.NewConditionItem(meta.Plant_Country, grmi.Equal, false),
		meta.Plant_Street.UrlParameterName:         grmi.NewConditionItem(meta.Plant_Street, grmi.Equal, false),
		meta.Plant_Address.UrlParameterName:        grmi.NewConditionItem(meta.Plant_Address, grmi.Equal, false),
		meta.Plant_PostCode.UrlParameterName:       grmi.NewConditionItem(meta.Plant_PostCode, grmi.Equal, false),
		meta.Plant_Phone.UrlParameterName:          grmi.NewConditionItem(meta.Plant_Phone, grmi.Equal, false),
		meta.Plant_Fax.UrlParameterName:            grmi.NewConditionItem(meta.Plant_Fax, grmi.Equal, false),
		meta.Plant_StartYear.UrlParameterName:      grmi.NewConditionItem(meta.Plant_StartYear, grmi.Equal, false),
		meta.Plant_EndYear.UrlParameterName:        grmi.NewConditionItem(meta.Plant_EndYear, grmi.Equal, false),
		meta.Plant_CompanyTitle.UrlParameterName:   grmi.NewConditionItem(meta.Plant_CompanyTitle, grmi.Equal, false),
		meta.Plant_CompanyAddress.UrlParameterName: grmi.NewConditionItem(meta.Plant_CompanyAddress, grmi.Equal, false),
		meta.Plant_TaxId.UrlParameterName:          grmi.NewConditionItem(meta.Plant_TaxId, grmi.Equal, false),
		meta.Plant_AccountBank.UrlParameterName:    grmi.NewConditionItem(meta.Plant_AccountBank, grmi.Equal, false),
		meta.Plant_AccountNr.UrlParameterName:      grmi.NewConditionItem(meta.Plant_AccountNr, grmi.Equal, false),
		meta.Plant_Currency.UrlParameterName:       grmi.NewConditionItem(meta.Plant_Currency, grmi.Equal, false),
		meta.Plant_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.Plant_LastModify, grmi.Approximate, false),
		meta.Plant_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.Plant_LastUser, grmi.Equal, false),
		meta.Plant_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.Plant_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//Plant的默认分页查询条件
var DefaultConditionOfPlantAndPaging = grmi.NewCondition(
	DefaultConditionOfPlant.Items,
	grmi.NewPaging(),
)

type PlantServiceImplement struct {
}

func (self *PlantServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Plant.service.impl.go", "SelectPlant", "查询Plant")

	condition := DefaultConditionOfPlantAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewPlantDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *PlantServiceImplement) InsertOne(user *models.Usertab, entity *model.Plant) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Plant.service.impl.go", "InsertOnePlant", "插入一个Plant")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPlantDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne()
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *PlantServiceImplement) DeleteOne(user *models.Usertab) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Plant.service.impl.go", "DeleteOnePlant", "删除一个Plant")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPlantDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne()
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne()
	if err != nil {
		return err
	}
	return nil
}

func (self *PlantServiceImplement) SelectOne(user *models.Usertab) (*model.Plant, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Plant.service.impl.go", "SelectOnePlant", "查询一个Plant")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPlantDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne()
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *PlantServiceImplement) UpdateOne(user *models.Usertab, entity *model.Plant) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Plant.service.impl.go", "UpdateOnePlant", "修改一个Plant")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPlantDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne()
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewPlantServiceImplement() *PlantServiceImplement {
	return &PlantServiceImplement{}
}
