package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//StatusColor的默认查询条件
var DefaultConditionOfStatusColor = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.StatusColor_StatusObj.UrlParameterName:      grmi.NewConditionItem(meta.StatusColor_StatusObj, grmi.Equal, true),
		meta.StatusColor_StatusVal.UrlParameterName:      grmi.NewConditionItem(meta.StatusColor_StatusVal, grmi.Equal, true),
		meta.StatusColor_Descr.UrlParameterName:          grmi.NewConditionItem(meta.StatusColor_Descr, grmi.Equal, false),
		meta.StatusColor_StatusRgb.UrlParameterName:      grmi.NewConditionItem(meta.StatusColor_StatusRgb, grmi.Equal, false),
		meta.StatusColor_StatusHexColor.UrlParameterName: grmi.NewConditionItem(meta.StatusColor_StatusHexColor, grmi.Equal, false),
		meta.StatusColor_StatusBitmap.UrlParameterName:   grmi.NewConditionItem(meta.StatusColor_StatusBitmap, grmi.Equal, false),
		meta.StatusColor_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.StatusColor_LastModify, grmi.Approximate, false),
		meta.StatusColor_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.StatusColor_LastUser, grmi.Equal, false),
		meta.StatusColor_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.StatusColor_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//StatusColor的默认分页查询条件
var DefaultConditionOfStatusColorAndPaging = grmi.NewCondition(
	DefaultConditionOfStatusColor.Items,
	grmi.NewPaging(),
)

type StatusColorServiceImplement struct {
}

func (self *StatusColorServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/StatusColor.service.impl.go", "SelectStatusColor", "查询StatusColor")

	condition := DefaultConditionOfStatusColorAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewStatusColorDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *StatusColorServiceImplement) InsertOne(user *models.Usertab, entity *model.StatusColor) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/StatusColor.service.impl.go", "InsertOneStatusColor", "插入一个StatusColor")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewStatusColorDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.StatusObj, entity.StatusVal)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *StatusColorServiceImplement) DeleteOne(user *models.Usertab, statusObj string, statusVal string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/StatusColor.service.impl.go", "DeleteOneStatusColor", "删除一个StatusColor")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewStatusColorDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(statusObj, statusVal)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(statusObj, statusVal)
	if err != nil {
		return err
	}
	return nil
}

func (self *StatusColorServiceImplement) SelectOne(user *models.Usertab, statusObj string, statusVal string) (*model.StatusColor, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/StatusColor.service.impl.go", "SelectOneStatusColor", "查询一个StatusColor")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewStatusColorDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(statusObj, statusVal)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *StatusColorServiceImplement) UpdateOne(user *models.Usertab, entity *model.StatusColor) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/StatusColor.service.impl.go", "UpdateOneStatusColor", "修改一个StatusColor")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewStatusColorDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.StatusObj, entity.StatusVal)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewStatusColorServiceImplement() *StatusColorServiceImplement {
	return &StatusColorServiceImplement{}
}
