package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//Uom的默认查询条件
var DefaultConditionOfUom = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Uom_UomId.UrlParameterName:          grmi.NewConditionItem(meta.Uom_UomId, grmi.Equal, true),
		meta.Uom_UomName.UrlParameterName:        grmi.NewConditionItem(meta.Uom_UomName, grmi.Equal, false),
		meta.Uom_UomType.UrlParameterName:        grmi.NewConditionItem(meta.Uom_UomType, grmi.Equal, false),
		meta.Uom_BasicUomToggle.UrlParameterName: grmi.NewConditionItem(meta.Uom_BasicUomToggle, grmi.Equal, false),
		meta.Uom_BasicUom.UrlParameterName:       grmi.NewConditionItem(meta.Uom_BasicUom, grmi.Equal, false),
		meta.Uom_ConvertRatio.UrlParameterName:   grmi.NewConditionItem(meta.Uom_ConvertRatio, grmi.Equal, false),
		meta.Uom_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.Uom_LastModify, grmi.Approximate, false),
		meta.Uom_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.Uom_LastUser, grmi.Equal, false),
		meta.Uom_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.Uom_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//Uom的默认分页查询条件
var DefaultConditionOfUomAndPaging = grmi.NewCondition(
	DefaultConditionOfUom.Items,
	grmi.NewPaging(),
)

type UomServiceImplement struct {
}

func (self *UomServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Uom.service.impl.go", "SelectUom", "查询Uom")

	condition := DefaultConditionOfUomAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewUomDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *UomServiceImplement) InsertOne(user *models.Usertab, entity *model.Uom) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Uom.service.impl.go", "InsertOneUom", "插入一个Uom")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewUomDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.UomId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *UomServiceImplement) DeleteOne(user *models.Usertab, uomId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Uom.service.impl.go", "DeleteOneUom", "删除一个Uom")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewUomDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(uomId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(uomId)
	if err != nil {
		return err
	}
	return nil
}

func (self *UomServiceImplement) SelectOne(user *models.Usertab, uomId string) (*model.Uom, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Uom.service.impl.go", "SelectOneUom", "查询一个Uom")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewUomDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(uomId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *UomServiceImplement) UpdateOne(user *models.Usertab, entity *model.Uom) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/Uom.service.impl.go", "UpdateOneUom", "修改一个Uom")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewUomDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.UomId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewUomServiceImplement() *UomServiceImplement {
	return &UomServiceImplement{}
}
