package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//WeekModelLst的默认查询条件
var DefaultConditionOfWeekModelLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WeekModelLst_WeekModelNr.UrlParameterName: grmi.NewConditionItem(meta.WeekModelLst_WeekModelNr, grmi.Equal, true),
		meta.WeekModelLst_WorkDate.UrlParameterName:    grmi.NewConditionItem(meta.WeekModelLst_WorkDate, grmi.Equal, true),
		meta.WeekModelLst_DayModelNr.UrlParameterName:  grmi.NewConditionItem(meta.WeekModelLst_DayModelNr, grmi.Equal, false),
		meta.WeekModelLst_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.WeekModelLst_LastModify, grmi.Approximate, false),
		meta.WeekModelLst_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.WeekModelLst_LastUser, grmi.Equal, false),
		meta.WeekModelLst_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.WeekModelLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//WeekModelLst的默认分页查询条件
var DefaultConditionOfWeekModelLstAndPaging = grmi.NewCondition(
	DefaultConditionOfWeekModelLst.Items,
	grmi.NewPaging(),
)

type WeekModelLstServiceImplement struct {
}

func (self *WeekModelLstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WeekModelLst.service.impl.go", "SelectWeekModelLst", "查询WeekModelLst")

	condition := DefaultConditionOfWeekModelLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWeekModelLstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *WeekModelLstServiceImplement) InsertOne(user *models.Usertab, entity *model.WeekModelLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WeekModelLst.service.impl.go", "InsertOneWeekModelLst", "插入一个WeekModelLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWeekModelLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WeekModelNr, entity.WorkDate)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *WeekModelLstServiceImplement) DeleteOne(user *models.Usertab, weekModelNr int, workDate int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WeekModelLst.service.impl.go", "DeleteOneWeekModelLst", "删除一个WeekModelLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWeekModelLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(weekModelNr, workDate)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(weekModelNr, workDate)
	if err != nil {
		return err
	}
	return nil
}

func (self *WeekModelLstServiceImplement) SelectOne(user *models.Usertab, weekModelNr int, workDate int) (*model.WeekModelLst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WeekModelLst.service.impl.go", "SelectOneWeekModelLst", "查询一个WeekModelLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWeekModelLstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(weekModelNr, workDate)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *WeekModelLstServiceImplement) UpdateOne(user *models.Usertab, entity *model.WeekModelLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WeekModelLst.service.impl.go", "UpdateOneWeekModelLst", "修改一个WeekModelLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWeekModelLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WeekModelNr, entity.WorkDate)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewWeekModelLstServiceImplement() *WeekModelLstServiceImplement {
	return &WeekModelLstServiceImplement{}
}
