package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//WorkCalendar的默认查询条件
var DefaultConditionOfWorkCalendar = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkCalendar_WorkCalendarNr.UrlParameterName: grmi.NewConditionItem(meta.WorkCalendar_WorkCalendarNr, grmi.Equal, true),
		meta.WorkCalendar_Descr.UrlParameterName:          grmi.NewConditionItem(meta.WorkCalendar_Descr, grmi.Equal, false),
		meta.WorkCalendar_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.WorkCalendar_LastModify, grmi.Approximate, false),
		meta.WorkCalendar_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.WorkCalendar_LastUser, grmi.Equal, false),
		meta.WorkCalendar_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.WorkCalendar_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//WorkCalendar的默认分页查询条件
var DefaultConditionOfWorkCalendarAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkCalendar.Items,
	grmi.NewPaging(),
)

type WorkCalendarServiceImplement struct {
}

func (self *WorkCalendarServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkCalendar.service.impl.go", "SelectWorkCalendar", "查询WorkCalendar")

	condition := DefaultConditionOfWorkCalendarAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkCalendarDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *WorkCalendarServiceImplement) InsertOne(user *models.Usertab, entity *model.WorkCalendar) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkCalendar.service.impl.go", "InsertOneWorkCalendar", "插入一个WorkCalendar")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkCalendarDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkCalendarNr)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkCalendarServiceImplement) DeleteOne(user *models.Usertab, workCalendarNr int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkCalendar.service.impl.go", "DeleteOneWorkCalendar", "删除一个WorkCalendar")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkCalendarDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(workCalendarNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workCalendarNr)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkCalendarServiceImplement) SelectOne(user *models.Usertab, workCalendarNr int) (*model.WorkCalendar, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkCalendar.service.impl.go", "SelectOneWorkCalendar", "查询一个WorkCalendar")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkCalendarDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(workCalendarNr)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *WorkCalendarServiceImplement) UpdateOne(user *models.Usertab, entity *model.WorkCalendar) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkCalendar.service.impl.go", "UpdateOneWorkCalendar", "修改一个WorkCalendar")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkCalendarDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkCalendarNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewWorkCalendarServiceImplement() *WorkCalendarServiceImplement {
	return &WorkCalendarServiceImplement{}
}
