package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//WorkCalendarLst的默认查询条件
var DefaultConditionOfWorkCalendarLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkCalendarLst_WorkCalendarNr.UrlParameterName: grmi.NewConditionItem(meta.WorkCalendarLst_WorkCalendarNr, grmi.Equal, true),
		meta.WorkCalendarLst_WorkDate.UrlParameterName:       grmi.NewConditionItem(meta.WorkCalendarLst_WorkDate, grmi.Equal, true),
		meta.WorkCalendarLst_DayModelNr.UrlParameterName:     grmi.NewConditionItem(meta.WorkCalendarLst_DayModelNr, grmi.Equal, false),
		meta.WorkCalendarLst_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.WorkCalendarLst_LastModify, grmi.Approximate, false),
		meta.WorkCalendarLst_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.WorkCalendarLst_LastUser, grmi.Equal, false),
		meta.WorkCalendarLst_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.WorkCalendarLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//WorkCalendarLst的默认分页查询条件
var DefaultConditionOfWorkCalendarLstAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkCalendarLst.Items,
	grmi.NewPaging(),
)

type WorkCalendarLstServiceImplement struct {
}

func (self *WorkCalendarLstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkCalendarLst.service.impl.go", "SelectWorkCalendarLst", "查询WorkCalendarLst")

	condition := DefaultConditionOfWorkCalendarLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkCalendarLstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *WorkCalendarLstServiceImplement) InsertOne(user *models.Usertab, entity *model.WorkCalendarLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkCalendarLst.service.impl.go", "InsertOneWorkCalendarLst", "插入一个WorkCalendarLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkCalendarLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkCalendarNr, entity.WorkDate)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkCalendarLstServiceImplement) DeleteOne(user *models.Usertab, workCalendarNr int, workDate int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkCalendarLst.service.impl.go", "DeleteOneWorkCalendarLst", "删除一个WorkCalendarLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkCalendarLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(workCalendarNr, workDate)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workCalendarNr, workDate)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkCalendarLstServiceImplement) SelectOne(user *models.Usertab, workCalendarNr int, workDate int) (*model.WorkCalendarLst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkCalendarLst.service.impl.go", "SelectOneWorkCalendarLst", "查询一个WorkCalendarLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkCalendarLstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(workCalendarNr, workDate)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *WorkCalendarLstServiceImplement) UpdateOne(user *models.Usertab, entity *model.WorkCalendarLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkCalendarLst.service.impl.go", "UpdateOneWorkCalendarLst", "修改一个WorkCalendarLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkCalendarLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkCalendarNr, entity.WorkDate)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewWorkCalendarLstServiceImplement() *WorkCalendarLstServiceImplement {
	return &WorkCalendarLstServiceImplement{}
}
