package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//WorkLine的默认查询条件
var DefaultConditionOfWorkLine = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkLine_WorkLineid.UrlParameterName:              grmi.NewConditionItem(meta.WorkLine_WorkLineid, grmi.Equal, true),
		meta.WorkLine_Descr.UrlParameterName:                   grmi.NewConditionItem(meta.WorkLine_Descr, grmi.Equal, false),
		meta.WorkLine_LineType.UrlParameterName:                grmi.NewConditionItem(meta.WorkLine_LineType, grmi.Equal, false),
		meta.WorkLine_LinePlanMode.UrlParameterName:            grmi.NewConditionItem(meta.WorkLine_LinePlanMode, grmi.Equal, false),
		meta.WorkLine_WeekModelNr.UrlParameterName:             grmi.NewConditionItem(meta.WorkLine_WeekModelNr, grmi.Equal, false),
		meta.WorkLine_WorkCalendarNr.UrlParameterName:          grmi.NewConditionItem(meta.WorkLine_WorkCalendarNr, grmi.Equal, false),
		meta.WorkLine_Location.UrlParameterName:                grmi.NewConditionItem(meta.WorkLine_Location, grmi.Equal, false),
		meta.WorkLine_CostCenterId.UrlParameterName:            grmi.NewConditionItem(meta.WorkLine_CostCenterId, grmi.Equal, false),
		meta.WorkLine_CostRate.UrlParameterName:                grmi.NewConditionItem(meta.WorkLine_CostRate, grmi.Equal, false),
		meta.WorkLine_ProdEff.UrlParameterName:                 grmi.NewConditionItem(meta.WorkLine_ProdEff, grmi.Equal, false),
		meta.WorkLine_ReqWorkers.UrlParameterName:              grmi.NewConditionItem(meta.WorkLine_ReqWorkers, grmi.Equal, false),
		meta.WorkLine_Pos.UrlParameterName:                     grmi.NewConditionItem(meta.WorkLine_Pos, grmi.Equal, false),
		meta.WorkLine_TaskQueueSortWay.UrlParameterName:        grmi.NewConditionItem(meta.WorkLine_TaskQueueSortWay, grmi.Equal, false),
		meta.WorkLine_MultiQueueMixSortToggle.UrlParameterName: grmi.NewConditionItem(meta.WorkLine_MultiQueueMixSortToggle, grmi.Equal, false),
		meta.WorkLine_TaskQueueMixSortWay.UrlParameterName:     grmi.NewConditionItem(meta.WorkLine_TaskQueueMixSortWay, grmi.Equal, false),
		meta.WorkLine_MixSortLogic.UrlParameterName:            grmi.NewConditionItem(meta.WorkLine_MixSortLogic, grmi.Equal, false),
		meta.WorkLine_TaskReleaseWay.UrlParameterName:          grmi.NewConditionItem(meta.WorkLine_TaskReleaseWay, grmi.Equal, false),
		meta.WorkLine_ReleaseQtyParameter.UrlParameterName:     grmi.NewConditionItem(meta.WorkLine_ReleaseQtyParameter, grmi.Equal, false),
		meta.WorkLine_ReleaseTimeParameter.UrlParameterName:    grmi.NewConditionItem(meta.WorkLine_ReleaseTimeParameter, grmi.Approximate, false),
		meta.WorkLine_ReleaseCtrlParameter.UrlParameterName:    grmi.NewConditionItem(meta.WorkLine_ReleaseCtrlParameter, grmi.Equal, false),
		meta.WorkLine_LastModify.UrlParameterName:              grmi.NewConditionItem(meta.WorkLine_LastModify, grmi.Approximate, false),
		meta.WorkLine_LastUser.UrlParameterName:                grmi.NewConditionItem(meta.WorkLine_LastUser, grmi.Equal, false),
		meta.WorkLine_CreateTime.UrlParameterName:              grmi.NewConditionItem(meta.WorkLine_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//WorkLine的默认分页查询条件
var DefaultConditionOfWorkLineAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkLine.Items,
	grmi.NewPaging(),
)

type WorkLineServiceImplement struct {
}

func (self *WorkLineServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLine.service.impl.go", "SelectWorkLine", "查询WorkLine")

	condition := DefaultConditionOfWorkLineAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *WorkLineServiceImplement) InsertOne(user *models.Usertab, entity *model.WorkLine) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLine.service.impl.go", "InsertOneWorkLine", "插入一个WorkLine")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineid)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkLineServiceImplement) DeleteOne(user *models.Usertab, workLineid string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLine.service.impl.go", "DeleteOneWorkLine", "删除一个WorkLine")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(workLineid)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workLineid)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkLineServiceImplement) SelectOne(user *models.Usertab, workLineid string) (*model.WorkLine, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLine.service.impl.go", "SelectOneWorkLine", "查询一个WorkLine")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(workLineid)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *WorkLineServiceImplement) UpdateOne(user *models.Usertab, entity *model.WorkLine) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLine.service.impl.go", "UpdateOneWorkLine", "修改一个WorkLine")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineid)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewWorkLineServiceImplement() *WorkLineServiceImplement {
	return &WorkLineServiceImplement{}
}
