package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//WorkLineSpecialDay的默认查询条件
var DefaultConditionOfWorkLineSpecialDay = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkLineSpecialDay_WorkLineid.UrlParameterName: grmi.NewConditionItem(meta.WorkLineSpecialDay_WorkLineid, grmi.Equal, true),
		meta.WorkLineSpecialDay_SpecialDay.UrlParameterName: grmi.NewConditionItem(meta.WorkLineSpecialDay_SpecialDay, grmi.Equal, true),
		meta.WorkLineSpecialDay_DayModelNr.UrlParameterName: grmi.NewConditionItem(meta.WorkLineSpecialDay_DayModelNr, grmi.Equal, false),
		meta.WorkLineSpecialDay_Descr.UrlParameterName:      grmi.NewConditionItem(meta.WorkLineSpecialDay_Descr, grmi.Equal, false),
		meta.WorkLineSpecialDay_LastModify.UrlParameterName: grmi.NewConditionItem(meta.WorkLineSpecialDay_LastModify, grmi.Approximate, false),
		meta.WorkLineSpecialDay_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.WorkLineSpecialDay_LastUser, grmi.Equal, false),
		meta.WorkLineSpecialDay_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.WorkLineSpecialDay_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//WorkLineSpecialDay的默认分页查询条件
var DefaultConditionOfWorkLineSpecialDayAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkLineSpecialDay.Items,
	grmi.NewPaging(),
)

type WorkLineSpecialDayServiceImplement struct {
}

func (self *WorkLineSpecialDayServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLineSpecialDay.service.impl.go", "SelectWorkLineSpecialDay", "查询WorkLineSpecialDay")

	condition := DefaultConditionOfWorkLineSpecialDayAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkLineSpecialDayDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *WorkLineSpecialDayServiceImplement) InsertOne(user *models.Usertab, entity *model.WorkLineSpecialDay) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLineSpecialDay.service.impl.go", "InsertOneWorkLineSpecialDay", "插入一个WorkLineSpecialDay")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineSpecialDayDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineid, entity.SpecialDay)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkLineSpecialDayServiceImplement) DeleteOne(user *models.Usertab, workLineid string, specialDay string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLineSpecialDay.service.impl.go", "DeleteOneWorkLineSpecialDay", "删除一个WorkLineSpecialDay")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineSpecialDayDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(workLineid, specialDay)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workLineid, specialDay)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkLineSpecialDayServiceImplement) SelectOne(user *models.Usertab, workLineid string, specialDay string) (*model.WorkLineSpecialDay, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLineSpecialDay.service.impl.go", "SelectOneWorkLineSpecialDay", "查询一个WorkLineSpecialDay")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineSpecialDayDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(workLineid, specialDay)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *WorkLineSpecialDayServiceImplement) UpdateOne(user *models.Usertab, entity *model.WorkLineSpecialDay) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLineSpecialDay.service.impl.go", "UpdateOneWorkLineSpecialDay", "修改一个WorkLineSpecialDay")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineSpecialDayDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineid, entity.SpecialDay)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewWorkLineSpecialDayServiceImplement() *WorkLineSpecialDayServiceImplement {
	return &WorkLineSpecialDayServiceImplement{}
}
