package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//WorkLineWorkShiftLst的默认查询条件
var DefaultConditionOfWorkLineWorkShiftLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkLineWorkShiftLst_WorkLineId.UrlParameterName:  grmi.NewConditionItem(meta.WorkLineWorkShiftLst_WorkLineId, grmi.Equal, true),
		meta.WorkLineWorkShiftLst_WorkDay.UrlParameterName:     grmi.NewConditionItem(meta.WorkLineWorkShiftLst_WorkDay, grmi.Equal, true),
		meta.WorkLineWorkShiftLst_Pos.UrlParameterName:         grmi.NewConditionItem(meta.WorkLineWorkShiftLst_Pos, grmi.Equal, true),
		meta.WorkLineWorkShiftLst_WorkShiftNr.UrlParameterName: grmi.NewConditionItem(meta.WorkLineWorkShiftLst_WorkShiftNr, grmi.Equal, false),
		meta.WorkLineWorkShiftLst_LevelId.UrlParameterName:     grmi.NewConditionItem(meta.WorkLineWorkShiftLst_LevelId, grmi.Equal, false),
		meta.WorkLineWorkShiftLst_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.WorkLineWorkShiftLst_LastModify, grmi.Approximate, false),
		meta.WorkLineWorkShiftLst_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.WorkLineWorkShiftLst_LastUser, grmi.Equal, false),
		meta.WorkLineWorkShiftLst_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.WorkLineWorkShiftLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//WorkLineWorkShiftLst的默认分页查询条件
var DefaultConditionOfWorkLineWorkShiftLstAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkLineWorkShiftLst.Items,
	grmi.NewPaging(),
)

type WorkLineWorkShiftLstServiceImplement struct {
}

func (self *WorkLineWorkShiftLstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLineWorkShiftLst.service.impl.go", "SelectWorkLineWorkShiftLst", "查询WorkLineWorkShiftLst")

	condition := DefaultConditionOfWorkLineWorkShiftLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkLineWorkShiftLstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *WorkLineWorkShiftLstServiceImplement) InsertOne(user *models.Usertab, entity *model.WorkLineWorkShiftLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLineWorkShiftLst.service.impl.go", "InsertOneWorkLineWorkShiftLst", "插入一个WorkLineWorkShiftLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineWorkShiftLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineId, entity.WorkDay, entity.Pos)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkLineWorkShiftLstServiceImplement) DeleteOne(user *models.Usertab, workLineId string, workDay string, pos int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLineWorkShiftLst.service.impl.go", "DeleteOneWorkLineWorkShiftLst", "删除一个WorkLineWorkShiftLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineWorkShiftLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(workLineId, workDay, pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workLineId, workDay, pos)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkLineWorkShiftLstServiceImplement) SelectOne(user *models.Usertab, workLineId string, workDay string, pos int) (*model.WorkLineWorkShiftLst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLineWorkShiftLst.service.impl.go", "SelectOneWorkLineWorkShiftLst", "查询一个WorkLineWorkShiftLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineWorkShiftLstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(workLineId, workDay, pos)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *WorkLineWorkShiftLstServiceImplement) UpdateOne(user *models.Usertab, entity *model.WorkLineWorkShiftLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkLineWorkShiftLst.service.impl.go", "UpdateOneWorkLineWorkShiftLst", "修改一个WorkLineWorkShiftLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkLineWorkShiftLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineId, entity.WorkDay, entity.Pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewWorkLineWorkShiftLstServiceImplement() *WorkLineWorkShiftLstServiceImplement {
	return &WorkLineWorkShiftLstServiceImplement{}
}
