package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//WorkShift的默认查询条件
var DefaultConditionOfWorkShift = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkShift_WorkShiftNr.UrlParameterName:    grmi.NewConditionItem(meta.WorkShift_WorkShiftNr, grmi.Equal, true),
		meta.WorkShift_Descr.UrlParameterName:          grmi.NewConditionItem(meta.WorkShift_Descr, grmi.Equal, false),
		meta.WorkShift_Abrev.UrlParameterName:          grmi.NewConditionItem(meta.WorkShift_Abrev, grmi.Equal, false),
		meta.WorkShift_HexColor.UrlParameterName:       grmi.NewConditionItem(meta.WorkShift_HexColor, grmi.Equal, false),
		meta.WorkShift_PlanPersonQty.UrlParameterName:  grmi.NewConditionItem(meta.WorkShift_PlanPersonQty, grmi.Equal, false),
		meta.WorkShift_PlanEfficiency.UrlParameterName: grmi.NewConditionItem(meta.WorkShift_PlanEfficiency, grmi.Equal, false),
		meta.WorkShift_SBeg.UrlParameterName:           grmi.NewConditionItem(meta.WorkShift_SBeg, grmi.Equal, false),
		meta.WorkShift_SEnd.UrlParameterName:           grmi.NewConditionItem(meta.WorkShift_SEnd, grmi.Equal, false),
		meta.WorkShift_SLen.UrlParameterName:           grmi.NewConditionItem(meta.WorkShift_SLen, grmi.Equal, false),
		meta.WorkShift_SB1Beg.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB1Beg, grmi.Equal, false),
		meta.WorkShift_SB1End.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB1End, grmi.Equal, false),
		meta.WorkShift_SB2Beg.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB2Beg, grmi.Equal, false),
		meta.WorkShift_SB2End.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB2End, grmi.Equal, false),
		meta.WorkShift_SB3Beg.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB3Beg, grmi.Equal, false),
		meta.WorkShift_SB3End.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB3End, grmi.Equal, false),
		meta.WorkShift_SB4Beg.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB4Beg, grmi.Equal, false),
		meta.WorkShift_SB4End.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB4End, grmi.Equal, false),
		meta.WorkShift_SB5Beg.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB5Beg, grmi.Equal, false),
		meta.WorkShift_SB5End.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB5End, grmi.Equal, false),
		meta.WorkShift_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.WorkShift_LastModify, grmi.Approximate, false),
		meta.WorkShift_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.WorkShift_LastUser, grmi.Equal, false),
		meta.WorkShift_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.WorkShift_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//WorkShift的默认分页查询条件
var DefaultConditionOfWorkShiftAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkShift.Items,
	grmi.NewPaging(),
)

type WorkShiftServiceImplement struct {
}

func (self *WorkShiftServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkShift.service.impl.go", "SelectWorkShift", "查询WorkShift")

	condition := DefaultConditionOfWorkShiftAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkShiftDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *WorkShiftServiceImplement) InsertOne(user *models.Usertab, entity *model.WorkShift) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkShift.service.impl.go", "InsertOneWorkShift", "插入一个WorkShift")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkShiftDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkShiftNr)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkShiftServiceImplement) DeleteOne(user *models.Usertab, workShiftNr int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkShift.service.impl.go", "DeleteOneWorkShift", "删除一个WorkShift")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkShiftDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(workShiftNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workShiftNr)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkShiftServiceImplement) SelectOne(user *models.Usertab, workShiftNr int) (*model.WorkShift, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkShift.service.impl.go", "SelectOneWorkShift", "查询一个WorkShift")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkShiftDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(workShiftNr)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *WorkShiftServiceImplement) UpdateOne(user *models.Usertab, entity *model.WorkShift) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkShift.service.impl.go", "UpdateOneWorkShift", "修改一个WorkShift")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkShiftDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkShiftNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewWorkShiftServiceImplement() *WorkShiftServiceImplement {
	return &WorkShiftServiceImplement{}
}
