package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/base"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/base"
	model "leit.com/LAPP_GAAS_GFrame/models/base"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//WorkShiftEffLst的默认查询条件
var DefaultConditionOfWorkShiftEffLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkShiftEffLst_WorkShiftNr.UrlParameterName:      grmi.NewConditionItem(meta.WorkShiftEffLst_WorkShiftNr, grmi.Equal, true),
		meta.WorkShiftEffLst_LevelId.UrlParameterName:          grmi.NewConditionItem(meta.WorkShiftEffLst_LevelId, grmi.Equal, true),
		meta.WorkShiftEffLst_Descr.UrlParameterName:            grmi.NewConditionItem(meta.WorkShiftEffLst_Descr, grmi.Equal, false),
		meta.WorkShiftEffLst_PlanPersonUclQty.UrlParameterName: grmi.NewConditionItem(meta.WorkShiftEffLst_PlanPersonUclQty, grmi.Equal, false),
		meta.WorkShiftEffLst_PlanPersonLclQty.UrlParameterName: grmi.NewConditionItem(meta.WorkShiftEffLst_PlanPersonLclQty, grmi.Equal, false),
		meta.WorkShiftEffLst_PlanEfficiency.UrlParameterName:   grmi.NewConditionItem(meta.WorkShiftEffLst_PlanEfficiency, grmi.Equal, false),
		meta.WorkShiftEffLst_LastModify.UrlParameterName:       grmi.NewConditionItem(meta.WorkShiftEffLst_LastModify, grmi.Approximate, false),
		meta.WorkShiftEffLst_LastUser.UrlParameterName:         grmi.NewConditionItem(meta.WorkShiftEffLst_LastUser, grmi.Equal, false),
		meta.WorkShiftEffLst_CreateTime.UrlParameterName:       grmi.NewConditionItem(meta.WorkShiftEffLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//WorkShiftEffLst的默认分页查询条件
var DefaultConditionOfWorkShiftEffLstAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkShiftEffLst.Items,
	grmi.NewPaging(),
)

type WorkShiftEffLstServiceImplement struct {
}

func (self *WorkShiftEffLstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkShiftEffLst.service.impl.go", "SelectWorkShiftEffLst", "查询WorkShiftEffLst")

	condition := DefaultConditionOfWorkShiftEffLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkShiftEffLstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *WorkShiftEffLstServiceImplement) InsertOne(user *models.Usertab, entity *model.WorkShiftEffLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkShiftEffLst.service.impl.go", "InsertOneWorkShiftEffLst", "插入一个WorkShiftEffLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkShiftEffLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkShiftNr, entity.LevelId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkShiftEffLstServiceImplement) DeleteOne(user *models.Usertab, workShiftNr int, levelId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkShiftEffLst.service.impl.go", "DeleteOneWorkShiftEffLst", "删除一个WorkShiftEffLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkShiftEffLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(workShiftNr, levelId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workShiftNr, levelId)
	if err != nil {
		return err
	}
	return nil
}

func (self *WorkShiftEffLstServiceImplement) SelectOne(user *models.Usertab, workShiftNr int, levelId string) (*model.WorkShiftEffLst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkShiftEffLst.service.impl.go", "SelectOneWorkShiftEffLst", "查询一个WorkShiftEffLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkShiftEffLstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(workShiftNr, levelId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *WorkShiftEffLstServiceImplement) UpdateOne(user *models.Usertab, entity *model.WorkShiftEffLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/base/implments/WorkShiftEffLst.service.impl.go", "UpdateOneWorkShiftEffLst", "修改一个WorkShiftEffLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewWorkShiftEffLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkShiftNr, entity.LevelId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewWorkShiftEffLstServiceImplement() *WorkShiftEffLstServiceImplement {
	return &WorkShiftEffLstServiceImplement{}
}
