package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/log"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//PackOrder的默认查询条件
var DefaultConditionOfPackOrder = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.PackOrder_PackOrderId.UrlParameterName:     grmi.NewConditionItem(meta.PackOrder_PackOrderId, grmi.Equal, true),
		meta.PackOrder_OrderInfo.UrlParameterName:       grmi.NewConditionItem(meta.PackOrder_OrderInfo, grmi.Equal, false),
		meta.PackOrder_PackTemplateId.UrlParameterName:  grmi.NewConditionItem(meta.PackOrder_PackTemplateId, grmi.Equal, false),
		meta.PackOrder_PackTypeId.UrlParameterName:      grmi.NewConditionItem(meta.PackOrder_PackTypeId, grmi.Equal, false),
		meta.PackOrder_TerminalId.UrlParameterName:      grmi.NewConditionItem(meta.PackOrder_TerminalId, grmi.Equal, false),
		meta.PackOrder_WorkplaceId.UrlParameterName:     grmi.NewConditionItem(meta.PackOrder_WorkplaceId, grmi.Equal, false),
		meta.PackOrder_PersonNr.UrlParameterName:        grmi.NewConditionItem(meta.PackOrder_PersonNr, grmi.Equal, false),
		meta.PackOrder_ShiftId.UrlParameterName:         grmi.NewConditionItem(meta.PackOrder_ShiftId, grmi.Equal, false),
		meta.PackOrder_MaterialId.UrlParameterName:      grmi.NewConditionItem(meta.PackOrder_MaterialId, grmi.Equal, false),
		meta.PackOrder_Status.UrlParameterName:          grmi.NewConditionItem(meta.PackOrder_Status, grmi.Equal, false),
		meta.PackOrder_ShortPack.UrlParameterName:       grmi.NewConditionItem(meta.PackOrder_ShortPack, grmi.Equal, false),
		meta.PackOrder_ShortBy.UrlParameterName:         grmi.NewConditionItem(meta.PackOrder_ShortBy, grmi.Equal, false),
		meta.PackOrder_ShortTime.UrlParameterName:       grmi.NewConditionItem(meta.PackOrder_ShortTime, grmi.Approximate, false),
		meta.PackOrder_ShipStatus.UrlParameterName:      grmi.NewConditionItem(meta.PackOrder_ShipStatus, grmi.Equal, false),
		meta.PackOrder_PlanQty.UrlParameterName:         grmi.NewConditionItem(meta.PackOrder_PlanQty, grmi.Equal, false),
		meta.PackOrder_ActQty.UrlParameterName:          grmi.NewConditionItem(meta.PackOrder_ActQty, grmi.Equal, false),
		meta.PackOrder_OpenTime.UrlParameterName:        grmi.NewConditionItem(meta.PackOrder_OpenTime, grmi.Approximate, false),
		meta.PackOrder_CloseTime.UrlParameterName:       grmi.NewConditionItem(meta.PackOrder_CloseTime, grmi.Approximate, false),
		meta.PackOrder_BackFlushStatus.UrlParameterName: grmi.NewConditionItem(meta.PackOrder_BackFlushStatus, grmi.Equal, false),
		meta.PackOrder_BackFlushTime.UrlParameterName:   grmi.NewConditionItem(meta.PackOrder_BackFlushTime, grmi.Approximate, false),
		meta.PackOrder_BoxSid.UrlParameterName:          grmi.NewConditionItem(meta.PackOrder_BoxSid, grmi.Equal, false),
		meta.PackOrder_SyncSid.UrlParameterName:         grmi.NewConditionItem(meta.PackOrder_SyncSid, grmi.Equal, false),
		meta.PackOrder_PKOCustC1.UrlParameterName:       grmi.NewConditionItem(meta.PackOrder_PKOCustC1, grmi.Equal, false),
		meta.PackOrder_PKOCustC2.UrlParameterName:       grmi.NewConditionItem(meta.PackOrder_PKOCustC2, grmi.Equal, false),
		meta.PackOrder_PKOCustI1.UrlParameterName:       grmi.NewConditionItem(meta.PackOrder_PKOCustI1, grmi.Equal, false),
		meta.PackOrder_PKOCustI2.UrlParameterName:       grmi.NewConditionItem(meta.PackOrder_PKOCustI2, grmi.Equal, false),
		meta.PackOrder_LastModify.UrlParameterName:      grmi.NewConditionItem(meta.PackOrder_LastModify, grmi.Approximate, false),
		meta.PackOrder_LastUser.UrlParameterName:        grmi.NewConditionItem(meta.PackOrder_LastUser, grmi.Equal, false),
		meta.PackOrder_CreateTime.UrlParameterName:      grmi.NewConditionItem(meta.PackOrder_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//PackOrder的默认分页查询条件
var DefaultConditionOfPackOrderAndPaging = grmi.NewCondition(
	DefaultConditionOfPackOrder.Items,
	grmi.NewPaging(),
)

type PackOrderServiceImplement struct {
}

func (self *PackOrderServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackOrder.service.impl.go", "SelectPackOrder", "查询PackOrder")

	condition := DefaultConditionOfPackOrderAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewPackOrderDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *PackOrderServiceImplement) InsertOne(user *models.Usertab, entity *model.PackOrder) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackOrder.service.impl.go", "InsertOnePackOrder", "插入一个PackOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackOrderDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.PackOrderId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *PackOrderServiceImplement) DeleteOne(user *models.Usertab, packOrderId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackOrder.service.impl.go", "DeleteOnePackOrder", "删除一个PackOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackOrderDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(packOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(packOrderId)
	if err != nil {
		return err
	}
	return nil
}

func (self *PackOrderServiceImplement) SelectOne(user *models.Usertab, packOrderId string) (*model.PackOrder, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackOrder.service.impl.go", "SelectOnePackOrder", "查询一个PackOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackOrderDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(packOrderId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *PackOrderServiceImplement) UpdateOne(user *models.Usertab, entity *model.PackOrder) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackOrder.service.impl.go", "UpdateOnePackOrder", "修改一个PackOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackOrderDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.PackOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewPackOrderServiceImplement() *PackOrderServiceImplement {
	return &PackOrderServiceImplement{}
}
