package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/log"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//PackOrderItemlst的默认查询条件
var DefaultConditionOfPackOrderItemlst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.PackOrderItemlst_PackOrderId.UrlParameterName:   grmi.NewConditionItem(meta.PackOrderItemlst_PackOrderId, grmi.Equal, true),
		meta.PackOrderItemlst_Pos.UrlParameterName:           grmi.NewConditionItem(meta.PackOrderItemlst_Pos, grmi.Equal, true),
		meta.PackOrderItemlst_PosCode.UrlParameterName:       grmi.NewConditionItem(meta.PackOrderItemlst_PosCode, grmi.Equal, false),
		meta.PackOrderItemlst_MaterialId.UrlParameterName:    grmi.NewConditionItem(meta.PackOrderItemlst_MaterialId, grmi.Equal, false),
		meta.PackOrderItemlst_SerialOrderId.UrlParameterName: grmi.NewConditionItem(meta.PackOrderItemlst_SerialOrderId, grmi.Equal, false),
		meta.PackOrderItemlst_PlanQty.UrlParameterName:       grmi.NewConditionItem(meta.PackOrderItemlst_PlanQty, grmi.Equal, false),
		meta.PackOrderItemlst_ActQty.UrlParameterName:        grmi.NewConditionItem(meta.PackOrderItemlst_ActQty, grmi.Equal, false),
		meta.PackOrderItemlst_Status.UrlParameterName:        grmi.NewConditionItem(meta.PackOrderItemlst_Status, grmi.Equal, false),
		meta.PackOrderItemlst_Seq.UrlParameterName:           grmi.NewConditionItem(meta.PackOrderItemlst_Seq, grmi.Equal, false),
		meta.PackOrderItemlst_PKOICustC1.UrlParameterName:    grmi.NewConditionItem(meta.PackOrderItemlst_PKOICustC1, grmi.Equal, false),
		meta.PackOrderItemlst_PKOICustC2.UrlParameterName:    grmi.NewConditionItem(meta.PackOrderItemlst_PKOICustC2, grmi.Equal, false),
		meta.PackOrderItemlst_PKOICustI1.UrlParameterName:    grmi.NewConditionItem(meta.PackOrderItemlst_PKOICustI1, grmi.Equal, false),
		meta.PackOrderItemlst_PKOICustI2.UrlParameterName:    grmi.NewConditionItem(meta.PackOrderItemlst_PKOICustI2, grmi.Equal, false),
		meta.PackOrderItemlst_LastModify.UrlParameterName:    grmi.NewConditionItem(meta.PackOrderItemlst_LastModify, grmi.Approximate, false),
		meta.PackOrderItemlst_LastUser.UrlParameterName:      grmi.NewConditionItem(meta.PackOrderItemlst_LastUser, grmi.Equal, false),
		meta.PackOrderItemlst_CreateTime.UrlParameterName:    grmi.NewConditionItem(meta.PackOrderItemlst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//PackOrderItemlst的默认分页查询条件
var DefaultConditionOfPackOrderItemlstAndPaging = grmi.NewCondition(
	DefaultConditionOfPackOrderItemlst.Items,
	grmi.NewPaging(),
)

type PackOrderItemlstServiceImplement struct {
}

func (self *PackOrderItemlstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackOrderItemlst.service.impl.go", "SelectPackOrderItemlst", "查询PackOrderItemlst")

	condition := DefaultConditionOfPackOrderItemlstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewPackOrderItemlstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *PackOrderItemlstServiceImplement) InsertOne(user *models.Usertab, entity *model.PackOrderItemlst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackOrderItemlst.service.impl.go", "InsertOnePackOrderItemlst", "插入一个PackOrderItemlst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackOrderItemlstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.PackOrderId, entity.Pos)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *PackOrderItemlstServiceImplement) DeleteOne(user *models.Usertab, packOrderId string, pos int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackOrderItemlst.service.impl.go", "DeleteOnePackOrderItemlst", "删除一个PackOrderItemlst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackOrderItemlstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(packOrderId, pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(packOrderId, pos)
	if err != nil {
		return err
	}
	return nil
}

func (self *PackOrderItemlstServiceImplement) SelectOne(user *models.Usertab, packOrderId string, pos int) (*model.PackOrderItemlst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackOrderItemlst.service.impl.go", "SelectOnePackOrderItemlst", "查询一个PackOrderItemlst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackOrderItemlstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(packOrderId, pos)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *PackOrderItemlstServiceImplement) UpdateOne(user *models.Usertab, entity *model.PackOrderItemlst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackOrderItemlst.service.impl.go", "UpdateOnePackOrderItemlst", "修改一个PackOrderItemlst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackOrderItemlstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.PackOrderId, entity.Pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewPackOrderItemlstServiceImplement() *PackOrderItemlstServiceImplement {
	return &PackOrderItemlstServiceImplement{}
}
