package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/log"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//PackTemplate的默认查询条件
var DefaultConditionOfPackTemplate = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.PackTemplate_PackTemplateId.UrlParameterName: grmi.NewConditionItem(meta.PackTemplate_PackTemplateId, grmi.Equal, true),
		meta.PackTemplate_Descr.UrlParameterName:          grmi.NewConditionItem(meta.PackTemplate_Descr, grmi.Equal, false),
		meta.PackTemplate_ActiveToggle.UrlParameterName:   grmi.NewConditionItem(meta.PackTemplate_ActiveToggle, grmi.Equal, false),
		meta.PackTemplate_PackTypeId.UrlParameterName:     grmi.NewConditionItem(meta.PackTemplate_PackTypeId, grmi.Equal, false),
		meta.PackTemplate_PrinterId.UrlParameterName:      grmi.NewConditionItem(meta.PackTemplate_PrinterId, grmi.Equal, false),
		meta.PackTemplate_TemplateFile.UrlParameterName:   grmi.NewConditionItem(meta.PackTemplate_TemplateFile, grmi.Equal, false),
		meta.PackTemplate_PrintQty.UrlParameterName:       grmi.NewConditionItem(meta.PackTemplate_PrintQty, grmi.Equal, false),
		meta.PackTemplate_PackOrderSn.UrlParameterName:    grmi.NewConditionItem(meta.PackTemplate_PackOrderSn, grmi.Equal, false),
		meta.PackTemplate_BoxSn.UrlParameterName:          grmi.NewConditionItem(meta.PackTemplate_BoxSn, grmi.Equal, false),
		meta.PackTemplate_SyncToggle.UrlParameterName:     grmi.NewConditionItem(meta.PackTemplate_SyncToggle, grmi.Equal, false),
		meta.PackTemplate_SyncSn.UrlParameterName:         grmi.NewConditionItem(meta.PackTemplate_SyncSn, grmi.Equal, false),
		meta.PackTemplate_TwoDSheet.UrlParameterName:      grmi.NewConditionItem(meta.PackTemplate_TwoDSheet, grmi.Equal, false),
		meta.PackTemplate_FullFillToggle.UrlParameterName: grmi.NewConditionItem(meta.PackTemplate_FullFillToggle, grmi.Equal, false),
		meta.PackTemplate_MaterialId.UrlParameterName:     grmi.NewConditionItem(meta.PackTemplate_MaterialId, grmi.Equal, false),
		meta.PackTemplate_PlanQty.UrlParameterName:        grmi.NewConditionItem(meta.PackTemplate_PlanQty, grmi.Equal, false),
		meta.PackTemplate_PKTMPCustC1.UrlParameterName:    grmi.NewConditionItem(meta.PackTemplate_PKTMPCustC1, grmi.Equal, false),
		meta.PackTemplate_PKTMPCustC2.UrlParameterName:    grmi.NewConditionItem(meta.PackTemplate_PKTMPCustC2, grmi.Equal, false),
		meta.PackTemplate_PKTMPCustI1.UrlParameterName:    grmi.NewConditionItem(meta.PackTemplate_PKTMPCustI1, grmi.Equal, false),
		meta.PackTemplate_PKTMPCustI2.UrlParameterName:    grmi.NewConditionItem(meta.PackTemplate_PKTMPCustI2, grmi.Equal, false),
		meta.PackTemplate_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.PackTemplate_LastModify, grmi.Approximate, false),
		meta.PackTemplate_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.PackTemplate_LastUser, grmi.Equal, false),
		meta.PackTemplate_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.PackTemplate_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//PackTemplate的默认分页查询条件
var DefaultConditionOfPackTemplateAndPaging = grmi.NewCondition(
	DefaultConditionOfPackTemplate.Items,
	grmi.NewPaging(),
)

type PackTemplateServiceImplement struct {
}

func (self *PackTemplateServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackTemplate.service.impl.go", "SelectPackTemplate", "查询PackTemplate")

	condition := DefaultConditionOfPackTemplateAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewPackTemplateDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *PackTemplateServiceImplement) InsertOne(user *models.Usertab, entity *model.PackTemplate) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackTemplate.service.impl.go", "InsertOnePackTemplate", "插入一个PackTemplate")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackTemplateDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.PackTemplateId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *PackTemplateServiceImplement) DeleteOne(user *models.Usertab, packTemplateId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackTemplate.service.impl.go", "DeleteOnePackTemplate", "删除一个PackTemplate")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackTemplateDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(packTemplateId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(packTemplateId)
	if err != nil {
		return err
	}
	return nil
}

func (self *PackTemplateServiceImplement) SelectOne(user *models.Usertab, packTemplateId string) (*model.PackTemplate, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackTemplate.service.impl.go", "SelectOnePackTemplate", "查询一个PackTemplate")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackTemplateDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(packTemplateId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *PackTemplateServiceImplement) UpdateOne(user *models.Usertab, entity *model.PackTemplate) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackTemplate.service.impl.go", "UpdateOnePackTemplate", "修改一个PackTemplate")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackTemplateDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.PackTemplateId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewPackTemplateServiceImplement() *PackTemplateServiceImplement {
	return &PackTemplateServiceImplement{}
}
