package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/log"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//PackType的默认查询条件
var DefaultConditionOfPackType = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.PackType_PackTypeId.UrlParameterName:       grmi.NewConditionItem(meta.PackType_PackTypeId, grmi.Equal, true),
		meta.PackType_Descr.UrlParameterName:            grmi.NewConditionItem(meta.PackType_Descr, grmi.Equal, false),
		meta.PackType_SortWay.UrlParameterName:          grmi.NewConditionItem(meta.PackType_SortWay, grmi.Equal, false),
		meta.PackType_VerifySlotToggle.UrlParameterName: grmi.NewConditionItem(meta.PackType_VerifySlotToggle, grmi.Equal, false),
		meta.PackType_VerifyRule.UrlParameterName:       grmi.NewConditionItem(meta.PackType_VerifyRule, grmi.Equal, false),
		meta.PackType_Length.UrlParameterName:           grmi.NewConditionItem(meta.PackType_Length, grmi.Equal, false),
		meta.PackType_Width.UrlParameterName:            grmi.NewConditionItem(meta.PackType_Width, grmi.Equal, false),
		meta.PackType_Height.UrlParameterName:           grmi.NewConditionItem(meta.PackType_Height, grmi.Equal, false),
		meta.PackType_SizeUom.UrlParameterName:          grmi.NewConditionItem(meta.PackType_SizeUom, grmi.Equal, false),
		meta.PackType_Weight.UrlParameterName:           grmi.NewConditionItem(meta.PackType_Weight, grmi.Equal, false),
		meta.PackType_WeightUom.UrlParameterName:        grmi.NewConditionItem(meta.PackType_WeightUom, grmi.Equal, false),
		meta.PackType_LastModify.UrlParameterName:       grmi.NewConditionItem(meta.PackType_LastModify, grmi.Approximate, false),
		meta.PackType_LastUser.UrlParameterName:         grmi.NewConditionItem(meta.PackType_LastUser, grmi.Equal, false),
		meta.PackType_CreateTime.UrlParameterName:       grmi.NewConditionItem(meta.PackType_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//PackType的默认分页查询条件
var DefaultConditionOfPackTypeAndPaging = grmi.NewCondition(
	DefaultConditionOfPackType.Items,
	grmi.NewPaging(),
)

type PackTypeServiceImplement struct {
}

func (self *PackTypeServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackType.service.impl.go", "SelectPackType", "查询PackType")

	condition := DefaultConditionOfPackTypeAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewPackTypeDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *PackTypeServiceImplement) InsertOne(user *models.Usertab, entity *model.PackType) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackType.service.impl.go", "InsertOnePackType", "插入一个PackType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackTypeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.PackTypeId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *PackTypeServiceImplement) DeleteOne(user *models.Usertab, packTypeId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackType.service.impl.go", "DeleteOnePackType", "删除一个PackType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackTypeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(packTypeId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(packTypeId)
	if err != nil {
		return err
	}
	return nil
}

func (self *PackTypeServiceImplement) SelectOne(user *models.Usertab, packTypeId string) (*model.PackType, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackType.service.impl.go", "SelectOnePackType", "查询一个PackType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackTypeDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(packTypeId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *PackTypeServiceImplement) UpdateOne(user *models.Usertab, entity *model.PackType) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_PackType.service.impl.go", "UpdateOnePackType", "修改一个PackType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewPackTypeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.PackTypeId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewPackTypeServiceImplement() *PackTypeServiceImplement {
	return &PackTypeServiceImplement{}
}
