package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/log"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//Vendor的默认查询条件
var DefaultConditionOfVendor = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Vendor_VendorId.UrlParameterName:       grmi.NewConditionItem(meta.Vendor_VendorId, grmi.Equal, true),
		meta.Vendor_Descr.UrlParameterName:          grmi.NewConditionItem(meta.Vendor_Descr, grmi.Equal, false),
		meta.Vendor_Address.UrlParameterName:        grmi.NewConditionItem(meta.Vendor_Address, grmi.Equal, false),
		meta.Vendor_VendorNr.UrlParameterName:       grmi.NewConditionItem(meta.Vendor_VendorNr, grmi.Equal, false),
		meta.Vendor_Name.UrlParameterName:           grmi.NewConditionItem(meta.Vendor_Name, grmi.Equal, false),
		meta.Vendor_Name1.UrlParameterName:          grmi.NewConditionItem(meta.Vendor_Name1, grmi.Equal, false),
		meta.Vendor_Name2.UrlParameterName:          grmi.NewConditionItem(meta.Vendor_Name2, grmi.Equal, false),
		meta.Vendor_ValidStartDate.UrlParameterName: grmi.NewConditionItem(meta.Vendor_ValidStartDate, grmi.Approximate, false),
		meta.Vendor_Country.UrlParameterName:        grmi.NewConditionItem(meta.Vendor_Country, grmi.Equal, false),
		meta.Vendor_City.UrlParameterName:           grmi.NewConditionItem(meta.Vendor_City, grmi.Equal, false),
		meta.Vendor_District.UrlParameterName:       grmi.NewConditionItem(meta.Vendor_District, grmi.Equal, false),
		meta.Vendor_Street.UrlParameterName:         grmi.NewConditionItem(meta.Vendor_Street, grmi.Equal, false),
		meta.Vendor_Location.UrlParameterName:       grmi.NewConditionItem(meta.Vendor_Location, grmi.Equal, false),
		meta.Vendor_PostCode.UrlParameterName:       grmi.NewConditionItem(meta.Vendor_PostCode, grmi.Equal, false),
		meta.Vendor_Phone.UrlParameterName:          grmi.NewConditionItem(meta.Vendor_Phone, grmi.Equal, false),
		meta.Vendor_Mobile.UrlParameterName:         grmi.NewConditionItem(meta.Vendor_Mobile, grmi.Equal, false),
		meta.Vendor_Fax.UrlParameterName:            grmi.NewConditionItem(meta.Vendor_Fax, grmi.Equal, false),
		meta.Vendor_Email1.UrlParameterName:         grmi.NewConditionItem(meta.Vendor_Email1, grmi.Equal, false),
		meta.Vendor_Email2.UrlParameterName:         grmi.NewConditionItem(meta.Vendor_Email2, grmi.Equal, false),
		meta.Vendor_ContactPerson.UrlParameterName:  grmi.NewConditionItem(meta.Vendor_ContactPerson, grmi.Equal, false),
		meta.Vendor_PersonTitle.UrlParameterName:    grmi.NewConditionItem(meta.Vendor_PersonTitle, grmi.Equal, false),
		meta.Vendor_ContactAddress.UrlParameterName: grmi.NewConditionItem(meta.Vendor_ContactAddress, grmi.Equal, false),
		meta.Vendor_Account.UrlParameterName:        grmi.NewConditionItem(meta.Vendor_Account, grmi.Equal, false),
		meta.Vendor_TaxRate.UrlParameterName:        grmi.NewConditionItem(meta.Vendor_TaxRate, grmi.Equal, false),
		meta.Vendor_Status.UrlParameterName:         grmi.NewConditionItem(meta.Vendor_Status, grmi.Equal, false),
		meta.Vendor_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.Vendor_LastModify, grmi.Approximate, false),
		meta.Vendor_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.Vendor_LastUser, grmi.Equal, false),
		meta.Vendor_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.Vendor_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//Vendor的默认分页查询条件
var DefaultConditionOfVendorAndPaging = grmi.NewCondition(
	DefaultConditionOfVendor.Items,
	grmi.NewPaging(),
)

type VendorServiceImplement struct {
}

func (self *VendorServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_Vendor.service.impl.go", "SelectVendor", "查询Vendor")

	condition := DefaultConditionOfVendorAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewVendorDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *VendorServiceImplement) InsertOne(user *models.Usertab, entity *model.Vendor) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_Vendor.service.impl.go", "InsertOneVendor", "插入一个Vendor")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.VendorId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *VendorServiceImplement) DeleteOne(user *models.Usertab, vendorId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_Vendor.service.impl.go", "DeleteOneVendor", "删除一个Vendor")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(vendorId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(vendorId)
	if err != nil {
		return err
	}
	return nil
}

func (self *VendorServiceImplement) SelectOne(user *models.Usertab, vendorId string) (*model.Vendor, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_Vendor.service.impl.go", "SelectOneVendor", "查询一个Vendor")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(vendorId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *VendorServiceImplement) UpdateOne(user *models.Usertab, entity *model.Vendor) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_Vendor.service.impl.go", "UpdateOneVendor", "修改一个Vendor")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.VendorId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewVendorServiceImplement() *VendorServiceImplement {
	return &VendorServiceImplement{}
}
