package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/log"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//VendorArtLst的默认查询条件
var DefaultConditionOfVendorArtLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.VendorArtLst_ArtId.UrlParameterName:      grmi.NewConditionItem(meta.VendorArtLst_ArtId, grmi.Equal, true),
		meta.VendorArtLst_VendorId.UrlParameterName:   grmi.NewConditionItem(meta.VendorArtLst_VendorId, grmi.Equal, false),
		meta.VendorArtLst_Pos.UrlParameterName:        grmi.NewConditionItem(meta.VendorArtLst_Pos, grmi.Equal, false),
		meta.VendorArtLst_CtrlLevel.UrlParameterName:  grmi.NewConditionItem(meta.VendorArtLst_CtrlLevel, grmi.Equal, false),
		meta.VendorArtLst_CtrlPara1.UrlParameterName:  grmi.NewConditionItem(meta.VendorArtLst_CtrlPara1, grmi.Equal, false),
		meta.VendorArtLst_CtrlPara2.UrlParameterName:  grmi.NewConditionItem(meta.VendorArtLst_CtrlPara2, grmi.Equal, false),
		meta.VendorArtLst_CtrlPara3.UrlParameterName:  grmi.NewConditionItem(meta.VendorArtLst_CtrlPara3, grmi.Equal, false),
		meta.VendorArtLst_CtrlPara4.UrlParameterName:  grmi.NewConditionItem(meta.VendorArtLst_CtrlPara4, grmi.Equal, false),
		meta.VendorArtLst_LastModify.UrlParameterName: grmi.NewConditionItem(meta.VendorArtLst_LastModify, grmi.Approximate, false),
		meta.VendorArtLst_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.VendorArtLst_LastUser, grmi.Equal, false),
		meta.VendorArtLst_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.VendorArtLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//VendorArtLst的默认分页查询条件
var DefaultConditionOfVendorArtLstAndPaging = grmi.NewCondition(
	DefaultConditionOfVendorArtLst.Items,
	grmi.NewPaging(),
)

type VendorArtLstServiceImplement struct {
}

func (self *VendorArtLstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_VendorArtLst.service.impl.go", "SelectVendorArtLst", "查询VendorArtLst")

	condition := DefaultConditionOfVendorArtLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewVendorArtLstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *VendorArtLstServiceImplement) InsertOne(user *models.Usertab, entity *model.VendorArtLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_VendorArtLst.service.impl.go", "InsertOneVendorArtLst", "插入一个VendorArtLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorArtLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ArtId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *VendorArtLstServiceImplement) DeleteOne(user *models.Usertab, artId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_VendorArtLst.service.impl.go", "DeleteOneVendorArtLst", "删除一个VendorArtLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorArtLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(artId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(artId)
	if err != nil {
		return err
	}
	return nil
}

func (self *VendorArtLstServiceImplement) SelectOne(user *models.Usertab, artId string) (*model.VendorArtLst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_VendorArtLst.service.impl.go", "SelectOneVendorArtLst", "查询一个VendorArtLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorArtLstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(artId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *VendorArtLstServiceImplement) UpdateOne(user *models.Usertab, entity *model.VendorArtLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_VendorArtLst.service.impl.go", "UpdateOneVendorArtLst", "修改一个VendorArtLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorArtLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ArtId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewVendorArtLstServiceImplement() *VendorArtLstServiceImplement {
	return &VendorArtLstServiceImplement{}
}
