package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/log"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/log"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//VendorUserLst的默认查询条件
var DefaultConditionOfVendorUserLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.VendorUserLst_VendorId.UrlParameterName:   grmi.NewConditionItem(meta.VendorUserLst_VendorId, grmi.Equal, true),
		meta.VendorUserLst_UserId.UrlParameterName:     grmi.NewConditionItem(meta.VendorUserLst_UserId, grmi.Equal, false),
		meta.VendorUserLst_Pos.UrlParameterName:        grmi.NewConditionItem(meta.VendorUserLst_Pos, grmi.Equal, false),
		meta.VendorUserLst_CtrlLevel.UrlParameterName:  grmi.NewConditionItem(meta.VendorUserLst_CtrlLevel, grmi.Equal, false),
		meta.VendorUserLst_CtrlPara1.UrlParameterName:  grmi.NewConditionItem(meta.VendorUserLst_CtrlPara1, grmi.Equal, false),
		meta.VendorUserLst_CtrlPara2.UrlParameterName:  grmi.NewConditionItem(meta.VendorUserLst_CtrlPara2, grmi.Equal, false),
		meta.VendorUserLst_CtrlPara3.UrlParameterName:  grmi.NewConditionItem(meta.VendorUserLst_CtrlPara3, grmi.Equal, false),
		meta.VendorUserLst_CtrlPara4.UrlParameterName:  grmi.NewConditionItem(meta.VendorUserLst_CtrlPara4, grmi.Equal, false),
		meta.VendorUserLst_LastModify.UrlParameterName: grmi.NewConditionItem(meta.VendorUserLst_LastModify, grmi.Approximate, false),
		meta.VendorUserLst_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.VendorUserLst_LastUser, grmi.Equal, false),
		meta.VendorUserLst_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.VendorUserLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//VendorUserLst的默认分页查询条件
var DefaultConditionOfVendorUserLstAndPaging = grmi.NewCondition(
	DefaultConditionOfVendorUserLst.Items,
	grmi.NewPaging(),
)

type VendorUserLstServiceImplement struct {
}

func (self *VendorUserLstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_VendorUserLst.service.impl.go", "SelectVendorUserLst", "查询VendorUserLst")

	condition := DefaultConditionOfVendorUserLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewVendorUserLstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *VendorUserLstServiceImplement) InsertOne(user *models.Usertab, entity *model.VendorUserLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_VendorUserLst.service.impl.go", "InsertOneVendorUserLst", "插入一个VendorUserLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorUserLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.VendorId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *VendorUserLstServiceImplement) DeleteOne(user *models.Usertab, vendorId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_VendorUserLst.service.impl.go", "DeleteOneVendorUserLst", "删除一个VendorUserLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorUserLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(vendorId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(vendorId)
	if err != nil {
		return err
	}
	return nil
}

func (self *VendorUserLstServiceImplement) SelectOne(user *models.Usertab, vendorId string) (*model.VendorUserLst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_VendorUserLst.service.impl.go", "SelectOneVendorUserLst", "查询一个VendorUserLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorUserLstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(vendorId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *VendorUserLstServiceImplement) UpdateOne(user *models.Usertab, entity *model.VendorUserLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/log/implments/LOG_VendorUserLst.service.impl.go", "UpdateOneVendorUserLst", "修改一个VendorUserLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewVendorUserLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.VendorId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewVendorUserLstServiceImplement() *VendorUserLstServiceImplement {
	return &VendorUserLstServiceImplement{}
}
