package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/ods"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/ods"
	model "leit.com/LAPP_GAAS_GFrame/models/ods"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//ArtRouteOdsLst的默认查询条件
var DefaultConditionOfArtRouteOdsLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ArtRouteOdsLst_ArtId.UrlParameterName:         grmi.NewConditionItem(meta.ArtRouteOdsLst_ArtId, grmi.Equal, true),
		meta.ArtRouteOdsLst_OperationNr.UrlParameterName:   grmi.NewConditionItem(meta.ArtRouteOdsLst_OperationNr, grmi.Equal, true),
		meta.ArtRouteOdsLst_Pos.UrlParameterName:           grmi.NewConditionItem(meta.ArtRouteOdsLst_Pos, grmi.Equal, true),
		meta.ArtRouteOdsLst_WorkPlaceId.UrlParameterName:   grmi.NewConditionItem(meta.ArtRouteOdsLst_WorkPlaceId, grmi.Equal, false),
		meta.ArtRouteOdsLst_Descr.UrlParameterName:         grmi.NewConditionItem(meta.ArtRouteOdsLst_Descr, grmi.Equal, false),
		meta.ArtRouteOdsLst_OdsId.UrlParameterName:         grmi.NewConditionItem(meta.ArtRouteOdsLst_OdsId, grmi.Equal, false),
		meta.ArtRouteOdsLst_OdsTypeId.UrlParameterName:     grmi.NewConditionItem(meta.ArtRouteOdsLst_OdsTypeId, grmi.Equal, false),
		meta.ArtRouteOdsLst_OdsContentIdx.UrlParameterName: grmi.NewConditionItem(meta.ArtRouteOdsLst_OdsContentIdx, grmi.Equal, false),
		meta.ArtRouteOdsLst_CtrlPara1.UrlParameterName:     grmi.NewConditionItem(meta.ArtRouteOdsLst_CtrlPara1, grmi.Equal, false),
		meta.ArtRouteOdsLst_CtrlPara2.UrlParameterName:     grmi.NewConditionItem(meta.ArtRouteOdsLst_CtrlPara2, grmi.Equal, false),
		meta.ArtRouteOdsLst_CtrlPara3.UrlParameterName:     grmi.NewConditionItem(meta.ArtRouteOdsLst_CtrlPara3, grmi.Equal, false),
		meta.ArtRouteOdsLst_CtrlPara4.UrlParameterName:     grmi.NewConditionItem(meta.ArtRouteOdsLst_CtrlPara4, grmi.Equal, false),
		meta.ArtRouteOdsLst_LastModify.UrlParameterName:    grmi.NewConditionItem(meta.ArtRouteOdsLst_LastModify, grmi.Approximate, false),
		meta.ArtRouteOdsLst_LastUser.UrlParameterName:      grmi.NewConditionItem(meta.ArtRouteOdsLst_LastUser, grmi.Equal, false),
		meta.ArtRouteOdsLst_CreateTime.UrlParameterName:    grmi.NewConditionItem(meta.ArtRouteOdsLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//ArtRouteOdsLst的默认分页查询条件
var DefaultConditionOfArtRouteOdsLstAndPaging = grmi.NewCondition(
	DefaultConditionOfArtRouteOdsLst.Items,
	grmi.NewPaging(),
)

type ArtRouteOdsLstServiceImplement struct {
}

func (self *ArtRouteOdsLstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_ArtRouteOdsLst.service.impl.go", "SelectArtRouteOdsLst", "查询ArtRouteOdsLst")

	condition := DefaultConditionOfArtRouteOdsLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewArtRouteOdsLstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *ArtRouteOdsLstServiceImplement) InsertOne(user *models.Usertab, entity *model.ArtRouteOdsLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_ArtRouteOdsLst.service.impl.go", "InsertOneArtRouteOdsLst", "插入一个ArtRouteOdsLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArtRouteOdsLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ArtId, entity.OperationNr, entity.Pos)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *ArtRouteOdsLstServiceImplement) DeleteOne(user *models.Usertab, artId string, operationNr int, pos int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_ArtRouteOdsLst.service.impl.go", "DeleteOneArtRouteOdsLst", "删除一个ArtRouteOdsLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArtRouteOdsLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(artId, operationNr, pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(artId, operationNr, pos)
	if err != nil {
		return err
	}
	return nil
}

func (self *ArtRouteOdsLstServiceImplement) SelectOne(user *models.Usertab, artId string, operationNr int, pos int) (*model.ArtRouteOdsLst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_ArtRouteOdsLst.service.impl.go", "SelectOneArtRouteOdsLst", "查询一个ArtRouteOdsLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArtRouteOdsLstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(artId, operationNr, pos)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *ArtRouteOdsLstServiceImplement) UpdateOne(user *models.Usertab, entity *model.ArtRouteOdsLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_ArtRouteOdsLst.service.impl.go", "UpdateOneArtRouteOdsLst", "修改一个ArtRouteOdsLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArtRouteOdsLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ArtId, entity.OperationNr, entity.Pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewArtRouteOdsLstServiceImplement() *ArtRouteOdsLstServiceImplement {
	return &ArtRouteOdsLstServiceImplement{}
}
