package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/ods"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/ods"
	model "leit.com/LAPP_GAAS_GFrame/models/ods"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//OdsHead的默认查询条件
var DefaultConditionOfOdsHead = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.OdsHead_OdsId.UrlParameterName:         grmi.NewConditionItem(meta.OdsHead_OdsId, grmi.Equal, true),
		meta.OdsHead_Descr.UrlParameterName:         grmi.NewConditionItem(meta.OdsHead_Descr, grmi.Equal, false),
		meta.OdsHead_OdsTypeId.UrlParameterName:     grmi.NewConditionItem(meta.OdsHead_OdsTypeId, grmi.Equal, false),
		meta.OdsHead_OdsContentIdx.UrlParameterName: grmi.NewConditionItem(meta.OdsHead_OdsContentIdx, grmi.Equal, false),
		meta.OdsHead_CtrlPara1.UrlParameterName:     grmi.NewConditionItem(meta.OdsHead_CtrlPara1, grmi.Equal, false),
		meta.OdsHead_CtrlPara2.UrlParameterName:     grmi.NewConditionItem(meta.OdsHead_CtrlPara2, grmi.Equal, false),
		meta.OdsHead_CtrlPara3.UrlParameterName:     grmi.NewConditionItem(meta.OdsHead_CtrlPara3, grmi.Equal, false),
		meta.OdsHead_CtrlPara4.UrlParameterName:     grmi.NewConditionItem(meta.OdsHead_CtrlPara4, grmi.Equal, false),
		meta.OdsHead_LastModify.UrlParameterName:    grmi.NewConditionItem(meta.OdsHead_LastModify, grmi.Approximate, false),
		meta.OdsHead_LastUser.UrlParameterName:      grmi.NewConditionItem(meta.OdsHead_LastUser, grmi.Equal, false),
		meta.OdsHead_CreateTime.UrlParameterName:    grmi.NewConditionItem(meta.OdsHead_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//OdsHead的默认分页查询条件
var DefaultConditionOfOdsHeadAndPaging = grmi.NewCondition(
	DefaultConditionOfOdsHead.Items,
	grmi.NewPaging(),
)

type OdsHeadServiceImplement struct {
}

func (self *OdsHeadServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsHead.service.impl.go", "SelectOdsHead", "查询OdsHead")

	condition := DefaultConditionOfOdsHeadAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewOdsHeadDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *OdsHeadServiceImplement) InsertOne(user *models.Usertab, entity *model.OdsHead) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsHead.service.impl.go", "InsertOneOdsHead", "插入一个OdsHead")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsHeadDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.OdsId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *OdsHeadServiceImplement) DeleteOne(user *models.Usertab, odsId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsHead.service.impl.go", "DeleteOneOdsHead", "删除一个OdsHead")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsHeadDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(odsId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(odsId)
	if err != nil {
		return err
	}
	return nil
}

func (self *OdsHeadServiceImplement) SelectOne(user *models.Usertab, odsId string) (*model.OdsHead, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsHead.service.impl.go", "SelectOneOdsHead", "查询一个OdsHead")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsHeadDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(odsId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *OdsHeadServiceImplement) UpdateOne(user *models.Usertab, entity *model.OdsHead) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsHead.service.impl.go", "UpdateOneOdsHead", "修改一个OdsHead")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsHeadDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.OdsId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewOdsHeadServiceImplement() *OdsHeadServiceImplement {
	return &OdsHeadServiceImplement{}
}
