package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/ods"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/ods"
	model "leit.com/LAPP_GAAS_GFrame/models/ods"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//OdsStepLst的默认查询条件
var DefaultConditionOfOdsStepLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.OdsStepLst_OdsId.UrlParameterName:         grmi.NewConditionItem(meta.OdsStepLst_OdsId, grmi.Equal, true),
		meta.OdsStepLst_Pos.UrlParameterName:           grmi.NewConditionItem(meta.OdsStepLst_Pos, grmi.Equal, true),
		meta.OdsStepLst_Descr.UrlParameterName:         grmi.NewConditionItem(meta.OdsStepLst_Descr, grmi.Equal, false),
		meta.OdsStepLst_OdsTypeId.UrlParameterName:     grmi.NewConditionItem(meta.OdsStepLst_OdsTypeId, grmi.Equal, false),
		meta.OdsStepLst_OdsContentIdx.UrlParameterName: grmi.NewConditionItem(meta.OdsStepLst_OdsContentIdx, grmi.Equal, false),
		meta.OdsStepLst_CtrlPara1.UrlParameterName:     grmi.NewConditionItem(meta.OdsStepLst_CtrlPara1, grmi.Equal, false),
		meta.OdsStepLst_CtrlPara2.UrlParameterName:     grmi.NewConditionItem(meta.OdsStepLst_CtrlPara2, grmi.Equal, false),
		meta.OdsStepLst_CtrlPara3.UrlParameterName:     grmi.NewConditionItem(meta.OdsStepLst_CtrlPara3, grmi.Equal, false),
		meta.OdsStepLst_CtrlPara4.UrlParameterName:     grmi.NewConditionItem(meta.OdsStepLst_CtrlPara4, grmi.Equal, false),
		meta.OdsStepLst_LastModify.UrlParameterName:    grmi.NewConditionItem(meta.OdsStepLst_LastModify, grmi.Approximate, false),
		meta.OdsStepLst_LastUser.UrlParameterName:      grmi.NewConditionItem(meta.OdsStepLst_LastUser, grmi.Equal, false),
		meta.OdsStepLst_CreateTime.UrlParameterName:    grmi.NewConditionItem(meta.OdsStepLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//OdsStepLst的默认分页查询条件
var DefaultConditionOfOdsStepLstAndPaging = grmi.NewCondition(
	DefaultConditionOfOdsStepLst.Items,
	grmi.NewPaging(),
)

type OdsStepLstServiceImplement struct {
}

func (self *OdsStepLstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsStepLst.service.impl.go", "SelectOdsStepLst", "查询OdsStepLst")

	condition := DefaultConditionOfOdsStepLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewOdsStepLstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *OdsStepLstServiceImplement) InsertOne(user *models.Usertab, entity *model.OdsStepLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsStepLst.service.impl.go", "InsertOneOdsStepLst", "插入一个OdsStepLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsStepLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.OdsId, entity.Pos)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *OdsStepLstServiceImplement) DeleteOne(user *models.Usertab, odsId string, pos int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsStepLst.service.impl.go", "DeleteOneOdsStepLst", "删除一个OdsStepLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsStepLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(odsId, pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(odsId, pos)
	if err != nil {
		return err
	}
	return nil
}

func (self *OdsStepLstServiceImplement) SelectOne(user *models.Usertab, odsId string, pos int) (*model.OdsStepLst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsStepLst.service.impl.go", "SelectOneOdsStepLst", "查询一个OdsStepLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsStepLstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(odsId, pos)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *OdsStepLstServiceImplement) UpdateOne(user *models.Usertab, entity *model.OdsStepLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsStepLst.service.impl.go", "UpdateOneOdsStepLst", "修改一个OdsStepLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsStepLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.OdsId, entity.Pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewOdsStepLstServiceImplement() *OdsStepLstServiceImplement {
	return &OdsStepLstServiceImplement{}
}
