package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/ods"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/ods"
	model "leit.com/LAPP_GAAS_GFrame/models/ods"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//OdsType的默认查询条件
var DefaultConditionOfOdsType = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.OdsType_OdsTypeId.UrlParameterName:  grmi.NewConditionItem(meta.OdsType_OdsTypeId, grmi.Equal, true),
		meta.OdsType_Descr.UrlParameterName:      grmi.NewConditionItem(meta.OdsType_Descr, grmi.Equal, false),
		meta.OdsType_Width.UrlParameterName:      grmi.NewConditionItem(meta.OdsType_Width, grmi.Equal, false),
		meta.OdsType_Height.UrlParameterName:     grmi.NewConditionItem(meta.OdsType_Height, grmi.Equal, false),
		meta.OdsType_Player.UrlParameterName:     grmi.NewConditionItem(meta.OdsType_Player, grmi.Equal, false),
		meta.OdsType_CtrlPara1.UrlParameterName:  grmi.NewConditionItem(meta.OdsType_CtrlPara1, grmi.Equal, false),
		meta.OdsType_CtrlPara2.UrlParameterName:  grmi.NewConditionItem(meta.OdsType_CtrlPara2, grmi.Equal, false),
		meta.OdsType_CtrlPara3.UrlParameterName:  grmi.NewConditionItem(meta.OdsType_CtrlPara3, grmi.Equal, false),
		meta.OdsType_CtrlPara4.UrlParameterName:  grmi.NewConditionItem(meta.OdsType_CtrlPara4, grmi.Equal, false),
		meta.OdsType_LastModify.UrlParameterName: grmi.NewConditionItem(meta.OdsType_LastModify, grmi.Approximate, false),
		meta.OdsType_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.OdsType_LastUser, grmi.Equal, false),
		meta.OdsType_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.OdsType_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//OdsType的默认分页查询条件
var DefaultConditionOfOdsTypeAndPaging = grmi.NewCondition(
	DefaultConditionOfOdsType.Items,
	grmi.NewPaging(),
)

type OdsTypeServiceImplement struct {
}

func (self *OdsTypeServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsType.service.impl.go", "SelectOdsType", "查询OdsType")

	condition := DefaultConditionOfOdsTypeAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewOdsTypeDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *OdsTypeServiceImplement) InsertOne(user *models.Usertab, entity *model.OdsType) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsType.service.impl.go", "InsertOneOdsType", "插入一个OdsType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsTypeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.OdsTypeId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *OdsTypeServiceImplement) DeleteOne(user *models.Usertab, odsTypeId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsType.service.impl.go", "DeleteOneOdsType", "删除一个OdsType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsTypeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(odsTypeId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(odsTypeId)
	if err != nil {
		return err
	}
	return nil
}

func (self *OdsTypeServiceImplement) SelectOne(user *models.Usertab, odsTypeId string) (*model.OdsType, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsType.service.impl.go", "SelectOneOdsType", "查询一个OdsType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsTypeDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(odsTypeId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *OdsTypeServiceImplement) UpdateOne(user *models.Usertab, entity *model.OdsType) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/ods/implments/ODS_OdsType.service.impl.go", "UpdateOneOdsType", "修改一个OdsType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewOdsTypeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.OdsTypeId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewOdsTypeServiceImplement() *OdsTypeServiceImplement {
	return &OdsTypeServiceImplement{}
}
