package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/om"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/om"
	model "leit.com/LAPP_GAAS_GFrame/models/om"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//ProdOrderQty的默认查询条件
var DefaultConditionOfProdOrderQty = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ProdOrderQty_ProdOrderId.UrlParameterName:  grmi.NewConditionItem(meta.ProdOrderQty_ProdOrderId, grmi.Equal, true),
		meta.ProdOrderQty_ActQty.UrlParameterName:       grmi.NewConditionItem(meta.ProdOrderQty_ActQty, grmi.Equal, false),
		meta.ProdOrderQty_ActGoodQty.UrlParameterName:   grmi.NewConditionItem(meta.ProdOrderQty_ActGoodQty, grmi.Equal, false),
		meta.ProdOrderQty_ActScrapQty.UrlParameterName:  grmi.NewConditionItem(meta.ProdOrderQty_ActScrapQty, grmi.Equal, false),
		meta.ProdOrderQty_ActReworkQty.UrlParameterName: grmi.NewConditionItem(meta.ProdOrderQty_ActReworkQty, grmi.Equal, false),
		meta.ProdOrderQty_ActQty1.UrlParameterName:      grmi.NewConditionItem(meta.ProdOrderQty_ActQty1, grmi.Equal, false),
		meta.ProdOrderQty_ActQty2.UrlParameterName:      grmi.NewConditionItem(meta.ProdOrderQty_ActQty2, grmi.Equal, false),
		meta.ProdOrderQty_ActQty3.UrlParameterName:      grmi.NewConditionItem(meta.ProdOrderQty_ActQty3, grmi.Equal, false),
		meta.ProdOrderQty_ActQty4.UrlParameterName:      grmi.NewConditionItem(meta.ProdOrderQty_ActQty4, grmi.Equal, false),
		meta.ProdOrderQty_LastModify.UrlParameterName:   grmi.NewConditionItem(meta.ProdOrderQty_LastModify, grmi.Approximate, false),
		meta.ProdOrderQty_LastUser.UrlParameterName:     grmi.NewConditionItem(meta.ProdOrderQty_LastUser, grmi.Equal, false),
		meta.ProdOrderQty_CreateTime.UrlParameterName:   grmi.NewConditionItem(meta.ProdOrderQty_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//ProdOrderQty的默认分页查询条件
var DefaultConditionOfProdOrderQtyAndPaging = grmi.NewCondition(
	DefaultConditionOfProdOrderQty.Items,
	grmi.NewPaging(),
)

type ProdOrderQtyServiceImplement struct {
}

func (self *ProdOrderQtyServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/om/implments/OM_ProdOrderQty.service.impl.go", "SelectProdOrderQty", "查询ProdOrderQty")

	condition := DefaultConditionOfProdOrderQtyAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewProdOrderQtyDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *ProdOrderQtyServiceImplement) InsertOne(user *models.Usertab, entity *model.ProdOrderQty) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/om/implments/OM_ProdOrderQty.service.impl.go", "InsertOneProdOrderQty", "插入一个ProdOrderQty")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewProdOrderQtyDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ProdOrderId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *ProdOrderQtyServiceImplement) DeleteOne(user *models.Usertab, prodOrderId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/om/implments/OM_ProdOrderQty.service.impl.go", "DeleteOneProdOrderQty", "删除一个ProdOrderQty")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewProdOrderQtyDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(prodOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(prodOrderId)
	if err != nil {
		return err
	}
	return nil
}

func (self *ProdOrderQtyServiceImplement) SelectOne(user *models.Usertab, prodOrderId string) (*model.ProdOrderQty, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/om/implments/OM_ProdOrderQty.service.impl.go", "SelectOneProdOrderQty", "查询一个ProdOrderQty")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewProdOrderQtyDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(prodOrderId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *ProdOrderQtyServiceImplement) UpdateOne(user *models.Usertab, entity *model.ProdOrderQty) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/om/implments/OM_ProdOrderQty.service.impl.go", "UpdateOneProdOrderQty", "修改一个ProdOrderQty")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewProdOrderQtyDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ProdOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewProdOrderQtyServiceImplement() *ProdOrderQtyServiceImplement {
	return &ProdOrderQtyServiceImplement{}
}
