package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/om"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/om"
	model "leit.com/LAPP_GAAS_GFrame/models/om"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//ProdOrderStatus的默认查询条件
var DefaultConditionOfProdOrderStatus = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ProdOrderStatus_ProdOrderId.UrlParameterName:        grmi.NewConditionItem(meta.ProdOrderStatus_ProdOrderId, grmi.Equal, true),
		meta.ProdOrderStatus_Status.UrlParameterName:             grmi.NewConditionItem(meta.ProdOrderStatus_Status, grmi.Equal, false),
		meta.ProdOrderStatus_TriggerEvent.UrlParameterName:       grmi.NewConditionItem(meta.ProdOrderStatus_TriggerEvent, grmi.Equal, false),
		meta.ProdOrderStatus_TriggerObjectId.UrlParameterName:    grmi.NewConditionItem(meta.ProdOrderStatus_TriggerObjectId, grmi.Equal, false),
		meta.ProdOrderStatus_TriggerSubObjectId.UrlParameterName: grmi.NewConditionItem(meta.ProdOrderStatus_TriggerSubObjectId, grmi.Equal, false),
		meta.ProdOrderStatus_LastModify.UrlParameterName:         grmi.NewConditionItem(meta.ProdOrderStatus_LastModify, grmi.Approximate, false),
		meta.ProdOrderStatus_LastUser.UrlParameterName:           grmi.NewConditionItem(meta.ProdOrderStatus_LastUser, grmi.Equal, false),
		meta.ProdOrderStatus_CreateTime.UrlParameterName:         grmi.NewConditionItem(meta.ProdOrderStatus_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//ProdOrderStatus的默认分页查询条件
var DefaultConditionOfProdOrderStatusAndPaging = grmi.NewCondition(
	DefaultConditionOfProdOrderStatus.Items,
	grmi.NewPaging(),
)

type ProdOrderStatusServiceImplement struct {
}

func (self *ProdOrderStatusServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/om/implments/OM_ProdOrderStatus.service.impl.go", "SelectProdOrderStatus", "查询ProdOrderStatus")

	condition := DefaultConditionOfProdOrderStatusAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewProdOrderStatusDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *ProdOrderStatusServiceImplement) InsertOne(user *models.Usertab, entity *model.ProdOrderStatus) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/om/implments/OM_ProdOrderStatus.service.impl.go", "InsertOneProdOrderStatus", "插入一个ProdOrderStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewProdOrderStatusDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ProdOrderId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *ProdOrderStatusServiceImplement) DeleteOne(user *models.Usertab, prodOrderId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/om/implments/OM_ProdOrderStatus.service.impl.go", "DeleteOneProdOrderStatus", "删除一个ProdOrderStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewProdOrderStatusDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(prodOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(prodOrderId)
	if err != nil {
		return err
	}
	return nil
}

func (self *ProdOrderStatusServiceImplement) SelectOne(user *models.Usertab, prodOrderId string) (*model.ProdOrderStatus, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/om/implments/OM_ProdOrderStatus.service.impl.go", "SelectOneProdOrderStatus", "查询一个ProdOrderStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewProdOrderStatusDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(prodOrderId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *ProdOrderStatusServiceImplement) UpdateOne(user *models.Usertab, entity *model.ProdOrderStatus) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/om/implments/OM_ProdOrderStatus.service.impl.go", "UpdateOneProdOrderStatus", "修改一个ProdOrderStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewProdOrderStatusDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ProdOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewProdOrderStatusServiceImplement() *ProdOrderStatusServiceImplement {
	return &ProdOrderStatusServiceImplement{}
}
