package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/qm"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//ArtView的默认查询条件
var DefaultConditionOfArtView = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ArtView_ArtId.UrlParameterName:       grmi.NewConditionItem(meta.ArtView_ArtId, grmi.Equal, true),
		meta.ArtView_ViewId.UrlParameterName:      grmi.NewConditionItem(meta.ArtView_ViewId, grmi.Equal, true),
		meta.ArtView_Pos.UrlParameterName:         grmi.NewConditionItem(meta.ArtView_Pos, grmi.Equal, false),
		meta.ArtView_Descr.UrlParameterName:       grmi.NewConditionItem(meta.ArtView_Descr, grmi.Equal, false),
		meta.ArtView_ViewPicture.UrlParameterName: grmi.NewConditionItem(meta.ArtView_ViewPicture, grmi.Equal, false),
		meta.ArtView_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.ArtView_LastModify, grmi.Approximate, false),
		meta.ArtView_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.ArtView_LastUser, grmi.Equal, false),
		meta.ArtView_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.ArtView_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//ArtView的默认分页查询条件
var DefaultConditionOfArtViewAndPaging = grmi.NewCondition(
	DefaultConditionOfArtView.Items,
	grmi.NewPaging(),
)

type ArtViewServiceImplement struct {
}

func (self *ArtViewServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ArtView.service.impl.go", "SelectArtView", "查询ArtView")

	condition := DefaultConditionOfArtViewAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewArtViewDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *ArtViewServiceImplement) InsertOne(user *models.Usertab, entity *model.ArtView) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ArtView.service.impl.go", "InsertOneArtView", "插入一个ArtView")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArtViewDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ArtId, entity.ViewId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *ArtViewServiceImplement) DeleteOne(user *models.Usertab, artId string, viewId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ArtView.service.impl.go", "DeleteOneArtView", "删除一个ArtView")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArtViewDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(artId, viewId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(artId, viewId)
	if err != nil {
		return err
	}
	return nil
}

func (self *ArtViewServiceImplement) SelectOne(user *models.Usertab, artId string, viewId string) (*model.ArtView, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ArtView.service.impl.go", "SelectOneArtView", "查询一个ArtView")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArtViewDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(artId, viewId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *ArtViewServiceImplement) UpdateOne(user *models.Usertab, entity *model.ArtView) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ArtView.service.impl.go", "UpdateOneArtView", "修改一个ArtView")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewArtViewDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ArtId, entity.ViewId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewArtViewServiceImplement() *ArtViewServiceImplement {
	return &ArtViewServiceImplement{}
}
