package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/qm"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//DefectGrp的默认查询条件
var DefaultConditionOfDefectGrp = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.DefectGrp_DefectGrpId.UrlParameterName: grmi.NewConditionItem(meta.DefectGrp_DefectGrpId, grmi.Equal, true),
		meta.DefectGrp_Descr.UrlParameterName:       grmi.NewConditionItem(meta.DefectGrp_Descr, grmi.Equal, false),
		meta.DefectGrp_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.DefectGrp_LastModify, grmi.Approximate, false),
		meta.DefectGrp_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.DefectGrp_LastUser, grmi.Equal, false),
		meta.DefectGrp_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.DefectGrp_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//DefectGrp的默认分页查询条件
var DefaultConditionOfDefectGrpAndPaging = grmi.NewCondition(
	DefaultConditionOfDefectGrp.Items,
	grmi.NewPaging(),
)

type DefectGrpServiceImplement struct {
}

func (self *DefectGrpServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectGrp.service.impl.go", "SelectDefectGrp", "查询DefectGrp")

	condition := DefaultConditionOfDefectGrpAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewDefectGrpDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *DefectGrpServiceImplement) InsertOne(user *models.Usertab, entity *model.DefectGrp) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectGrp.service.impl.go", "InsertOneDefectGrp", "插入一个DefectGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectGrpDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.DefectGrpId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *DefectGrpServiceImplement) DeleteOne(user *models.Usertab, defectGrpId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectGrp.service.impl.go", "DeleteOneDefectGrp", "删除一个DefectGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectGrpDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(defectGrpId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(defectGrpId)
	if err != nil {
		return err
	}
	return nil
}

func (self *DefectGrpServiceImplement) SelectOne(user *models.Usertab, defectGrpId string) (*model.DefectGrp, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectGrp.service.impl.go", "SelectOneDefectGrp", "查询一个DefectGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectGrpDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(defectGrpId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *DefectGrpServiceImplement) UpdateOne(user *models.Usertab, entity *model.DefectGrp) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectGrp.service.impl.go", "UpdateOneDefectGrp", "修改一个DefectGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectGrpDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.DefectGrpId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewDefectGrpServiceImplement() *DefectGrpServiceImplement {
	return &DefectGrpServiceImplement{}
}
