package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/qm"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//DefectGrpReasonLst的默认查询条件
var DefaultConditionOfDefectGrpReasonLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.DefectGrpReasonLst_DefectGrpId.UrlParameterName:    grmi.NewConditionItem(meta.DefectGrpReasonLst_DefectGrpId, grmi.Equal, true),
		meta.DefectGrpReasonLst_DefectReasonId.UrlParameterName: grmi.NewConditionItem(meta.DefectGrpReasonLst_DefectReasonId, grmi.Equal, true),
		meta.DefectGrpReasonLst_Pos.UrlParameterName:            grmi.NewConditionItem(meta.DefectGrpReasonLst_Pos, grmi.Equal, false),
		meta.DefectGrpReasonLst_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.DefectGrpReasonLst_LastModify, grmi.Approximate, false),
		meta.DefectGrpReasonLst_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.DefectGrpReasonLst_LastUser, grmi.Equal, false),
		meta.DefectGrpReasonLst_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.DefectGrpReasonLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//DefectGrpReasonLst的默认分页查询条件
var DefaultConditionOfDefectGrpReasonLstAndPaging = grmi.NewCondition(
	DefaultConditionOfDefectGrpReasonLst.Items,
	grmi.NewPaging(),
)

type DefectGrpReasonLstServiceImplement struct {
}

func (self *DefectGrpReasonLstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectGrpReasonLst.service.impl.go", "SelectDefectGrpReasonLst", "查询DefectGrpReasonLst")

	condition := DefaultConditionOfDefectGrpReasonLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewDefectGrpReasonLstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *DefectGrpReasonLstServiceImplement) InsertOne(user *models.Usertab, entity *model.DefectGrpReasonLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectGrpReasonLst.service.impl.go", "InsertOneDefectGrpReasonLst", "插入一个DefectGrpReasonLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectGrpReasonLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.DefectGrpId, entity.DefectReasonId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *DefectGrpReasonLstServiceImplement) DeleteOne(user *models.Usertab, defectGrpId string, defectReasonId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectGrpReasonLst.service.impl.go", "DeleteOneDefectGrpReasonLst", "删除一个DefectGrpReasonLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectGrpReasonLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(defectGrpId, defectReasonId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(defectGrpId, defectReasonId)
	if err != nil {
		return err
	}
	return nil
}

func (self *DefectGrpReasonLstServiceImplement) SelectOne(user *models.Usertab, defectGrpId string, defectReasonId string) (*model.DefectGrpReasonLst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectGrpReasonLst.service.impl.go", "SelectOneDefectGrpReasonLst", "查询一个DefectGrpReasonLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectGrpReasonLstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(defectGrpId, defectReasonId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *DefectGrpReasonLstServiceImplement) UpdateOne(user *models.Usertab, entity *model.DefectGrpReasonLst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectGrpReasonLst.service.impl.go", "UpdateOneDefectGrpReasonLst", "修改一个DefectGrpReasonLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectGrpReasonLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.DefectGrpId, entity.DefectReasonId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewDefectGrpReasonLstServiceImplement() *DefectGrpReasonLstServiceImplement {
	return &DefectGrpReasonLstServiceImplement{}
}
