package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/qm"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//DefectReason的默认查询条件
var DefaultConditionOfDefectReason = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.DefectReason_DefectReasonId.UrlParameterName: grmi.NewConditionItem(meta.DefectReason_DefectReasonId, grmi.Equal, true),
		meta.DefectReason_Descr.UrlParameterName:          grmi.NewConditionItem(meta.DefectReason_Descr, grmi.Equal, false),
		meta.DefectReason_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.DefectReason_LastModify, grmi.Approximate, false),
		meta.DefectReason_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.DefectReason_LastUser, grmi.Equal, false),
		meta.DefectReason_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.DefectReason_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//DefectReason的默认分页查询条件
var DefaultConditionOfDefectReasonAndPaging = grmi.NewCondition(
	DefaultConditionOfDefectReason.Items,
	grmi.NewPaging(),
)

type DefectReasonServiceImplement struct {
}

func (self *DefectReasonServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectReason.service.impl.go", "SelectDefectReason", "查询DefectReason")

	condition := DefaultConditionOfDefectReasonAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewDefectReasonDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *DefectReasonServiceImplement) InsertOne(user *models.Usertab, entity *model.DefectReason) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectReason.service.impl.go", "InsertOneDefectReason", "插入一个DefectReason")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectReasonDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.DefectReasonId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *DefectReasonServiceImplement) DeleteOne(user *models.Usertab, defectReasonId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectReason.service.impl.go", "DeleteOneDefectReason", "删除一个DefectReason")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectReasonDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(defectReasonId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(defectReasonId)
	if err != nil {
		return err
	}
	return nil
}

func (self *DefectReasonServiceImplement) SelectOne(user *models.Usertab, defectReasonId string) (*model.DefectReason, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectReason.service.impl.go", "SelectOneDefectReason", "查询一个DefectReason")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectReasonDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(defectReasonId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *DefectReasonServiceImplement) UpdateOne(user *models.Usertab, entity *model.DefectReason) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectReason.service.impl.go", "UpdateOneDefectReason", "修改一个DefectReason")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectReasonDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.DefectReasonId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewDefectReasonServiceImplement() *DefectReasonServiceImplement {
	return &DefectReasonServiceImplement{}
}
