package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/qm"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//DefectRecord的默认查询条件
var DefaultConditionOfDefectRecord = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.DefectRecord_RecNr.UrlParameterName:          grmi.NewConditionItem(meta.DefectRecord_RecNr, grmi.Equal, true),
		meta.DefectRecord_SerialOrderId.UrlParameterName:  grmi.NewConditionItem(meta.DefectRecord_SerialOrderId, grmi.Equal, false),
		meta.DefectRecord_OperationNr.UrlParameterName:    grmi.NewConditionItem(meta.DefectRecord_OperationNr, grmi.Equal, false),
		meta.DefectRecord_Qty.UrlParameterName:            grmi.NewConditionItem(meta.DefectRecord_Qty, grmi.Equal, false),
		meta.DefectRecord_ViewId.UrlParameterName:         grmi.NewConditionItem(meta.DefectRecord_ViewId, grmi.Equal, false),
		meta.DefectRecord_ViewDescr.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_ViewDescr, grmi.Equal, false),
		meta.DefectRecord_ViewPicture.UrlParameterName:    grmi.NewConditionItem(meta.DefectRecord_ViewPicture, grmi.Equal, false),
		meta.DefectRecord_ViewCode.UrlParameterName:       grmi.NewConditionItem(meta.DefectRecord_ViewCode, grmi.Equal, false),
		meta.DefectRecord_Width.UrlParameterName:          grmi.NewConditionItem(meta.DefectRecord_Width, grmi.Equal, false),
		meta.DefectRecord_Height.UrlParameterName:         grmi.NewConditionItem(meta.DefectRecord_Height, grmi.Equal, false),
		meta.DefectRecord_EndProduct.UrlParameterName:     grmi.NewConditionItem(meta.DefectRecord_EndProduct, grmi.Equal, false),
		meta.DefectRecord_AreaId.UrlParameterName:         grmi.NewConditionItem(meta.DefectRecord_AreaId, grmi.Equal, false),
		meta.DefectRecord_XStart.UrlParameterName:         grmi.NewConditionItem(meta.DefectRecord_XStart, grmi.Equal, false),
		meta.DefectRecord_XEnd.UrlParameterName:           grmi.NewConditionItem(meta.DefectRecord_XEnd, grmi.Equal, false),
		meta.DefectRecord_YStart.UrlParameterName:         grmi.NewConditionItem(meta.DefectRecord_YStart, grmi.Equal, false),
		meta.DefectRecord_YEnd.UrlParameterName:           grmi.NewConditionItem(meta.DefectRecord_YEnd, grmi.Equal, false),
		meta.DefectRecord_XPos.UrlParameterName:           grmi.NewConditionItem(meta.DefectRecord_XPos, grmi.Equal, false),
		meta.DefectRecord_YPos.UrlParameterName:           grmi.NewConditionItem(meta.DefectRecord_YPos, grmi.Equal, false),
		meta.DefectRecord_WorkplaceId.UrlParameterName:    grmi.NewConditionItem(meta.DefectRecord_WorkplaceId, grmi.Equal, false),
		meta.DefectRecord_ReworkplaceId.UrlParameterName:  grmi.NewConditionItem(meta.DefectRecord_ReworkplaceId, grmi.Equal, false),
		meta.DefectRecord_Status.UrlParameterName:         grmi.NewConditionItem(meta.DefectRecord_Status, grmi.Equal, false),
		meta.DefectRecord_DefectGrpId.UrlParameterName:    grmi.NewConditionItem(meta.DefectRecord_DefectGrpId, grmi.Equal, false),
		meta.DefectRecord_DefectGrpDescr.UrlParameterName: grmi.NewConditionItem(meta.DefectRecord_DefectGrpDescr, grmi.Equal, false),
		meta.DefectRecord_DefectReasonId.UrlParameterName: grmi.NewConditionItem(meta.DefectRecord_DefectReasonId, grmi.Equal, false),
		meta.DefectRecord_DefectDescr.UrlParameterName:    grmi.NewConditionItem(meta.DefectRecord_DefectDescr, grmi.Equal, false),
		meta.DefectRecord_InspectTime.UrlParameterName:    grmi.NewConditionItem(meta.DefectRecord_InspectTime, grmi.Approximate, false),
		meta.DefectRecord_InspectShiftId.UrlParameterName: grmi.NewConditionItem(meta.DefectRecord_InspectShiftId, grmi.Equal, false),
		meta.DefectRecord_Inspector.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_Inspector, grmi.Equal, false),
		meta.DefectRecord_ReworkTime.UrlParameterName:     grmi.NewConditionItem(meta.DefectRecord_ReworkTime, grmi.Approximate, false),
		meta.DefectRecord_ReworkShiftId.UrlParameterName:  grmi.NewConditionItem(meta.DefectRecord_ReworkShiftId, grmi.Equal, false),
		meta.DefectRecord_Reworker.UrlParameterName:       grmi.NewConditionItem(meta.DefectRecord_Reworker, grmi.Equal, false),
		meta.DefectRecord_BuildCode.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_BuildCode, grmi.Equal, false),
		meta.DefectRecord_DDCCustC1.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_DDCCustC1, grmi.Equal, false),
		meta.DefectRecord_DDCCustC2.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_DDCCustC2, grmi.Equal, false),
		meta.DefectRecord_DDCCustC3.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_DDCCustC3, grmi.Equal, false),
		meta.DefectRecord_DDCCustC4.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_DDCCustC4, grmi.Equal, false),
		meta.DefectRecord_DDCCustI1.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_DDCCustI1, grmi.Equal, false),
		meta.DefectRecord_DDCCustI2.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_DDCCustI2, grmi.Equal, false),
		meta.DefectRecord_DDCCustI3.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_DDCCustI3, grmi.Equal, false),
		meta.DefectRecord_DDCCustI4.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_DDCCustI4, grmi.Equal, false),
		meta.DefectRecord_DDCCustT1.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_DDCCustT1, grmi.Approximate, false),
		meta.DefectRecord_DDCCustT2.UrlParameterName:      grmi.NewConditionItem(meta.DefectRecord_DDCCustT2, grmi.Approximate, false),
		meta.DefectRecord_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.DefectRecord_LastModify, grmi.Approximate, false),
		meta.DefectRecord_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.DefectRecord_LastUser, grmi.Equal, false),
		meta.DefectRecord_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.DefectRecord_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//DefectRecord的默认分页查询条件
var DefaultConditionOfDefectRecordAndPaging = grmi.NewCondition(
	DefaultConditionOfDefectRecord.Items,
	grmi.NewPaging(),
)

type DefectRecordServiceImplement struct {
}

func (self *DefectRecordServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectRecord.service.impl.go", "SelectDefectRecord", "查询DefectRecord")

	condition := DefaultConditionOfDefectRecordAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewDefectRecordDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *DefectRecordServiceImplement) InsertOne(user *models.Usertab, entity *model.DefectRecord) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectRecord.service.impl.go", "InsertOneDefectRecord", "插入一个DefectRecord")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectRecordDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.RecNr)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *DefectRecordServiceImplement) DeleteOne(user *models.Usertab, recNr int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectRecord.service.impl.go", "DeleteOneDefectRecord", "删除一个DefectRecord")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectRecordDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(recNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(recNr)
	if err != nil {
		return err
	}
	return nil
}

func (self *DefectRecordServiceImplement) SelectOne(user *models.Usertab, recNr int) (*model.DefectRecord, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectRecord.service.impl.go", "SelectOneDefectRecord", "查询一个DefectRecord")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectRecordDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(recNr)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *DefectRecordServiceImplement) UpdateOne(user *models.Usertab, entity *model.DefectRecord) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_DefectRecord.service.impl.go", "UpdateOneDefectRecord", "修改一个DefectRecord")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewDefectRecordDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.RecNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewDefectRecordServiceImplement() *DefectRecordServiceImplement {
	return &DefectRecordServiceImplement{}
}
