package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/qm"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//View的默认查询条件
var DefaultConditionOfView = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.View_ViewId.UrlParameterName:      grmi.NewConditionItem(meta.View_ViewId, grmi.Equal, true),
		meta.View_Descr.UrlParameterName:       grmi.NewConditionItem(meta.View_Descr, grmi.Equal, false),
		meta.View_Picture.UrlParameterName:     grmi.NewConditionItem(meta.View_Picture, grmi.Equal, false),
		meta.View_Abrev.UrlParameterName:       grmi.NewConditionItem(meta.View_Abrev, grmi.Equal, false),
		meta.View_Width.UrlParameterName:       grmi.NewConditionItem(meta.View_Width, grmi.Equal, false),
		meta.View_Height.UrlParameterName:      grmi.NewConditionItem(meta.View_Height, grmi.Equal, false),
		meta.View_XLineColor.UrlParameterName:  grmi.NewConditionItem(meta.View_XLineColor, grmi.Equal, false),
		meta.View_YLineColor.UrlParameterName:  grmi.NewConditionItem(meta.View_YLineColor, grmi.Equal, false),
		meta.View_UseXYToggle.UrlParameterName: grmi.NewConditionItem(meta.View_UseXYToggle, grmi.Equal, false),
		meta.View_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.View_LastModify, grmi.Approximate, false),
		meta.View_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.View_LastUser, grmi.Equal, false),
		meta.View_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.View_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//View的默认分页查询条件
var DefaultConditionOfViewAndPaging = grmi.NewCondition(
	DefaultConditionOfView.Items,
	grmi.NewPaging(),
)

type ViewServiceImplement struct {
}

func (self *ViewServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_View.service.impl.go", "SelectView", "查询View")

	condition := DefaultConditionOfViewAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewViewDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *ViewServiceImplement) InsertOne(user *models.Usertab, entity *model.View) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_View.service.impl.go", "InsertOneView", "插入一个View")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ViewId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *ViewServiceImplement) DeleteOne(user *models.Usertab, viewId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_View.service.impl.go", "DeleteOneView", "删除一个View")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(viewId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(viewId)
	if err != nil {
		return err
	}
	return nil
}

func (self *ViewServiceImplement) SelectOne(user *models.Usertab, viewId string) (*model.View, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_View.service.impl.go", "SelectOneView", "查询一个View")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(viewId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *ViewServiceImplement) UpdateOne(user *models.Usertab, entity *model.View) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_View.service.impl.go", "UpdateOneView", "修改一个View")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ViewId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewViewServiceImplement() *ViewServiceImplement {
	return &ViewServiceImplement{}
}
