package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/qm"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//ViewDefectGrplst的默认查询条件
var DefaultConditionOfViewDefectGrplst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ViewDefectGrplst_ViewId.UrlParameterName:      grmi.NewConditionItem(meta.ViewDefectGrplst_ViewId, grmi.Equal, true),
		meta.ViewDefectGrplst_DefectGrpId.UrlParameterName: grmi.NewConditionItem(meta.ViewDefectGrplst_DefectGrpId, grmi.Equal, true),
		meta.ViewDefectGrplst_Pos.UrlParameterName:         grmi.NewConditionItem(meta.ViewDefectGrplst_Pos, grmi.Equal, false),
		meta.ViewDefectGrplst_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.ViewDefectGrplst_LastModify, grmi.Approximate, false),
		meta.ViewDefectGrplst_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.ViewDefectGrplst_LastUser, grmi.Equal, false),
		meta.ViewDefectGrplst_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.ViewDefectGrplst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//ViewDefectGrplst的默认分页查询条件
var DefaultConditionOfViewDefectGrplstAndPaging = grmi.NewCondition(
	DefaultConditionOfViewDefectGrplst.Items,
	grmi.NewPaging(),
)

type ViewDefectGrplstServiceImplement struct {
}

func (self *ViewDefectGrplstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewDefectGrplst.service.impl.go", "SelectViewDefectGrplst", "查询ViewDefectGrplst")

	condition := DefaultConditionOfViewDefectGrplstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewViewDefectGrplstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *ViewDefectGrplstServiceImplement) InsertOne(user *models.Usertab, entity *model.ViewDefectGrplst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewDefectGrplst.service.impl.go", "InsertOneViewDefectGrplst", "插入一个ViewDefectGrplst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDefectGrplstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ViewId, entity.DefectGrpId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *ViewDefectGrplstServiceImplement) DeleteOne(user *models.Usertab, viewId string, defectGrpId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewDefectGrplst.service.impl.go", "DeleteOneViewDefectGrplst", "删除一个ViewDefectGrplst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDefectGrplstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(viewId, defectGrpId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(viewId, defectGrpId)
	if err != nil {
		return err
	}
	return nil
}

func (self *ViewDefectGrplstServiceImplement) SelectOne(user *models.Usertab, viewId string, defectGrpId string) (*model.ViewDefectGrplst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewDefectGrplst.service.impl.go", "SelectOneViewDefectGrplst", "查询一个ViewDefectGrplst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDefectGrplstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(viewId, defectGrpId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *ViewDefectGrplstServiceImplement) UpdateOne(user *models.Usertab, entity *model.ViewDefectGrplst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewDefectGrplst.service.impl.go", "UpdateOneViewDefectGrplst", "修改一个ViewDefectGrplst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDefectGrplstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ViewId, entity.DefectGrpId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewViewDefectGrplstServiceImplement() *ViewDefectGrplstServiceImplement {
	return &ViewDefectGrplstServiceImplement{}
}
