package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/qm"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//ViewDefectlst的默认查询条件
var DefaultConditionOfViewDefectlst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ViewDefectlst_ViewId.UrlParameterName:         grmi.NewConditionItem(meta.ViewDefectlst_ViewId, grmi.Equal, true),
		meta.ViewDefectlst_DefectReasonId.UrlParameterName: grmi.NewConditionItem(meta.ViewDefectlst_DefectReasonId, grmi.Equal, true),
		meta.ViewDefectlst_Pos.UrlParameterName:            grmi.NewConditionItem(meta.ViewDefectlst_Pos, grmi.Equal, false),
		meta.ViewDefectlst_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.ViewDefectlst_LastModify, grmi.Approximate, false),
		meta.ViewDefectlst_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.ViewDefectlst_LastUser, grmi.Equal, false),
		meta.ViewDefectlst_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.ViewDefectlst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//ViewDefectlst的默认分页查询条件
var DefaultConditionOfViewDefectlstAndPaging = grmi.NewCondition(
	DefaultConditionOfViewDefectlst.Items,
	grmi.NewPaging(),
)

type ViewDefectlstServiceImplement struct {
}

func (self *ViewDefectlstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewDefectlst.service.impl.go", "SelectViewDefectlst", "查询ViewDefectlst")

	condition := DefaultConditionOfViewDefectlstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewViewDefectlstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *ViewDefectlstServiceImplement) InsertOne(user *models.Usertab, entity *model.ViewDefectlst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewDefectlst.service.impl.go", "InsertOneViewDefectlst", "插入一个ViewDefectlst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDefectlstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ViewId, entity.DefectReasonId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *ViewDefectlstServiceImplement) DeleteOne(user *models.Usertab, viewId string, defectReasonId string) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewDefectlst.service.impl.go", "DeleteOneViewDefectlst", "删除一个ViewDefectlst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDefectlstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(viewId, defectReasonId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(viewId, defectReasonId)
	if err != nil {
		return err
	}
	return nil
}

func (self *ViewDefectlstServiceImplement) SelectOne(user *models.Usertab, viewId string, defectReasonId string) (*model.ViewDefectlst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewDefectlst.service.impl.go", "SelectOneViewDefectlst", "查询一个ViewDefectlst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDefectlstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(viewId, defectReasonId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *ViewDefectlstServiceImplement) UpdateOne(user *models.Usertab, entity *model.ViewDefectlst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewDefectlst.service.impl.go", "UpdateOneViewDefectlst", "修改一个ViewDefectlst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewDefectlstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ViewId, entity.DefectReasonId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewViewDefectlstServiceImplement() *ViewDefectlstServiceImplement {
	return &ViewDefectlstServiceImplement{}
}
