package implments

import (
	dal "leit.com/LAPP_GAAS_GFrame/dao/qm"
	"leit.com/LAPP_GAAS_GFrame/db"
	"leit.com/LAPP_GAAS_GFrame/grmi"
	meta "leit.com/LAPP_GAAS_GFrame/meta/qm"
	model "leit.com/LAPP_GAAS_GFrame/models/qm"
	"leit.com/LAPP_GAAS_GFrame/web/models"
)

//ViewValst的默认查询条件
var DefaultConditionOfViewValst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ViewValst_ViewId.UrlParameterName:     grmi.NewConditionItem(meta.ViewValst_ViewId, grmi.Equal, true),
		meta.ViewValst_Pos.UrlParameterName:        grmi.NewConditionItem(meta.ViewValst_Pos, grmi.Equal, true),
		meta.ViewValst_ValName.UrlParameterName:    grmi.NewConditionItem(meta.ViewValst_ValName, grmi.Equal, false),
		meta.ViewValst_XStart.UrlParameterName:     grmi.NewConditionItem(meta.ViewValst_XStart, grmi.Equal, false),
		meta.ViewValst_YStart.UrlParameterName:     grmi.NewConditionItem(meta.ViewValst_YStart, grmi.Equal, false),
		meta.ViewValst_Width.UrlParameterName:      grmi.NewConditionItem(meta.ViewValst_Width, grmi.Equal, false),
		meta.ViewValst_Height.UrlParameterName:     grmi.NewConditionItem(meta.ViewValst_Height, grmi.Equal, false),
		meta.ViewValst_Descr.UrlParameterName:      grmi.NewConditionItem(meta.ViewValst_Descr, grmi.Equal, false),
		meta.ViewValst_LastModify.UrlParameterName: grmi.NewConditionItem(meta.ViewValst_LastModify, grmi.Approximate, false),
		meta.ViewValst_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.ViewValst_LastUser, grmi.Equal, false),
		meta.ViewValst_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.ViewValst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

//ViewValst的默认分页查询条件
var DefaultConditionOfViewValstAndPaging = grmi.NewCondition(
	DefaultConditionOfViewValst.Items,
	grmi.NewPaging(),
)

type ViewValstServiceImplement struct {
}

func (self *ViewValstServiceImplement) Select(urlParameters map[string]string, user *models.Usertab) (interface{}, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewValst.service.impl.go", "SelectViewValst", "查询ViewValst")

	condition := DefaultConditionOfViewValstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewViewValstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

func (self *ViewValstServiceImplement) InsertOne(user *models.Usertab, entity *model.ViewValst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewValst.service.impl.go", "InsertOneViewValst", "插入一个ViewValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewValstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ViewId, entity.Pos)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func (self *ViewValstServiceImplement) DeleteOne(user *models.Usertab, viewId string, pos int) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewValst.service.impl.go", "DeleteOneViewValst", "删除一个ViewValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewValstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(viewId, pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(viewId, pos)
	if err != nil {
		return err
	}
	return nil
}

func (self *ViewValstServiceImplement) SelectOne(user *models.Usertab, viewId string, pos int) (*model.ViewValst, error) {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewValst.service.impl.go", "SelectOneViewValst", "查询一个ViewValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewValstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(viewId, pos)
	if err != nil {
		return nil, err
	}
	return result, nil
}

func (self *ViewValstServiceImplement) UpdateOne(user *models.Usertab, entity *model.ViewValst) error {

	grmi.Log(user, "/C:/Users/Wei Chenglei/source/repos/GAAS_BackEnd/services/qm/implments/QM_ViewValst.service.impl.go", "UpdateOneViewValst", "修改一个ViewValst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	dao := dal.NewViewValstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ViewId, entity.Pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

func NewViewValstServiceImplement() *ViewValstServiceImplement {
	return &ViewValstServiceImplement{}
}
