package log

import (
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
	model "leit.com/LAPP_GAAS_GFrame/models/log"
	"leit.com/LAPP_GAAS_GFrame/web/middleware/jwts"
	"leit.com/LAPP_GAAS_GFrame/web/models"
	"leit.com/LAPP_GAAS_GFrame/web/supports"
)

func RegisterSelectArtDemandHead(party router.Party, path string, method func(map[string]string, *models.Usertab) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		result, err := method(ctx.URLParams(), user)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

func RegisterInsertOneArtDemandHead(party router.Party, path string, method func(*models.Usertab, *model.ArtDemandHead) error) {

	party.Put(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ArtDemandHead)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

func RegisterDeleteOneArtDemandHead(party router.Party, path string, method func(*models.Usertab, string, string) error) {

	party.Delete(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		artId := ctx.Params().GetString("artId")
		demandId := ctx.Params().GetString("demandId")

		err = method(user, artId, demandId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

func RegisterSelectOneArtDemandHead(party router.Party, path string, method func(*models.Usertab, string, string) (*model.ArtDemandHead, error)) {

	party.Get(path+"/{artId:string}/{demandId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		artId := ctx.Params().GetString("artId")
		demandId := ctx.Params().GetString("demandId")
		result, err := method(user, artId, demandId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

func RegisterUpdateOneArtDemandHead(party router.Party, path string, method func(*models.Usertab, *model.ArtDemandHead) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ArtDemandHead)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
